#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/

void f_run_eval(double *data,double *x,double *y,double *u,double *p,double Dt){

data[0] = -p[17]*x[0] - y[64] + u[23] + 1; 

}

void g_run_eval(double *data,double *x,double *y,double *u,double *p,double Dt){

data[0] = 94.615102344455565*y[1] + 184.75059629806532*y[0] - 17.974903844364775*y[3] - 69.368640085185334*y[2] - 40.74868784166955*y[5] - 43.675799641021136*y[4] - 17.974903844364817*y[7] - 69.368640085185348*y[6] - 94.615102344455565*y[9] - 184.75059629806532*y[8] + 17.974903844364775*y[11] + 69.368640085185334*y[10] + 40.74868784166955*y[13] + 43.675799641021136*y[12] + 17.974903844364817*y[15] + 69.368640085185348*y[14] - y[40]; 
data[1] = 184.75059629806532*y[1] - 94.615102344455565*y[0] - 69.368640085185334*y[3] + 17.974903844364775*y[2] - 43.675799641021136*y[5] + 40.74868784166955*y[4] - 69.368640085185348*y[7] + 17.974903844364817*y[6] - 184.75059629806532*y[9] + 94.615102344455565*y[8] + 69.368640085185334*y[11] - 17.974903844364775*y[10] + 43.675799641021136*y[13] - 40.74868784166955*y[12] + 69.368640085185348*y[15] - 17.974903844364817*y[14] - y[44]; 
data[2] = -17.974903844364796*y[1] - 69.368640085185319*y[0] + 94.615102344455607*y[3] + 184.75059629806523*y[2] - 17.974903844364814*y[5] - 69.368640085185291*y[4] - 40.748687841669586*y[7] - 43.675799641021079*y[6] + 17.974903844364796*y[9] + 69.368640085185319*y[8] - 94.615102344455607*y[11] - 184.75059629806523*y[10] + 17.974903844364814*y[13] + 69.368640085185291*y[12] + 40.748687841669586*y[15] + 43.675799641021079*y[14] - y[41]; 
data[3] = -69.368640085185319*y[1] + 17.974903844364796*y[0] + 184.75059629806523*y[3] - 94.615102344455607*y[2] - 69.368640085185291*y[5] + 17.974903844364814*y[4] - 43.675799641021079*y[7] + 40.748687841669586*y[6] + 69.368640085185319*y[9] - 17.974903844364796*y[8] - 184.75059629806523*y[11] + 94.615102344455607*y[10] + 69.368640085185291*y[13] - 17.974903844364814*y[12] + 43.675799641021079*y[15] - 40.748687841669586*y[14] - y[45]; 
data[4] = -40.748687841669557*y[1] - 43.675799641021122*y[0] - 17.97490384436481*y[3] - 69.368640085185277*y[2] + 94.615102344455636*y[5] + 184.75059629806526*y[4] - 17.974903844364817*y[7] - 69.368640085185277*y[6] + 40.748687841669557*y[9] + 43.675799641021122*y[8] + 17.97490384436481*y[11] + 69.368640085185277*y[10] - 94.615102344455636*y[13] - 184.75059629806526*y[12] + 17.974903844364817*y[15] + 69.368640085185277*y[14] - y[42]; 
data[5] = -43.675799641021122*y[1] + 40.748687841669557*y[0] - 69.368640085185277*y[3] + 17.97490384436481*y[2] + 184.75059629806526*y[5] - 94.615102344455636*y[4] - 69.368640085185277*y[7] + 17.974903844364817*y[6] + 43.675799641021122*y[9] - 40.748687841669557*y[8] + 69.368640085185277*y[11] - 17.97490384436481*y[10] - 184.75059629806526*y[13] + 94.615102344455636*y[12] + 69.368640085185277*y[15] - 17.974903844364817*y[14] - y[46]; 
data[6] = -17.9749038443648*y[1] - 69.368640085185334*y[0] - 40.748687841669586*y[3] - 43.675799641021086*y[2] - 17.974903844364821*y[5] - 69.368640085185291*y[4] + 94.61510234445565*y[7] + 184.75059629806523*y[6] + 17.9749038443648*y[9] + 69.368640085185334*y[8] + 40.748687841669586*y[11] + 43.675799641021086*y[10] + 17.974903844364821*y[13] + 69.368640085185291*y[12] - 94.61510234445565*y[15] - 184.75059629806523*y[14] - y[43]; 
data[7] = -69.368640085185334*y[1] + 17.9749038443648*y[0] - 43.675799641021086*y[3] + 40.748687841669586*y[2] - 69.368640085185291*y[5] + 17.974903844364821*y[4] + 184.75059629806523*y[7] - 94.61510234445565*y[6] + 69.368640085185334*y[9] - 17.9749038443648*y[8] + 43.675799641021086*y[11] - 40.748687841669586*y[10] + 69.368640085185291*y[13] - 17.974903844364821*y[12] - 184.75059629806523*y[15] + 94.61510234445565*y[14] - y[47]; 
data[8] = -94.615102344455565*y[1] - 184.75059629806532*y[0] + 17.974903844364775*y[3] + 69.368640085185334*y[2] + 40.74868784166955*y[5] + 43.675799641021136*y[4] + 17.974903844364817*y[7] + 69.368640085185348*y[6] + 94.615102344455565*y[9] + 184.75059629806532*y[8] - 17.974903844364775*y[11] - 69.368640085185334*y[10] - 40.74868784166955*y[13] - 43.675799641021136*y[12] - 17.974903844364817*y[15] - 69.368640085185348*y[14] - y[56]*u[22] - y[32]; 
data[9] = -184.75059629806532*y[1] + 94.615102344455565*y[0] + 69.368640085185334*y[3] - 17.974903844364775*y[2] + 43.675799641021136*y[5] - 40.74868784166955*y[4] + 69.368640085185348*y[7] - 17.974903844364817*y[6] + 184.75059629806532*y[9] - 94.615102344455565*y[8] - 69.368640085185334*y[11] + 17.974903844364775*y[10] - 43.675799641021136*y[13] + 40.74868784166955*y[12] - 69.368640085185348*y[15] + 17.974903844364817*y[14] - y[60]*u[22] - y[33]; 
data[10] = 17.974903844364796*y[1] + 69.368640085185319*y[0] - 94.615102344455607*y[3] - 184.75059629806523*y[2] + 17.974903844364814*y[5] + 69.368640085185291*y[4] + 40.748687841669586*y[7] + 43.675799641021079*y[6] - 17.974903844364796*y[9] - 69.368640085185319*y[8] + 94.615102344455607*y[11] + 184.75059629806523*y[10] - 17.974903844364814*y[13] - 69.368640085185291*y[12] - 40.748687841669586*y[15] - 43.675799641021079*y[14] - y[57]*u[22] - y[34]; 
data[11] = 69.368640085185319*y[1] - 17.974903844364796*y[0] - 184.75059629806523*y[3] + 94.615102344455607*y[2] + 69.368640085185291*y[5] - 17.974903844364814*y[4] + 43.675799641021079*y[7] - 40.748687841669586*y[6] - 69.368640085185319*y[9] + 17.974903844364796*y[8] + 184.75059629806523*y[11] - 94.615102344455607*y[10] - 69.368640085185291*y[13] + 17.974903844364814*y[12] - 43.675799641021079*y[15] + 40.748687841669586*y[14] - y[61]*u[22] - y[35]; 
data[12] = 40.748687841669557*y[1] + 43.675799641021122*y[0] + 17.97490384436481*y[3] + 69.368640085185277*y[2] - 94.615102344455636*y[5] - 184.75059629806526*y[4] + 17.974903844364817*y[7] + 69.368640085185277*y[6] - 40.748687841669557*y[9] - 43.675799641021122*y[8] - 17.97490384436481*y[11] - 69.368640085185277*y[10] + 94.615102344455636*y[13] + 184.75059629806526*y[12] - 17.974903844364817*y[15] - 69.368640085185277*y[14] - y[58]*u[22] - y[36]; 
data[13] = 43.675799641021122*y[1] - 40.748687841669557*y[0] + 69.368640085185277*y[3] - 17.97490384436481*y[2] - 184.75059629806526*y[5] + 94.615102344455636*y[4] + 69.368640085185277*y[7] - 17.974903844364817*y[6] - 43.675799641021122*y[9] + 40.748687841669557*y[8] - 69.368640085185277*y[11] + 17.97490384436481*y[10] + 184.75059629806526*y[13] - 94.615102344455636*y[12] - 69.368640085185277*y[15] + 17.974903844364817*y[14] - y[62]*u[22] - y[37]; 
data[14] = 17.9749038443648*y[1] + 69.368640085185334*y[0] + 40.748687841669586*y[3] + 43.675799641021086*y[2] + 17.974903844364821*y[5] + 69.368640085185291*y[4] - 94.61510234445565*y[7] - 184.75059629806523*y[6] - 17.9749038443648*y[9] - 69.368640085185334*y[8] - 40.748687841669586*y[11] - 43.675799641021086*y[10] - 17.974903844364821*y[13] - 69.368640085185291*y[12] + 94.61510234445565*y[15] + 184.75059629806523*y[14] - y[59]*u[22] - y[38]; 
data[15] = 69.368640085185334*y[1] - 17.9749038443648*y[0] + 43.675799641021086*y[3] - 40.748687841669586*y[2] + 69.368640085185291*y[5] - 17.974903844364821*y[4] - 184.75059629806523*y[7] + 94.61510234445565*y[6] - 69.368640085185334*y[9] + 17.9749038443648*y[8] - 43.675799641021086*y[11] + 40.748687841669586*y[10] - 69.368640085185291*y[13] + 17.974903844364821*y[12] + 184.75059629806523*y[15] - 94.61510234445565*y[14] - y[63]*u[22] - y[39]; 
data[16] = 94.615102344455565*y[17] + 184.75059629806532*y[16] - 17.974903844364775*y[19] - 69.368640085185334*y[18] - 40.74868784166955*y[21] - 43.675799641021136*y[20] - 17.974903844364817*y[23] - 69.368640085185348*y[22] - 94.615102344455565*y[25] - 184.75059629806532*y[24] + 17.974903844364775*y[27] + 69.368640085185334*y[26] + 40.74868784166955*y[29] + 43.675799641021136*y[28] + 17.974903844364817*y[31] + 69.368640085185348*y[30] + y[56]*u[22]; 
data[17] = 184.75059629806532*y[17] - 94.615102344455565*y[16] - 69.368640085185334*y[19] + 17.974903844364775*y[18] - 43.675799641021136*y[21] + 40.74868784166955*y[20] - 69.368640085185348*y[23] + 17.974903844364817*y[22] - 184.75059629806532*y[25] + 94.615102344455565*y[24] + 69.368640085185334*y[27] - 17.974903844364775*y[26] + 43.675799641021136*y[29] - 40.74868784166955*y[28] + 69.368640085185348*y[31] - 17.974903844364817*y[30] + y[60]*u[22]; 
data[18] = -17.974903844364796*y[17] - 69.368640085185319*y[16] + 94.615102344455607*y[19] + 184.75059629806523*y[18] - 17.974903844364814*y[21] - 69.368640085185291*y[20] - 40.748687841669586*y[23] - 43.675799641021079*y[22] + 17.974903844364796*y[25] + 69.368640085185319*y[24] - 94.615102344455607*y[27] - 184.75059629806523*y[26] + 17.974903844364814*y[29] + 69.368640085185291*y[28] + 40.748687841669586*y[31] + 43.675799641021079*y[30] + y[57]*u[22]; 
data[19] = -69.368640085185319*y[17] + 17.974903844364796*y[16] + 184.75059629806523*y[19] - 94.615102344455607*y[18] - 69.368640085185291*y[21] + 17.974903844364814*y[20] - 43.675799641021079*y[23] + 40.748687841669586*y[22] + 69.368640085185319*y[25] - 17.974903844364796*y[24] - 184.75059629806523*y[27] + 94.615102344455607*y[26] + 69.368640085185291*y[29] - 17.974903844364814*y[28] + 43.675799641021079*y[31] - 40.748687841669586*y[30] + y[61]*u[22]; 
data[20] = -40.748687841669557*y[17] - 43.675799641021122*y[16] - 17.97490384436481*y[19] - 69.368640085185277*y[18] + 94.615102344455636*y[21] + 184.75059629806526*y[20] - 17.974903844364817*y[23] - 69.368640085185277*y[22] + 40.748687841669557*y[25] + 43.675799641021122*y[24] + 17.97490384436481*y[27] + 69.368640085185277*y[26] - 94.615102344455636*y[29] - 184.75059629806526*y[28] + 17.974903844364817*y[31] + 69.368640085185277*y[30] + y[58]*u[22]; 
data[21] = -43.675799641021122*y[17] + 40.748687841669557*y[16] - 69.368640085185277*y[19] + 17.97490384436481*y[18] + 184.75059629806526*y[21] - 94.615102344455636*y[20] - 69.368640085185277*y[23] + 17.974903844364817*y[22] + 43.675799641021122*y[25] - 40.748687841669557*y[24] + 69.368640085185277*y[27] - 17.97490384436481*y[26] - 184.75059629806526*y[29] + 94.615102344455636*y[28] + 69.368640085185277*y[31] - 17.974903844364817*y[30] + y[62]*u[22]; 
data[22] = -17.9749038443648*y[17] - 69.368640085185334*y[16] - 40.748687841669586*y[19] - 43.675799641021086*y[18] - 17.974903844364821*y[21] - 69.368640085185291*y[20] + 94.61510234445565*y[23] + 184.75059629806523*y[22] + 17.9749038443648*y[25] + 69.368640085185334*y[24] + 40.748687841669586*y[27] + 43.675799641021086*y[26] + 17.974903844364821*y[29] + 69.368640085185291*y[28] - 94.61510234445565*y[31] - 184.75059629806523*y[30] + y[59]*u[22]; 
data[23] = -69.368640085185334*y[17] + 17.9749038443648*y[16] - 43.675799641021086*y[19] + 40.748687841669586*y[18] - 69.368640085185291*y[21] + 17.974903844364821*y[20] + 184.75059629806523*y[23] - 94.61510234445565*y[22] + 69.368640085185334*y[25] - 17.9749038443648*y[24] + 43.675799641021086*y[27] - 40.748687841669586*y[26] + 69.368640085185291*y[29] - 17.974903844364821*y[28] - 184.75059629806523*y[31] + 94.61510234445565*y[30] + y[63]*u[22]; 
data[24] = -94.615102344455565*y[17] - 184.75059629806532*y[16] + 17.974903844364775*y[19] + 69.368640085185334*y[18] + 40.74868784166955*y[21] + 43.675799641021136*y[20] + 17.974903844364817*y[23] + 69.368640085185348*y[22] + 94.615102344455565*y[25] + 184.75059629806532*y[24] - 17.974903844364775*y[27] - 69.368640085185334*y[26] - 40.74868784166955*y[29] - 43.675799641021136*y[28] - 17.974903844364817*y[31] - 69.368640085185348*y[30] - y[48]; 
data[25] = -184.75059629806532*y[17] + 94.615102344455565*y[16] + 69.368640085185334*y[19] - 17.974903844364775*y[18] + 43.675799641021136*y[21] - 40.74868784166955*y[20] + 69.368640085185348*y[23] - 17.974903844364817*y[22] + 184.75059629806532*y[25] - 94.615102344455565*y[24] - 69.368640085185334*y[27] + 17.974903844364775*y[26] - 43.675799641021136*y[29] + 40.74868784166955*y[28] - 69.368640085185348*y[31] + 17.974903844364817*y[30] - y[52]; 
data[26] = 17.974903844364796*y[17] + 69.368640085185319*y[16] - 94.615102344455607*y[19] - 184.75059629806523*y[18] + 17.974903844364814*y[21] + 69.368640085185291*y[20] + 40.748687841669586*y[23] + 43.675799641021079*y[22] - 17.974903844364796*y[25] - 69.368640085185319*y[24] + 94.615102344455607*y[27] + 184.75059629806523*y[26] - 17.974903844364814*y[29] - 69.368640085185291*y[28] - 40.748687841669586*y[31] - 43.675799641021079*y[30] - y[49]; 
data[27] = 69.368640085185319*y[17] - 17.974903844364796*y[16] - 184.75059629806523*y[19] + 94.615102344455607*y[18] + 69.368640085185291*y[21] - 17.974903844364814*y[20] + 43.675799641021079*y[23] - 40.748687841669586*y[22] - 69.368640085185319*y[25] + 17.974903844364796*y[24] + 184.75059629806523*y[27] - 94.615102344455607*y[26] - 69.368640085185291*y[29] + 17.974903844364814*y[28] - 43.675799641021079*y[31] + 40.748687841669586*y[30] - y[53]; 
data[28] = 40.748687841669557*y[17] + 43.675799641021122*y[16] + 17.97490384436481*y[19] + 69.368640085185277*y[18] - 94.615102344455636*y[21] - 184.75059629806526*y[20] + 17.974903844364817*y[23] + 69.368640085185277*y[22] - 40.748687841669557*y[25] - 43.675799641021122*y[24] - 17.97490384436481*y[27] - 69.368640085185277*y[26] + 94.615102344455636*y[29] + 184.75059629806526*y[28] - 17.974903844364817*y[31] - 69.368640085185277*y[30] - y[50]; 
data[29] = 43.675799641021122*y[17] - 40.748687841669557*y[16] + 69.368640085185277*y[19] - 17.97490384436481*y[18] - 184.75059629806526*y[21] + 94.615102344455636*y[20] + 69.368640085185277*y[23] - 17.974903844364817*y[22] - 43.675799641021122*y[25] + 40.748687841669557*y[24] - 69.368640085185277*y[27] + 17.97490384436481*y[26] + 184.75059629806526*y[29] - 94.615102344455636*y[28] - 69.368640085185277*y[31] + 17.974903844364817*y[30] - y[54]; 
data[30] = 17.9749038443648*y[17] + 69.368640085185334*y[16] + 40.748687841669586*y[19] + 43.675799641021086*y[18] + 17.974903844364821*y[21] + 69.368640085185291*y[20] - 94.61510234445565*y[23] - 184.75059629806523*y[22] - 17.9749038443648*y[25] - 69.368640085185334*y[24] - 40.748687841669586*y[27] - 43.675799641021086*y[26] - 17.974903844364821*y[29] - 69.368640085185291*y[28] + 94.61510234445565*y[31] + 184.75059629806523*y[30] - y[51]; 
data[31] = 69.368640085185334*y[17] - 17.9749038443648*y[16] + 43.675799641021086*y[19] - 40.748687841669586*y[18] + 69.368640085185291*y[21] - 17.974903844364821*y[20] - 184.75059629806523*y[23] + 94.61510234445565*y[22] - 69.368640085185334*y[25] + 17.9749038443648*y[24] - 43.675799641021086*y[27] + 40.748687841669586*y[26] - 69.368640085185291*y[29] + 17.974903844364821*y[28] + 184.75059629806523*y[31] - 94.61510234445565*y[30] - y[55]; 
data[32] = p[0]*(pow(y[9], 2)*u[2] - 2*y[9]*y[15]*u[2] + pow(y[8], 2)*u[2] - 2*y[8]*y[14]*u[2] + pow(y[15], 2)*u[2] + pow(y[14], 2)*u[2] + u[0] + (y[9]*y[33] + y[8]*y[32] - y[15]*y[33] - y[14]*y[32])*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[33] = p[0]*(pow(y[11], 2)*u[6] - 2*y[11]*y[15]*u[6] + pow(y[10], 2)*u[6] - 2*y[10]*y[14]*u[6] + pow(y[15], 2)*u[6] + pow(y[14], 2)*u[6] + u[4] + (y[11]*y[35] + y[10]*y[34] - y[15]*y[35] - y[14]*y[34])*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[34] = p[0]*(pow(y[13], 2)*u[10] - 2*y[13]*y[15]*u[10] + pow(y[12], 2)*u[10] - 2*y[12]*y[14]*u[10] + pow(y[15], 2)*u[10] + pow(y[14], 2)*u[10] + u[8] + (y[13]*y[37] + y[12]*y[36] - y[15]*y[37] - y[14]*y[36])*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[35] = p[0]*(-1.0*pow(y[9], 2)*u[3] + 2.0*y[9]*y[15]*u[3] - 1.0*pow(y[8], 2)*u[3] + 2.0*y[8]*y[14]*u[3] - 1.0*pow(y[15], 2)*u[3] - 1.0*pow(y[14], 2)*u[3] + u[1] + (y[9]*y[32] - y[8]*y[33] - y[15]*y[32] + y[14]*y[33])*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[36] = p[0]*(-1.0*pow(y[11], 2)*u[7] + 2.0*y[11]*y[15]*u[7] - 1.0*pow(y[10], 2)*u[7] + 2.0*y[10]*y[14]*u[7] - 1.0*pow(y[15], 2)*u[7] - 1.0*pow(y[14], 2)*u[7] + u[5] + (y[11]*y[34] - y[10]*y[35] - y[15]*y[34] + y[14]*y[35])*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[37] = p[0]*(-1.0*pow(y[13], 2)*u[11] + 2.0*y[13]*y[15]*u[11] - 1.0*pow(y[12], 2)*u[11] + 2.0*y[12]*y[14]*u[11] - 1.0*pow(y[15], 2)*u[11] - 1.0*pow(y[14], 2)*u[11] + u[9] + (y[13]*y[36] - y[12]*y[37] - y[15]*y[36] + y[14]*y[37])*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[38] = y[32] + y[34] + y[36] + y[38]; 
data[39] = y[33] + y[35] + y[37] + y[39]; 
data[40] = -p[2]*y[40] - y[0] + 1.0*p[1]*y[44] + u[12]*cos(u[16]); 
data[41] = -p[2]*y[41] - y[2] + 1.0*p[1]*y[45] + u[13]*cos(u[16] - 2.0943951023931953); 
data[42] = -p[2]*y[42] - y[4] + 1.0*p[1]*y[46] + u[14]*cos(u[16] - 4.1887902047863905); 
data[43] = -p[4]*y[43] - y[6] + 1.0*p[3]*y[47]; 
data[44] = -1.0*p[2]*y[44] - 1.0*y[1] - 1.0*p[1]*y[40] + 1.0*u[12]*sin(u[16]); 
data[45] = -1.0*p[2]*y[45] - 1.0*y[3] - 1.0*p[1]*y[41] + 1.0*u[13]*sin(u[16] - 2.0943951023931953); 
data[46] = -1.0*p[2]*y[46] - 1.0*y[5] - 1.0*p[1]*y[42] + 1.0*u[14]*sin(u[16] - 4.1887902047863905); 
data[47] = -1.0*p[4]*y[47] - 1.0*y[7] - 1.0*p[3]*y[43]; 
data[48] = -p[8]*y[48] - y[24] + 1.0*p[7]*y[52] + u[17]*cos(u[21]); 
data[49] = -p[8]*y[49] - y[26] + 1.0*p[7]*y[53] + u[18]*cos(u[21] - 2.0943951023931953); 
data[50] = -p[8]*y[50] - y[28] + 1.0*p[7]*y[54] + u[19]*cos(u[21] - 4.1887902047863905); 
data[51] = -p[10]*y[51] - y[30] + 1.0*p[9]*y[55]; 
data[52] = -1.0*p[8]*y[52] - 1.0*y[25] - 1.0*p[7]*y[48] + 1.0*u[17]*sin(u[21]); 
data[53] = -1.0*p[8]*y[53] - 1.0*y[27] - 1.0*p[7]*y[49] + 1.0*u[18]*sin(u[21] - 2.0943951023931953); 
data[54] = -1.0*p[8]*y[54] - 1.0*y[29] - 1.0*p[7]*y[50] + 1.0*u[19]*sin(u[21] - 4.1887902047863905); 
data[55] = -1.0*p[10]*y[55] - 1.0*y[31] - 1.0*p[9]*y[51]; 
data[56] = -p[13]*y[56] + y[8] - y[16] + 1.0*p[14]*y[60]; 
data[57] = -p[13]*y[57] + y[10] - y[18] + 1.0*p[14]*y[61]; 
data[58] = -p[13]*y[58] + y[12] - y[20] + 1.0*p[14]*y[62]; 
data[59] = -p[13]*y[59] + y[14] - y[22] + 1.0*p[14]*y[63]; 
data[60] = -1.0*p[13]*y[60] + 1.0*y[9] - 1.0*y[17] - 1.0*p[14]*y[56]; 
data[61] = -1.0*p[13]*y[61] + 1.0*y[11] - 1.0*y[19] - 1.0*p[14]*y[57]; 
data[62] = -1.0*p[13]*y[62] + 1.0*y[13] - 1.0*y[21] - 1.0*p[14]*y[58]; 
data[63] = -1.0*p[13]*y[63] + 1.0*y[15] - 1.0*y[23] - 1.0*p[14]*y[59]; 
data[64] = 1.0 - y[64]; 
data[65] = p[16]*x[0] + p[15]*(1 - y[64]) - y[65]; 

}

void h_eval(double *data,double *x,double *y,double *u,double *p,double Dt){

data[0] = 94.615102344455565*y[1] + 184.75059629806532*y[0] - 17.974903844364775*y[3] - 69.368640085185334*y[2] - 40.74868784166955*y[5] - 43.675799641021136*y[4] - 17.974903844364817*y[7] - 69.368640085185348*y[6] - 94.615102344455565*y[9] - 184.75059629806532*y[8] + 17.974903844364775*y[11] + 69.368640085185334*y[10] + 40.74868784166955*y[13] + 43.675799641021136*y[12] + 17.974903844364817*y[15] + 69.368640085185348*y[14]; 
data[1] = 184.75059629806532*y[1] - 94.615102344455565*y[0] - 69.368640085185334*y[3] + 17.974903844364775*y[2] - 43.675799641021136*y[5] + 40.74868784166955*y[4] - 69.368640085185348*y[7] + 17.974903844364817*y[6] - 184.75059629806532*y[9] + 94.615102344455565*y[8] + 69.368640085185334*y[11] - 17.974903844364775*y[10] + 43.675799641021136*y[13] - 40.74868784166955*y[12] + 69.368640085185348*y[15] - 17.974903844364817*y[14]; 
data[2] = -17.974903844364796*y[1] - 69.368640085185319*y[0] + 94.615102344455607*y[3] + 184.75059629806523*y[2] - 17.974903844364814*y[5] - 69.368640085185291*y[4] - 40.748687841669586*y[7] - 43.675799641021079*y[6] + 17.974903844364796*y[9] + 69.368640085185319*y[8] - 94.615102344455607*y[11] - 184.75059629806523*y[10] + 17.974903844364814*y[13] + 69.368640085185291*y[12] + 40.748687841669586*y[15] + 43.675799641021079*y[14]; 
data[3] = -69.368640085185319*y[1] + 17.974903844364796*y[0] + 184.75059629806523*y[3] - 94.615102344455607*y[2] - 69.368640085185291*y[5] + 17.974903844364814*y[4] - 43.675799641021079*y[7] + 40.748687841669586*y[6] + 69.368640085185319*y[9] - 17.974903844364796*y[8] - 184.75059629806523*y[11] + 94.615102344455607*y[10] + 69.368640085185291*y[13] - 17.974903844364814*y[12] + 43.675799641021079*y[15] - 40.748687841669586*y[14]; 
data[4] = -40.748687841669557*y[1] - 43.675799641021122*y[0] - 17.97490384436481*y[3] - 69.368640085185277*y[2] + 94.615102344455636*y[5] + 184.75059629806526*y[4] - 17.974903844364817*y[7] - 69.368640085185277*y[6] + 40.748687841669557*y[9] + 43.675799641021122*y[8] + 17.97490384436481*y[11] + 69.368640085185277*y[10] - 94.615102344455636*y[13] - 184.75059629806526*y[12] + 17.974903844364817*y[15] + 69.368640085185277*y[14]; 
data[5] = -43.675799641021122*y[1] + 40.748687841669557*y[0] - 69.368640085185277*y[3] + 17.97490384436481*y[2] + 184.75059629806526*y[5] - 94.615102344455636*y[4] - 69.368640085185277*y[7] + 17.974903844364817*y[6] + 43.675799641021122*y[9] - 40.748687841669557*y[8] + 69.368640085185277*y[11] - 17.97490384436481*y[10] - 184.75059629806526*y[13] + 94.615102344455636*y[12] + 69.368640085185277*y[15] - 17.974903844364817*y[14]; 
data[6] = -17.9749038443648*y[1] - 69.368640085185334*y[0] - 40.748687841669586*y[3] - 43.675799641021086*y[2] - 17.974903844364821*y[5] - 69.368640085185291*y[4] + 94.61510234445565*y[7] + 184.75059629806523*y[6] + 17.9749038443648*y[9] + 69.368640085185334*y[8] + 40.748687841669586*y[11] + 43.675799641021086*y[10] + 17.974903844364821*y[13] + 69.368640085185291*y[12] - 94.61510234445565*y[15] - 184.75059629806523*y[14]; 
data[7] = -69.368640085185334*y[1] + 17.9749038443648*y[0] - 43.675799641021086*y[3] + 40.748687841669586*y[2] - 69.368640085185291*y[5] + 17.974903844364821*y[4] + 184.75059629806523*y[7] - 94.61510234445565*y[6] + 69.368640085185334*y[9] - 17.9749038443648*y[8] + 43.675799641021086*y[11] - 40.748687841669586*y[10] + 69.368640085185291*y[13] - 17.974903844364821*y[12] - 184.75059629806523*y[15] + 94.61510234445565*y[14]; 
data[8] = 94.615102344455565*y[17] + 184.75059629806532*y[16] - 17.974903844364775*y[19] - 69.368640085185334*y[18] - 40.74868784166955*y[21] - 43.675799641021136*y[20] - 17.974903844364817*y[23] - 69.368640085185348*y[22] - 94.615102344455565*y[25] - 184.75059629806532*y[24] + 17.974903844364775*y[27] + 69.368640085185334*y[26] + 40.74868784166955*y[29] + 43.675799641021136*y[28] + 17.974903844364817*y[31] + 69.368640085185348*y[30]; 
data[9] = 184.75059629806532*y[17] - 94.615102344455565*y[16] - 69.368640085185334*y[19] + 17.974903844364775*y[18] - 43.675799641021136*y[21] + 40.74868784166955*y[20] - 69.368640085185348*y[23] + 17.974903844364817*y[22] - 184.75059629806532*y[25] + 94.615102344455565*y[24] + 69.368640085185334*y[27] - 17.974903844364775*y[26] + 43.675799641021136*y[29] - 40.74868784166955*y[28] + 69.368640085185348*y[31] - 17.974903844364817*y[30]; 
data[10] = -17.974903844364796*y[17] - 69.368640085185319*y[16] + 94.615102344455607*y[19] + 184.75059629806523*y[18] - 17.974903844364814*y[21] - 69.368640085185291*y[20] - 40.748687841669586*y[23] - 43.675799641021079*y[22] + 17.974903844364796*y[25] + 69.368640085185319*y[24] - 94.615102344455607*y[27] - 184.75059629806523*y[26] + 17.974903844364814*y[29] + 69.368640085185291*y[28] + 40.748687841669586*y[31] + 43.675799641021079*y[30]; 
data[11] = -69.368640085185319*y[17] + 17.974903844364796*y[16] + 184.75059629806523*y[19] - 94.615102344455607*y[18] - 69.368640085185291*y[21] + 17.974903844364814*y[20] - 43.675799641021079*y[23] + 40.748687841669586*y[22] + 69.368640085185319*y[25] - 17.974903844364796*y[24] - 184.75059629806523*y[27] + 94.615102344455607*y[26] + 69.368640085185291*y[29] - 17.974903844364814*y[28] + 43.675799641021079*y[31] - 40.748687841669586*y[30]; 
data[12] = -40.748687841669557*y[17] - 43.675799641021122*y[16] - 17.97490384436481*y[19] - 69.368640085185277*y[18] + 94.615102344455636*y[21] + 184.75059629806526*y[20] - 17.974903844364817*y[23] - 69.368640085185277*y[22] + 40.748687841669557*y[25] + 43.675799641021122*y[24] + 17.97490384436481*y[27] + 69.368640085185277*y[26] - 94.615102344455636*y[29] - 184.75059629806526*y[28] + 17.974903844364817*y[31] + 69.368640085185277*y[30]; 
data[13] = -43.675799641021122*y[17] + 40.748687841669557*y[16] - 69.368640085185277*y[19] + 17.97490384436481*y[18] + 184.75059629806526*y[21] - 94.615102344455636*y[20] - 69.368640085185277*y[23] + 17.974903844364817*y[22] + 43.675799641021122*y[25] - 40.748687841669557*y[24] + 69.368640085185277*y[27] - 17.97490384436481*y[26] - 184.75059629806526*y[29] + 94.615102344455636*y[28] + 69.368640085185277*y[31] - 17.974903844364817*y[30]; 
data[14] = -17.9749038443648*y[17] - 69.368640085185334*y[16] - 40.748687841669586*y[19] - 43.675799641021086*y[18] - 17.974903844364821*y[21] - 69.368640085185291*y[20] + 94.61510234445565*y[23] + 184.75059629806523*y[22] + 17.9749038443648*y[25] + 69.368640085185334*y[24] + 40.748687841669586*y[27] + 43.675799641021086*y[26] + 17.974903844364821*y[29] + 69.368640085185291*y[28] - 94.61510234445565*y[31] - 184.75059629806523*y[30]; 
data[15] = -69.368640085185334*y[17] + 17.9749038443648*y[16] - 43.675799641021086*y[19] + 40.748687841669586*y[18] - 69.368640085185291*y[21] + 17.974903844364821*y[20] + 184.75059629806523*y[23] - 94.61510234445565*y[22] + 69.368640085185334*y[25] - 17.9749038443648*y[24] + 43.675799641021086*y[27] - 40.748687841669586*y[26] + 69.368640085185291*y[29] - 17.974903844364821*y[28] - 184.75059629806523*y[31] + 94.61510234445565*y[30]; 
data[16] = sqrt(pow(y[9], 2) + pow(y[8], 2)); 
data[17] = sqrt(pow(y[11], 2) + pow(y[10], 2)); 
data[18] = sqrt(pow(y[13], 2) + pow(y[12], 2)); 
data[19] = sqrt(1.0*pow(y[44], 2) + pow(y[40], 2)); 
data[20] = sqrt(1.0*pow(y[45], 2) + pow(y[41], 2)); 
data[21] = sqrt(1.0*pow(y[46], 2) + pow(y[42], 2)); 
data[22] = sqrt(1.0*pow(y[47], 2) + pow(y[43], 2)); 
data[23] = 1.0*y[1]*y[44] + y[0]*y[40] + 1.0*y[3]*y[45] + y[2]*y[41] + 1.0*y[5]*y[46] + y[4]*y[42]; 
data[24] = 1.0*y[1]*y[40] - 1.0*y[0]*y[44] + 1.0*y[3]*y[41] - 1.0*y[2]*y[45] + 1.0*y[5]*y[42] - 1.0*y[4]*y[46]; 
data[25] = sqrt(1.0*pow(y[52], 2) + pow(y[48], 2)); 
data[26] = sqrt(1.0*pow(y[53], 2) + pow(y[49], 2)); 
data[27] = sqrt(1.0*pow(y[54], 2) + pow(y[50], 2)); 
data[28] = sqrt(1.0*pow(y[55], 2) + pow(y[51], 2)); 
data[29] = 1.0*y[25]*y[52] + y[24]*y[48] + 1.0*y[27]*y[53] + y[26]*y[49] + 1.0*y[29]*y[54] + y[28]*y[50]; 
data[30] = 1.0*y[25]*y[48] - 1.0*y[24]*y[52] + 1.0*y[27]*y[49] - 1.0*y[26]*y[53] + 1.0*y[29]*y[50] - 1.0*y[28]*y[54]; 
data[31] = sqrt(1.0*pow(y[60], 2) + pow(y[56], 2)); 
data[32] = sqrt(1.0*pow(y[61], 2) + pow(y[57], 2)); 
data[33] = sqrt(1.0*pow(y[62], 2) + pow(y[58], 2)); 
data[34] = sqrt(1.0*pow(y[63], 2) + pow(y[59], 2)); 
data[35] = sqrt(1.0*pow(y[60], 2) + pow(y[56], 2)); 
data[36] = sqrt(1.0*pow(y[61], 2) + pow(y[57], 2)); 
data[37] = sqrt(1.0*pow(y[62], 2) + pow(y[58], 2)); 
data[38] = sqrt(1.0*pow(y[63], 2) + pow(y[59], 2)); 
data[39] = x[0]; 
data[40] = u[23]; 

}

void de_jac_run_up_eval(double *data,double *x,double *y,double *u,double *p,double Dt){

data[0] = -p[17]; 
data[660] = -u[22]; 
data[731] = -u[22]; 
data[795] = -u[22]; 
data[866] = -u[22]; 
data[930] = -u[22]; 
data[1001] = -u[22]; 
data[1065] = -u[22]; 
data[1136] = -u[22]; 
data[1196] = u[22]; 
data[1267] = u[22]; 
data[1331] = u[22]; 
data[1402] = u[22]; 
data[1466] = u[22]; 
data[1537] = u[22]; 
data[1601] = u[22]; 
data[1672] = u[22]; 
data[2788] = -p[2]; 
data[2792] = 1.0*p[1]; 
data[2856] = -p[2]; 
data[2860] = 1.0*p[1]; 
data[2924] = -p[2]; 
data[2928] = 1.0*p[1]; 
data[2992] = -p[4]; 
data[2996] = 1.0*p[3]; 
data[3056] = -1.0*p[1]; 
data[3060] = -1.0*p[2]; 
data[3124] = -1.0*p[1]; 
data[3128] = -1.0*p[2]; 
data[3192] = -1.0*p[1]; 
data[3196] = -1.0*p[2]; 
data[3260] = -1.0*p[3]; 
data[3264] = -1.0*p[4]; 
data[3332] = -p[8]; 
data[3336] = 1.0*p[7]; 
data[3400] = -p[8]; 
data[3404] = 1.0*p[7]; 
data[3468] = -p[8]; 
data[3472] = 1.0*p[7]; 
data[3536] = -p[10]; 
data[3540] = 1.0*p[9]; 
data[3600] = -1.0*p[7]; 
data[3604] = -1.0*p[8]; 
data[3668] = -1.0*p[7]; 
data[3672] = -1.0*p[8]; 
data[3736] = -1.0*p[7]; 
data[3740] = -1.0*p[8]; 
data[3804] = -1.0*p[9]; 
data[3808] = -1.0*p[10]; 
data[3876] = -p[13]; 
data[3880] = 1.0*p[14]; 
data[3944] = -p[13]; 
data[3948] = 1.0*p[14]; 
data[4012] = -p[13]; 
data[4016] = 1.0*p[14]; 
data[4080] = -p[13]; 
data[4084] = 1.0*p[14]; 
data[4144] = -1.0*p[14]; 
data[4148] = -1.0*p[13]; 
data[4212] = -1.0*p[14]; 
data[4216] = -1.0*p[13]; 
data[4280] = -1.0*p[14]; 
data[4284] = -1.0*p[13]; 
data[4348] = -1.0*p[14]; 
data[4352] = -1.0*p[13]; 
data[4422] = p[16]; 
data[4487] = -p[15]; 

}

void de_jac_run_xy_eval(double *data,double *x,double *y,double *u,double *p,double Dt){

data[2220] = p[0]*(2*y[8]*u[2] - 2*y[14]*u[2] + y[32]*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999)
)
: (
   1.0
)) + (y[9]*y[33] + y[8]*y[32] - y[15]*y[33] - y[14]*y[32])*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   -1.0*y[8]*pow(pow(y[9], 2) + pow(y[8], 2), -0.5)/pow(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999, 2)
)
: (
   0
))); 
data[2221] = p[0]*(2*y[9]*u[2] - 2*y[15]*u[2] + y[33]*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999)
)
: (
   1.0
)) + (y[9]*y[33] + y[8]*y[32] - y[15]*y[33] - y[14]*y[32])*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   -1.0*y[9]*pow(pow(y[9], 2) + pow(y[8], 2), -0.5)/pow(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999, 2)
)
: (
   0
))); 
data[2226] = p[0]*(-2*y[8]*u[2] + 2*y[14]*u[2] - y[32]*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[2227] = p[0]*(-2*y[9]*u[2] + 2*y[15]*u[2] - y[33]*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[2244] = p[0]*(y[8] - y[14])*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999)
)
: (
   1.0
)); 
data[2245] = p[0]*(y[9] - y[15])*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999)
)
: (
   1.0
)); 
data[2289] = p[0]*(2*y[10]*u[6] - 2*y[14]*u[6] + y[34]*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999)
)
: (
   1.0
)) + (y[11]*y[35] + y[10]*y[34] - y[15]*y[35] - y[14]*y[34])*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   -1.0*y[10]*pow(pow(y[11], 2) + pow(y[10], 2), -0.5)/pow(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999, 2)
)
: (
   0
))); 
data[2290] = p[0]*(2*y[11]*u[6] - 2*y[15]*u[6] + y[35]*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999)
)
: (
   1.0
)) + (y[11]*y[35] + y[10]*y[34] - y[15]*y[35] - y[14]*y[34])*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   -1.0*y[11]*pow(pow(y[11], 2) + pow(y[10], 2), -0.5)/pow(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999, 2)
)
: (
   0
))); 
data[2293] = p[0]*(-2*y[10]*u[6] + 2*y[14]*u[6] - y[34]*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[2294] = p[0]*(-2*y[11]*u[6] + 2*y[15]*u[6] - y[35]*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[2313] = p[0]*(y[10] - y[14])*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999)
)
: (
   1.0
)); 
data[2314] = p[0]*(y[11] - y[15])*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999)
)
: (
   1.0
)); 
data[2358] = p[0]*(2*y[12]*u[10] - 2*y[14]*u[10] + y[36]*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999)
)
: (
   1.0
)) + (y[13]*y[37] + y[12]*y[36] - y[15]*y[37] - y[14]*y[36])*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   -1.0*y[12]*pow(pow(y[13], 2) + pow(y[12], 2), -0.5)/pow(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999, 2)
)
: (
   0
))); 
data[2359] = p[0]*(2*y[13]*u[10] - 2*y[15]*u[10] + y[37]*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999)
)
: (
   1.0
)) + (y[13]*y[37] + y[12]*y[36] - y[15]*y[37] - y[14]*y[36])*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   -1.0*y[13]*pow(pow(y[13], 2) + pow(y[12], 2), -0.5)/pow(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999, 2)
)
: (
   0
))); 
data[2360] = p[0]*(-2*y[12]*u[10] + 2*y[14]*u[10] - y[36]*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[2361] = p[0]*(-2*y[13]*u[10] + 2*y[15]*u[10] - y[37]*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[2382] = p[0]*(y[12] - y[14])*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999)
)
: (
   1.0
)); 
data[2383] = p[0]*(y[13] - y[15])*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999)
)
: (
   1.0
)); 
data[2421] = p[0]*(-2.0*y[8]*u[3] + 2.0*y[14]*u[3] - y[33]*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999)
)
: (
   1.0
)) + (y[9]*y[32] - y[8]*y[33] - y[15]*y[32] + y[14]*y[33])*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   -1.0*y[8]*pow(pow(y[9], 2) + pow(y[8], 2), -0.5)/pow(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999, 2)
)
: (
   0
))); 
data[2422] = p[0]*(-2.0*y[9]*u[3] + 2.0*y[15]*u[3] + y[32]*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999)
)
: (
   1.0
)) + (y[9]*y[32] - y[8]*y[33] - y[15]*y[32] + y[14]*y[33])*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   -1.0*y[9]*pow(pow(y[9], 2) + pow(y[8], 2), -0.5)/pow(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999, 2)
)
: (
   0
))); 
data[2427] = p[0]*(2.0*y[8]*u[3] - 2.0*y[14]*u[3] + y[33]*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[2428] = p[0]*(2.0*y[9]*u[3] - 2.0*y[15]*u[3] - y[32]*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[2445] = p[0]*(y[9] - y[15])*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999)
)
: (
   1.0
)); 
data[2446] = p[0]*(-y[8] + y[14])*((sqrt(pow(y[9], 2) + pow(y[8], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[9], 2) + pow(y[8], 2)) + 0.29999999999999999)
)
: (
   1.0
)); 
data[2490] = p[0]*(-2.0*y[10]*u[7] + 2.0*y[14]*u[7] - y[35]*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999)
)
: (
   1.0
)) + (y[11]*y[34] - y[10]*y[35] - y[15]*y[34] + y[14]*y[35])*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   -1.0*y[10]*pow(pow(y[11], 2) + pow(y[10], 2), -0.5)/pow(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999, 2)
)
: (
   0
))); 
data[2491] = p[0]*(-2.0*y[11]*u[7] + 2.0*y[15]*u[7] + y[34]*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999)
)
: (
   1.0
)) + (y[11]*y[34] - y[10]*y[35] - y[15]*y[34] + y[14]*y[35])*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   -1.0*y[11]*pow(pow(y[11], 2) + pow(y[10], 2), -0.5)/pow(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999, 2)
)
: (
   0
))); 
data[2494] = p[0]*(2.0*y[10]*u[7] - 2.0*y[14]*u[7] + y[35]*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[2495] = p[0]*(2.0*y[11]*u[7] - 2.0*y[15]*u[7] - y[34]*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[2514] = p[0]*(y[11] - y[15])*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999)
)
: (
   1.0
)); 
data[2515] = p[0]*(-y[10] + y[14])*((sqrt(pow(y[11], 2) + pow(y[10], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[11], 2) + pow(y[10], 2)) + 0.29999999999999999)
)
: (
   1.0
)); 
data[2559] = p[0]*(-2.0*y[12]*u[11] + 2.0*y[14]*u[11] - y[37]*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999)
)
: (
   1.0
)) + (y[13]*y[36] - y[12]*y[37] - y[15]*y[36] + y[14]*y[37])*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   -1.0*y[12]*pow(pow(y[13], 2) + pow(y[12], 2), -0.5)/pow(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999, 2)
)
: (
   0
))); 
data[2560] = p[0]*(-2.0*y[13]*u[11] + 2.0*y[15]*u[11] + y[36]*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999)
)
: (
   1.0
)) + (y[13]*y[36] - y[12]*y[37] - y[15]*y[36] + y[14]*y[37])*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   -1.0*y[13]*pow(pow(y[13], 2) + pow(y[12], 2), -0.5)/pow(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999, 2)
)
: (
   0
))); 
data[2561] = p[0]*(2.0*y[12]*u[11] - 2.0*y[14]*u[11] + y[37]*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[2562] = p[0]*(2.0*y[13]*u[11] - 2.0*y[15]*u[11] - y[36]*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999)
)
: (
   1.0
))); 
data[2583] = p[0]*(y[13] - y[15])*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999)
)
: (
   1.0
)); 
data[2584] = p[0]*(-y[12] + y[14])*((sqrt(pow(y[13], 2) + pow(y[12], 2)) < 0.69999999999999996) ? (
   1.0/(sqrt(pow(y[13], 2) + pow(y[12], 2)) + 0.29999999999999999)
)
: (
   1.0
)); 

}

void de_jac_run_num_eval(double *data,double *x,double *y,double *u,double *p,double Dt){

data[65] = -1; 
data[68] = 184.75059629806532; 
data[69] = 94.615102344455565; 
data[70] = -69.368640085185334; 
data[71] = -17.974903844364775; 
data[72] = -43.675799641021136; 
data[73] = -40.74868784166955; 
data[74] = -69.368640085185348; 
data[75] = -17.974903844364817; 
data[76] = -184.75059629806532; 
data[77] = -94.615102344455565; 
data[78] = 69.368640085185334; 
data[79] = 17.974903844364775; 
data[80] = 43.675799641021136; 
data[81] = 40.74868784166955; 
data[82] = 69.368640085185348; 
data[83] = 17.974903844364817; 
data[108] = -1; 
data[135] = -94.615102344455565; 
data[136] = 184.75059629806532; 
data[137] = 17.974903844364775; 
data[138] = -69.368640085185334; 
data[139] = 40.74868784166955; 
data[140] = -43.675799641021136; 
data[141] = 17.974903844364817; 
data[142] = -69.368640085185348; 
data[143] = 94.615102344455565; 
data[144] = -184.75059629806532; 
data[145] = -17.974903844364775; 
data[146] = 69.368640085185334; 
data[147] = -40.74868784166955; 
data[148] = 43.675799641021136; 
data[149] = -17.974903844364817; 
data[150] = 69.368640085185348; 
data[179] = -1; 
data[202] = -69.368640085185319; 
data[203] = -17.974903844364796; 
data[204] = 184.75059629806523; 
data[205] = 94.615102344455607; 
data[206] = -69.368640085185291; 
data[207] = -17.974903844364814; 
data[208] = -43.675799641021079; 
data[209] = -40.748687841669586; 
data[210] = 69.368640085185319; 
data[211] = 17.974903844364796; 
data[212] = -184.75059629806523; 
data[213] = -94.615102344455607; 
data[214] = 69.368640085185291; 
data[215] = 17.974903844364814; 
data[216] = 43.675799641021079; 
data[217] = 40.748687841669586; 
data[243] = -1; 
data[269] = 17.974903844364796; 
data[270] = -69.368640085185319; 
data[271] = -94.615102344455607; 
data[272] = 184.75059629806523; 
data[273] = 17.974903844364814; 
data[274] = -69.368640085185291; 
data[275] = 40.748687841669586; 
data[276] = -43.675799641021079; 
data[277] = -17.974903844364796; 
data[278] = 69.368640085185319; 
data[279] = 94.615102344455607; 
data[280] = -184.75059629806523; 
data[281] = -17.974903844364814; 
data[282] = 69.368640085185291; 
data[283] = -40.748687841669586; 
data[284] = 43.675799641021079; 
data[314] = -1; 
data[336] = -43.675799641021122; 
data[337] = -40.748687841669557; 
data[338] = -69.368640085185277; 
data[339] = -17.97490384436481; 
data[340] = 184.75059629806526; 
data[341] = 94.615102344455636; 
data[342] = -69.368640085185277; 
data[343] = -17.974903844364817; 
data[344] = 43.675799641021122; 
data[345] = 40.748687841669557; 
data[346] = 69.368640085185277; 
data[347] = 17.97490384436481; 
data[348] = -184.75059629806526; 
data[349] = -94.615102344455636; 
data[350] = 69.368640085185277; 
data[351] = 17.974903844364817; 
data[378] = -1; 
data[403] = 40.748687841669557; 
data[404] = -43.675799641021122; 
data[405] = 17.97490384436481; 
data[406] = -69.368640085185277; 
data[407] = -94.615102344455636; 
data[408] = 184.75059629806526; 
data[409] = 17.974903844364817; 
data[410] = -69.368640085185277; 
data[411] = -40.748687841669557; 
data[412] = 43.675799641021122; 
data[413] = -17.97490384436481; 
data[414] = 69.368640085185277; 
data[415] = 94.615102344455636; 
data[416] = -184.75059629806526; 
data[417] = -17.974903844364817; 
data[418] = 69.368640085185277; 
data[449] = -1; 
data[470] = -69.368640085185334; 
data[471] = -17.9749038443648; 
data[472] = -43.675799641021086; 
data[473] = -40.748687841669586; 
data[474] = -69.368640085185291; 
data[475] = -17.974903844364821; 
data[476] = 184.75059629806523; 
data[477] = 94.61510234445565; 
data[478] = 69.368640085185334; 
data[479] = 17.9749038443648; 
data[480] = 43.675799641021086; 
data[481] = 40.748687841669586; 
data[482] = 69.368640085185291; 
data[483] = 17.974903844364821; 
data[484] = -184.75059629806523; 
data[485] = -94.61510234445565; 
data[513] = -1; 
data[537] = 17.9749038443648; 
data[538] = -69.368640085185334; 
data[539] = 40.748687841669586; 
data[540] = -43.675799641021086; 
data[541] = 17.974903844364821; 
data[542] = -69.368640085185291; 
data[543] = -94.61510234445565; 
data[544] = 184.75059629806523; 
data[545] = -17.9749038443648; 
data[546] = 69.368640085185334; 
data[547] = -40.748687841669586; 
data[548] = 43.675799641021086; 
data[549] = -17.974903844364821; 
data[550] = 69.368640085185291; 
data[551] = 94.61510234445565; 
data[552] = -184.75059629806523; 
data[584] = -1; 
data[604] = -184.75059629806532; 
data[605] = -94.615102344455565; 
data[606] = 69.368640085185334; 
data[607] = 17.974903844364775; 
data[608] = 43.675799641021136; 
data[609] = 40.74868784166955; 
data[610] = 69.368640085185348; 
data[611] = 17.974903844364817; 
data[612] = 184.75059629806532; 
data[613] = 94.615102344455565; 
data[614] = -69.368640085185334; 
data[615] = -17.974903844364775; 
data[616] = -43.675799641021136; 
data[617] = -40.74868784166955; 
data[618] = -69.368640085185348; 
data[619] = -17.974903844364817; 
data[636] = -1; 
data[671] = 94.615102344455565; 
data[672] = -184.75059629806532; 
data[673] = -17.974903844364775; 
data[674] = 69.368640085185334; 
data[675] = -40.74868784166955; 
data[676] = 43.675799641021136; 
data[677] = -17.974903844364817; 
data[678] = 69.368640085185348; 
data[679] = -94.615102344455565; 
data[680] = 184.75059629806532; 
data[681] = 17.974903844364775; 
data[682] = -69.368640085185334; 
data[683] = 40.74868784166955; 
data[684] = -43.675799641021136; 
data[685] = 17.974903844364817; 
data[686] = -69.368640085185348; 
data[704] = -1; 
data[738] = 69.368640085185319; 
data[739] = 17.974903844364796; 
data[740] = -184.75059629806523; 
data[741] = -94.615102344455607; 
data[742] = 69.368640085185291; 
data[743] = 17.974903844364814; 
data[744] = 43.675799641021079; 
data[745] = 40.748687841669586; 
data[746] = -69.368640085185319; 
data[747] = -17.974903844364796; 
data[748] = 184.75059629806523; 
data[749] = 94.615102344455607; 
data[750] = -69.368640085185291; 
data[751] = -17.974903844364814; 
data[752] = -43.675799641021079; 
data[753] = -40.748687841669586; 
data[772] = -1; 
data[805] = -17.974903844364796; 
data[806] = 69.368640085185319; 
data[807] = 94.615102344455607; 
data[808] = -184.75059629806523; 
data[809] = -17.974903844364814; 
data[810] = 69.368640085185291; 
data[811] = -40.748687841669586; 
data[812] = 43.675799641021079; 
data[813] = 17.974903844364796; 
data[814] = -69.368640085185319; 
data[815] = -94.615102344455607; 
data[816] = 184.75059629806523; 
data[817] = 17.974903844364814; 
data[818] = -69.368640085185291; 
data[819] = 40.748687841669586; 
data[820] = -43.675799641021079; 
data[840] = -1; 
data[872] = 43.675799641021122; 
data[873] = 40.748687841669557; 
data[874] = 69.368640085185277; 
data[875] = 17.97490384436481; 
data[876] = -184.75059629806526; 
data[877] = -94.615102344455636; 
data[878] = 69.368640085185277; 
data[879] = 17.974903844364817; 
data[880] = -43.675799641021122; 
data[881] = -40.748687841669557; 
data[882] = -69.368640085185277; 
data[883] = -17.97490384436481; 
data[884] = 184.75059629806526; 
data[885] = 94.615102344455636; 
data[886] = -69.368640085185277; 
data[887] = -17.974903844364817; 
data[908] = -1; 
data[939] = -40.748687841669557; 
data[940] = 43.675799641021122; 
data[941] = -17.97490384436481; 
data[942] = 69.368640085185277; 
data[943] = 94.615102344455636; 
data[944] = -184.75059629806526; 
data[945] = -17.974903844364817; 
data[946] = 69.368640085185277; 
data[947] = 40.748687841669557; 
data[948] = -43.675799641021122; 
data[949] = 17.97490384436481; 
data[950] = -69.368640085185277; 
data[951] = -94.615102344455636; 
data[952] = 184.75059629806526; 
data[953] = 17.974903844364817; 
data[954] = -69.368640085185277; 
data[976] = -1; 
data[1006] = 69.368640085185334; 
data[1007] = 17.9749038443648; 
data[1008] = 43.675799641021086; 
data[1009] = 40.748687841669586; 
data[1010] = 69.368640085185291; 
data[1011] = 17.974903844364821; 
data[1012] = -184.75059629806523; 
data[1013] = -94.61510234445565; 
data[1014] = -69.368640085185334; 
data[1015] = -17.9749038443648; 
data[1016] = -43.675799641021086; 
data[1017] = -40.748687841669586; 
data[1018] = -69.368640085185291; 
data[1019] = -17.974903844364821; 
data[1020] = 184.75059629806523; 
data[1021] = 94.61510234445565; 
data[1044] = -1; 
data[1073] = -17.9749038443648; 
data[1074] = 69.368640085185334; 
data[1075] = -40.748687841669586; 
data[1076] = 43.675799641021086; 
data[1077] = -17.974903844364821; 
data[1078] = 69.368640085185291; 
data[1079] = 94.61510234445565; 
data[1080] = -184.75059629806523; 
data[1081] = 17.9749038443648; 
data[1082] = -69.368640085185334; 
data[1083] = 40.748687841669586; 
data[1084] = -43.675799641021086; 
data[1085] = 17.974903844364821; 
data[1086] = -69.368640085185291; 
data[1087] = -94.61510234445565; 
data[1088] = 184.75059629806523; 
data[1112] = -1; 
data[1156] = 184.75059629806532; 
data[1157] = 94.615102344455565; 
data[1158] = -69.368640085185334; 
data[1159] = -17.974903844364775; 
data[1160] = -43.675799641021136; 
data[1161] = -40.74868784166955; 
data[1162] = -69.368640085185348; 
data[1163] = -17.974903844364817; 
data[1164] = -184.75059629806532; 
data[1165] = -94.615102344455565; 
data[1166] = 69.368640085185334; 
data[1167] = 17.974903844364775; 
data[1168] = 43.675799641021136; 
data[1169] = 40.74868784166955; 
data[1170] = 69.368640085185348; 
data[1171] = 17.974903844364817; 
data[1223] = -94.615102344455565; 
data[1224] = 184.75059629806532; 
data[1225] = 17.974903844364775; 
data[1226] = -69.368640085185334; 
data[1227] = 40.74868784166955; 
data[1228] = -43.675799641021136; 
data[1229] = 17.974903844364817; 
data[1230] = -69.368640085185348; 
data[1231] = 94.615102344455565; 
data[1232] = -184.75059629806532; 
data[1233] = -17.974903844364775; 
data[1234] = 69.368640085185334; 
data[1235] = -40.74868784166955; 
data[1236] = 43.675799641021136; 
data[1237] = -17.974903844364817; 
data[1238] = 69.368640085185348; 
data[1290] = -69.368640085185319; 
data[1291] = -17.974903844364796; 
data[1292] = 184.75059629806523; 
data[1293] = 94.615102344455607; 
data[1294] = -69.368640085185291; 
data[1295] = -17.974903844364814; 
data[1296] = -43.675799641021079; 
data[1297] = -40.748687841669586; 
data[1298] = 69.368640085185319; 
data[1299] = 17.974903844364796; 
data[1300] = -184.75059629806523; 
data[1301] = -94.615102344455607; 
data[1302] = 69.368640085185291; 
data[1303] = 17.974903844364814; 
data[1304] = 43.675799641021079; 
data[1305] = 40.748687841669586; 
data[1357] = 17.974903844364796; 
data[1358] = -69.368640085185319; 
data[1359] = -94.615102344455607; 
data[1360] = 184.75059629806523; 
data[1361] = 17.974903844364814; 
data[1362] = -69.368640085185291; 
data[1363] = 40.748687841669586; 
data[1364] = -43.675799641021079; 
data[1365] = -17.974903844364796; 
data[1366] = 69.368640085185319; 
data[1367] = 94.615102344455607; 
data[1368] = -184.75059629806523; 
data[1369] = -17.974903844364814; 
data[1370] = 69.368640085185291; 
data[1371] = -40.748687841669586; 
data[1372] = 43.675799641021079; 
data[1424] = -43.675799641021122; 
data[1425] = -40.748687841669557; 
data[1426] = -69.368640085185277; 
data[1427] = -17.97490384436481; 
data[1428] = 184.75059629806526; 
data[1429] = 94.615102344455636; 
data[1430] = -69.368640085185277; 
data[1431] = -17.974903844364817; 
data[1432] = 43.675799641021122; 
data[1433] = 40.748687841669557; 
data[1434] = 69.368640085185277; 
data[1435] = 17.97490384436481; 
data[1436] = -184.75059629806526; 
data[1437] = -94.615102344455636; 
data[1438] = 69.368640085185277; 
data[1439] = 17.974903844364817; 
data[1491] = 40.748687841669557; 
data[1492] = -43.675799641021122; 
data[1493] = 17.97490384436481; 
data[1494] = -69.368640085185277; 
data[1495] = -94.615102344455636; 
data[1496] = 184.75059629806526; 
data[1497] = 17.974903844364817; 
data[1498] = -69.368640085185277; 
data[1499] = -40.748687841669557; 
data[1500] = 43.675799641021122; 
data[1501] = -17.97490384436481; 
data[1502] = 69.368640085185277; 
data[1503] = 94.615102344455636; 
data[1504] = -184.75059629806526; 
data[1505] = -17.974903844364817; 
data[1506] = 69.368640085185277; 
data[1558] = -69.368640085185334; 
data[1559] = -17.9749038443648; 
data[1560] = -43.675799641021086; 
data[1561] = -40.748687841669586; 
data[1562] = -69.368640085185291; 
data[1563] = -17.974903844364821; 
data[1564] = 184.75059629806523; 
data[1565] = 94.61510234445565; 
data[1566] = 69.368640085185334; 
data[1567] = 17.9749038443648; 
data[1568] = 43.675799641021086; 
data[1569] = 40.748687841669586; 
data[1570] = 69.368640085185291; 
data[1571] = 17.974903844364821; 
data[1572] = -184.75059629806523; 
data[1573] = -94.61510234445565; 
data[1625] = 17.9749038443648; 
data[1626] = -69.368640085185334; 
data[1627] = 40.748687841669586; 
data[1628] = -43.675799641021086; 
data[1629] = 17.974903844364821; 
data[1630] = -69.368640085185291; 
data[1631] = -94.61510234445565; 
data[1632] = 184.75059629806523; 
data[1633] = -17.9749038443648; 
data[1634] = 69.368640085185334; 
data[1635] = -40.748687841669586; 
data[1636] = 43.675799641021086; 
data[1637] = -17.974903844364821; 
data[1638] = 69.368640085185291; 
data[1639] = 94.61510234445565; 
data[1640] = -184.75059629806523; 
data[1692] = -184.75059629806532; 
data[1693] = -94.615102344455565; 
data[1694] = 69.368640085185334; 
data[1695] = 17.974903844364775; 
data[1696] = 43.675799641021136; 
data[1697] = 40.74868784166955; 
data[1698] = 69.368640085185348; 
data[1699] = 17.974903844364817; 
data[1700] = 184.75059629806532; 
data[1701] = 94.615102344455565; 
data[1702] = -69.368640085185334; 
data[1703] = -17.974903844364775; 
data[1704] = -43.675799641021136; 
data[1705] = -40.74868784166955; 
data[1706] = -69.368640085185348; 
data[1707] = -17.974903844364817; 
data[1724] = -1; 
data[1759] = 94.615102344455565; 
data[1760] = -184.75059629806532; 
data[1761] = -17.974903844364775; 
data[1762] = 69.368640085185334; 
data[1763] = -40.74868784166955; 
data[1764] = 43.675799641021136; 
data[1765] = -17.974903844364817; 
data[1766] = 69.368640085185348; 
data[1767] = -94.615102344455565; 
data[1768] = 184.75059629806532; 
data[1769] = 17.974903844364775; 
data[1770] = -69.368640085185334; 
data[1771] = 40.74868784166955; 
data[1772] = -43.675799641021136; 
data[1773] = 17.974903844364817; 
data[1774] = -69.368640085185348; 
data[1795] = -1; 
data[1826] = 69.368640085185319; 
data[1827] = 17.974903844364796; 
data[1828] = -184.75059629806523; 
data[1829] = -94.615102344455607; 
data[1830] = 69.368640085185291; 
data[1831] = 17.974903844364814; 
data[1832] = 43.675799641021079; 
data[1833] = 40.748687841669586; 
data[1834] = -69.368640085185319; 
data[1835] = -17.974903844364796; 
data[1836] = 184.75059629806523; 
data[1837] = 94.615102344455607; 
data[1838] = -69.368640085185291; 
data[1839] = -17.974903844364814; 
data[1840] = -43.675799641021079; 
data[1841] = -40.748687841669586; 
data[1859] = -1; 
data[1893] = -17.974903844364796; 
data[1894] = 69.368640085185319; 
data[1895] = 94.615102344455607; 
data[1896] = -184.75059629806523; 
data[1897] = -17.974903844364814; 
data[1898] = 69.368640085185291; 
data[1899] = -40.748687841669586; 
data[1900] = 43.675799641021079; 
data[1901] = 17.974903844364796; 
data[1902] = -69.368640085185319; 
data[1903] = -94.615102344455607; 
data[1904] = 184.75059629806523; 
data[1905] = 17.974903844364814; 
data[1906] = -69.368640085185291; 
data[1907] = 40.748687841669586; 
data[1908] = -43.675799641021079; 
data[1930] = -1; 
data[1960] = 43.675799641021122; 
data[1961] = 40.748687841669557; 
data[1962] = 69.368640085185277; 
data[1963] = 17.97490384436481; 
data[1964] = -184.75059629806526; 
data[1965] = -94.615102344455636; 
data[1966] = 69.368640085185277; 
data[1967] = 17.974903844364817; 
data[1968] = -43.675799641021122; 
data[1969] = -40.748687841669557; 
data[1970] = -69.368640085185277; 
data[1971] = -17.97490384436481; 
data[1972] = 184.75059629806526; 
data[1973] = 94.615102344455636; 
data[1974] = -69.368640085185277; 
data[1975] = -17.974903844364817; 
data[1994] = -1; 
data[2027] = -40.748687841669557; 
data[2028] = 43.675799641021122; 
data[2029] = -17.97490384436481; 
data[2030] = 69.368640085185277; 
data[2031] = 94.615102344455636; 
data[2032] = -184.75059629806526; 
data[2033] = -17.974903844364817; 
data[2034] = 69.368640085185277; 
data[2035] = 40.748687841669557; 
data[2036] = -43.675799641021122; 
data[2037] = 17.97490384436481; 
data[2038] = -69.368640085185277; 
data[2039] = -94.615102344455636; 
data[2040] = 184.75059629806526; 
data[2041] = 17.974903844364817; 
data[2042] = -69.368640085185277; 
data[2065] = -1; 
data[2094] = 69.368640085185334; 
data[2095] = 17.9749038443648; 
data[2096] = 43.675799641021086; 
data[2097] = 40.748687841669586; 
data[2098] = 69.368640085185291; 
data[2099] = 17.974903844364821; 
data[2100] = -184.75059629806523; 
data[2101] = -94.61510234445565; 
data[2102] = -69.368640085185334; 
data[2103] = -17.9749038443648; 
data[2104] = -43.675799641021086; 
data[2105] = -40.748687841669586; 
data[2106] = -69.368640085185291; 
data[2107] = -17.974903844364821; 
data[2108] = 184.75059629806523; 
data[2109] = 94.61510234445565; 
data[2129] = -1; 
data[2161] = -17.9749038443648; 
data[2162] = 69.368640085185334; 
data[2163] = -40.748687841669586; 
data[2164] = 43.675799641021086; 
data[2165] = -17.974903844364821; 
data[2166] = 69.368640085185291; 
data[2167] = 94.61510234445565; 
data[2168] = -184.75059629806523; 
data[2169] = 17.9749038443648; 
data[2170] = -69.368640085185334; 
data[2171] = 40.748687841669586; 
data[2172] = -43.675799641021086; 
data[2173] = 17.974903844364821; 
data[2174] = -69.368640085185291; 
data[2175] = -94.61510234445565; 
data[2176] = 184.75059629806523; 
data[2200] = -1; 
data[2646] = 1; 
data[2648] = 1; 
data[2650] = 1; 
data[2652] = 1; 
data[2714] = 1; 
data[2716] = 1; 
data[2718] = 1; 
data[2720] = 1; 
data[2748] = -1; 
data[2817] = -1; 
data[2886] = -1; 
data[2955] = -1; 
data[3017] = -1.0; 
data[3086] = -1.0; 
data[3155] = -1.0; 
data[3224] = -1.0; 
data[3308] = -1; 
data[3377] = -1; 
data[3446] = -1; 
data[3515] = -1; 
data[3577] = -1.0; 
data[3646] = -1.0; 
data[3715] = -1.0; 
data[3784] = -1.0; 
data[3828] = 1; 
data[3836] = -1; 
data[3897] = 1; 
data[3905] = -1; 
data[3966] = 1; 
data[3974] = -1; 
data[4035] = 1; 
data[4043] = -1; 
data[4097] = 1.0; 
data[4105] = -1.0; 
data[4166] = 1.0; 
data[4174] = -1.0; 
data[4235] = 1.0; 
data[4243] = -1.0; 
data[4304] = 1.0; 
data[4312] = -1.0; 
data[4420] = -1; 
data[4488] = -1; 

}



/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // void()(double *, double *, double *, double *, double *, double)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 6), // double *
/*  2 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  3 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  4 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  5 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  6 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14), // double
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  8 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static void _cffi_d_de_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_num_eval _cffi_d_de_jac_run_num_eval
#endif

static void _cffi_d_de_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_up_eval _cffi_d_de_jac_run_up_eval
#endif

static void _cffi_d_de_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_xy_eval _cffi_d_de_jac_run_xy_eval
#endif

static void _cffi_d_f_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_run_eval _cffi_d_f_run_eval
#endif

static void _cffi_d_g_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_run_eval _cffi_d_g_run_eval
#endif

static void _cffi_d_h_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  h_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_h_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "h_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { h_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_h_eval _cffi_d_h_eval
#endif

static const struct _cffi_global_s _cffi_globals[] = {
  { "de_jac_run_num_eval", (void *)_cffi_f_de_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_num_eval },
  { "de_jac_run_up_eval", (void *)_cffi_f_de_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_up_eval },
  { "de_jac_run_xy_eval", (void *)_cffi_f_de_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_xy_eval },
  { "f_run_eval", (void *)_cffi_f_f_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_run_eval },
  { "g_run_eval", (void *)_cffi_f_g_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_run_eval },
  { "h_eval", (void *)_cffi_f_h_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_h_eval },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  NULL,  /* no fields */
  NULL,  /* no struct_unions */
  NULL,  /* no enums */
  NULL,  /* no typenames */
  6,  /* num_globals */
  0,  /* num_struct_unions */
  0,  /* num_enums */
  0,  /* num_typenames */
  NULL,  /* no includes */
  9,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit_temp_run_cffi(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit_temp_run_cffi(void) { return NULL; }
#  else
     inittemp_run_cffi(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit_temp_run_cffi(void)
{
  return _cffi_init("temp_run_cffi", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
inittemp_run_cffi(void)
{
  _cffi_init("temp_run_cffi", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
