#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/

void f_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 6.2831853071795862*p[7]*(y[4] - y[25]) - p[10]*(x[0] - u[7]);
out[1] = -x[1]*p[11] + u[4];
out[2] = -x[2]*p[12] + u[9];
out[3] = (-x[3] + ((u[10] < 0) ? (
   p[14]*pow(x[7], 3) + p[25]*(pow(y[12], 2) + pow(y[13], 2)) + u[10]
)
: (
   p[14]*pow(x[7], 3) + p[25]*(pow(y[12], 2) + pow(y[13], 2))
)))*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0.0
)
: (
   1.0
))/p[50];
out[4] = -1.0e-8*x[4] + ((p[15] - x[8] > 0) ? (
   0.0
)
: (
   -p[15] + x[8]
));
out[5] = 1.0*(p[18]*x[4] + p[17]*((p[15] - x[8] > 0) ? (
   0.0
)
: (
   -p[15] + x[8]
)) - x[5] + u[11])/p[16];
out[6] = -x[8] + x[7] - u[18];
out[7] = 0.5*(-p[22]*(-x[8] + x[7]) - p[21]*x[6] + ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0.0
)
: (
   p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
)))/(p[19]*x[7]);
out[8] = 0.5*(p[22]*(-x[8] + x[7]) + p[21]*x[6] - x[8]*y[14])/(p[20]*x[8]);
out[9] = 314.15926535897933*p[31]*x[10] + 314.15926535897933*p[30]*(y[0]*sin(y[1])*cos(x[9]) - y[0]*sin(x[9])*cos(y[1])) - 314.15926535897933*y[25] + 314.15926535897933;
out[10] = y[0]*sin(y[1])*cos(x[9]) - y[0]*sin(x[9])*cos(y[1]);
out[11] = (p[31]*x[10] + p[30]*(y[0]*sin(y[1])*cos(x[9]) - y[0]*sin(x[9])*cos(y[1])) - x[11] + 1.0)/p[32];
out[12] = (0.5*(y[12]*y[10] + y[13]*y[11])/(x[12] + 9.9999999999999995e-7) - 0.5*(y[21]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[22]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/(x[12] + 9.9999999999999995e-7))/p[35];
out[13] = -p[53]*x[13] - y[25] + 1;

}
void g_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -u[0]/p[0] + pow(y[0], 2)*p[1] + y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) - p[13]*y[23]/p[0];
out[1] = -u[1]/p[0] + pow(y[0], 2)*(-p[2] - 1.0/2.0*p[3]) + y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3])) - p[13]*y[24]/p[0];
out[2] = -u[2]/p[0] + y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + pow(y[2], 2)*p[1] - p[6]*y[7]/p[0];
out[3] = -u[3]/p[0] + y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + pow(y[2], 2)*(-p[2] - 1.0/2.0*p[3]) - p[6]*y[8]/p[0];
out[4] = x[1] - y[4] + u[6];
out[5] = -p[9]*y[5] - y[2]*sin(x[0] + u[8] - y[3]) + p[8]*y[6];
out[6] = x[2] - p[9]*y[6] - y[2]*cos(x[0] + u[8] - y[3]) - p[8]*y[5] + u[5];
out[7] = y[2]*y[5]*sin(x[0] + u[8] - y[3]) + y[2]*y[6]*cos(x[0] + u[8] - y[3]) - y[7];
out[8] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]) - y[8];
out[9] = -p[23]*(1.0 - x[11]) + p[24]*y[20] + p[27]*y[9]*x[8] - u[13] - x[3];
out[10] = -p[26]*y[9]*x[8] - p[25]*u[12] - y[10];
out[11] = p[26]*u[12]*x[8] + p[27]*x[8] - p[25]*y[9] - y[11];
out[12] = -p[26]*y[13]*x[8] - p[25]*y[12] - y[10];
out[13] = p[26]*y[12]*x[8] + p[27]*x[8] - p[25]*y[13] - y[11];
out[14] = p[27]*y[13] - y[14];
out[15] = p[29]*(y[12]*y[10] + y[13]*y[11]) - p[28]*(-x[12] + u[14]) - y[15];
out[16] = y[17]*(y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2)) - y[15];
out[17] = -y[16]*(y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2)) - u[15];
out[18] = -p[33]*y[16] - p[34]*y[17] + y[18];
out[19] = -p[33]*y[17] - y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2) + p[34]*y[16] + y[19];
out[20] = y[20] - (p[31]*x[10] + p[30]*(y[0]*sin(y[1])*cos(x[9]) - y[0]*sin(x[9])*cos(y[1])) - x[11] + 1.0)/p[32];
out[21] = -p[33]*y[21] - y[0]*sin(y[1]) - p[34]*y[22] + y[18]*cos(y[1]) + y[19]*sin(y[1]);
out[22] = -p[33]*y[22] - y[0]*cos(y[1]) + p[34]*y[21] - y[18]*sin(y[1]) + y[19]*cos(y[1]);
out[23] = y[0]*y[21]*sin(y[1]) + y[0]*y[22]*cos(y[1]) - y[23];
out[24] = -y[0]*y[21]*cos(y[1]) + y[0]*y[22]*sin(y[1]) - y[24];
out[25] = 1.0*y[4] - y[25];
out[26] = p[52]*x[13] + p[51]*(1 - y[25]) - y[26];

}
void f_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 6.2831853071795862*p[7]*(y[4] - y[25]) - p[10]*(x[0] - u[7]);
out[1] = -x[1]*p[11] + u[4];
out[2] = -x[2]*p[12] + u[9];
out[3] = (-x[3] + ((u[10] < 0) ? (
   p[14]*pow(x[7], 3) + p[25]*(pow(y[12], 2) + pow(y[13], 2)) + u[10]
)
: (
   p[14]*pow(x[7], 3) + p[25]*(pow(y[12], 2) + pow(y[13], 2))
)))*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0.0
)
: (
   1.0
))/p[50];
out[4] = -1.0e-8*x[4] + ((p[15] - x[8] > 0) ? (
   0.0
)
: (
   -p[15] + x[8]
));
out[5] = 1.0*(p[18]*x[4] + p[17]*((p[15] - x[8] > 0) ? (
   0.0
)
: (
   -p[15] + x[8]
)) - x[5] + u[11])/p[16];
out[6] = -x[8] + x[7] - u[18];
out[7] = 0.5*(-p[22]*(-x[8] + x[7]) - p[21]*x[6] + ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0.0
)
: (
   p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
)))/(p[19]*x[7]);
out[8] = 0.5*(p[22]*(-x[8] + x[7]) + p[21]*x[6] - x[8]*y[14])/(p[20]*x[8]);
out[9] = 314.15926535897933*p[31]*x[10] + 314.15926535897933*p[30]*(y[0]*sin(y[1])*cos(x[9]) - y[0]*sin(x[9])*cos(y[1])) - 314.15926535897933*y[25] + 314.15926535897933;
out[10] = y[0]*sin(y[1])*cos(x[9]) - y[0]*sin(x[9])*cos(y[1]);
out[11] = (p[31]*x[10] + p[30]*(y[0]*sin(y[1])*cos(x[9]) - y[0]*sin(x[9])*cos(y[1])) - x[11] + 1.0)/p[32];
out[12] = (0.5*(y[12]*y[10] + y[13]*y[11])/(x[12] + 9.9999999999999995e-7) - 0.5*(y[21]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[22]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/(x[12] + 9.9999999999999995e-7))/p[35];
out[13] = -p[53]*x[13] - y[25] + 1;

}
void g_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -u[0]/p[0] + pow(y[0], 2)*p[1] + y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) - p[13]*y[23]/p[0];
out[1] = -u[1]/p[0] + pow(y[0], 2)*(-p[2] - 1.0/2.0*p[3]) + y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3])) - p[13]*y[24]/p[0];
out[2] = -u[2]/p[0] + y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + pow(y[2], 2)*p[1] - p[6]*y[7]/p[0];
out[3] = -u[3]/p[0] + y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + pow(y[2], 2)*(-p[2] - 1.0/2.0*p[3]) - p[6]*y[8]/p[0];
out[4] = x[1] - y[4] + u[6];
out[5] = -p[9]*y[5] - y[2]*sin(x[0] + u[8] - y[3]) + p[8]*y[6];
out[6] = x[2] - p[9]*y[6] - y[2]*cos(x[0] + u[8] - y[3]) - p[8]*y[5] + u[5];
out[7] = y[2]*y[5]*sin(x[0] + u[8] - y[3]) + y[2]*y[6]*cos(x[0] + u[8] - y[3]) - y[7];
out[8] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]) - y[8];
out[9] = -p[23]*(1.0 - x[11]) + p[24]*y[20] + p[27]*y[9]*x[8] - u[13] - x[3];
out[10] = -p[26]*y[9]*x[8] - p[25]*u[12] - y[10];
out[11] = p[26]*u[12]*x[8] + p[27]*x[8] - p[25]*y[9] - y[11];
out[12] = -p[26]*y[13]*x[8] - p[25]*y[12] - y[10];
out[13] = p[26]*y[12]*x[8] + p[27]*x[8] - p[25]*y[13] - y[11];
out[14] = p[27]*y[13] - y[14];
out[15] = p[29]*(y[12]*y[10] + y[13]*y[11]) - p[28]*(-x[12] + u[14]) - y[15];
out[16] = y[17]*(y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2)) - y[15];
out[17] = -y[16]*(y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2)) - u[15];
out[18] = -p[33]*y[16] - p[34]*y[17] + y[18];
out[19] = -p[33]*y[17] - y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2) + p[34]*y[16] + y[19];
out[20] = y[20] - (p[31]*x[10] + p[30]*(y[0]*sin(y[1])*cos(x[9]) - y[0]*sin(x[9])*cos(y[1])) - x[11] + 1.0)/p[32];
out[21] = -p[33]*y[21] - y[0]*sin(y[1]) - p[34]*y[22] + y[18]*cos(y[1]) + y[19]*sin(y[1]);
out[22] = -p[33]*y[22] - y[0]*cos(y[1]) + p[34]*y[21] - y[18]*sin(y[1]) + y[19]*cos(y[1]);
out[23] = y[0]*y[21]*sin(y[1]) + y[0]*y[22]*cos(y[1]) - y[23];
out[24] = -y[0]*y[21]*cos(y[1]) + y[0]*y[22]*sin(y[1]) - y[24];
out[25] = 1.0*y[4] - y[25];
out[26] = p[52]*x[13] + p[51]*(1 - y[25]) - y[26];

}
void h_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = y[0];
out[1] = y[2];
out[2] = u[4];
out[3] = x[2];
out[4] = u[17];
if (p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) {
   out[5] = 0.0;
}
else {
   out[5] = p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3));
}
out[6] = p[23]*(1.0 - x[11]);
out[7] = -p[24]*y[20];
out[8] = y[12]*y[10] + y[13]*y[11];
out[9] = -y[12]*y[11] + y[13]*y[10];
out[10] = p[31]*x[10] + p[30]*(y[0]*sin(y[1])*cos(x[9]) - y[0]*sin(x[9])*cos(y[1])) + 1.0;
out[11] = x[11];
out[12] = y[20];
out[13] = y[23];
out[14] = y[24];
out[15] = y[21];
out[16] = y[22];
out[17] = (y[21]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[22]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/x[12];
out[18] = (y[12]*y[10] + y[13]*y[11])/(x[12] + 9.9999999999999995e-7);

}
void de_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[126] = -((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[130] = 3.0*p[14]*pow(x[7], 2)*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[149] = 2.0*p[25]*y[12]*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[150] = 2.0*p[25]*y[13]*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[172] = ((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
));
out[213] = 1.0*p[17]*((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
))/p[16];
out[292] = 0.5*((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(-p[39]*p[43]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2))*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[39]*(p[40]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) - p[41])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))))/(p[49]*pow(p[45], 3))
))/(p[19]*x[7]);
out[293] = -0.5*p[21]/(p[19]*x[7]);
out[294] = 0.5*(-p[22] + ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(-p[39]*p[40]*p[46]*p[45]*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*u[17]*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) + p[39]*p[43]*p[46]*p[45]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*u[17]*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) + p[44]*p[46]*p[45]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
)))/(p[19]*x[7]) - 0.5*(-p[22]*(-x[8] + x[7]) - p[21]*x[6] + ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
)))/(p[19]*pow(x[7], 2));
out[295] = 0.5*p[22]/(p[19]*x[7]);
out[334] = 0.5*p[21]/(p[20]*x[8]);
out[335] = 0.5*p[22]/(p[20]*x[8]);
out[336] = 0.5*(-p[22] - y[14])/(p[20]*x[8]) - 0.5*(p[22]*(-x[8] + x[7]) + p[21]*x[6] - x[8]*y[14])/(p[20]*pow(x[8], 2));
out[378] = 314.15926535897933*p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]));
out[383] = 314.15926535897933*p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]));
out[384] = 314.15926535897933*p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]));
out[419] = -y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]);
out[424] = sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]);
out[425] = y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]);
out[460] = p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]))/p[32];
out[465] = p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]))/p[32];
out[466] = p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]))/p[32];
out[504] = (-0.5*(y[12]*y[10] + y[13]*y[11])/pow(x[12] + 9.9999999999999995e-7, 2) + 0.5*(y[21]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[22]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/pow(x[12] + 9.9999999999999995e-7, 2))/p[35];
out[507] = -0.5*(y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])) + y[22]*(-y[18]*cos(y[1]) - y[19]*sin(y[1])))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[516] = 0.5*y[12]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[517] = 0.5*y[13]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[518] = 0.5*y[10]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[519] = 0.5*y[11]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[524] = -0.5*(y[21]*cos(y[1]) - y[22]*sin(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[525] = -0.5*(y[21]*sin(y[1]) + y[22]*cos(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[527] = -0.5*(y[18]*cos(y[1]) + y[19]*sin(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[528] = -0.5*(-y[18]*sin(y[1]) + y[19]*cos(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[588] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[589] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[590] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[591] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[629] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[630] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[631] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[632] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[670] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[671] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[672] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[673] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[711] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[712] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[713] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[714] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[779] = -y[2]*cos(x[0] + u[8] - y[3]);
out[795] = -sin(x[0] + u[8] - y[3]);
out[796] = y[2]*cos(x[0] + u[8] - y[3]);
out[820] = y[2]*sin(x[0] + u[8] - y[3]);
out[836] = -cos(x[0] + u[8] - y[3]);
out[837] = -y[2]*sin(x[0] + u[8] - y[3]);
out[861] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[877] = y[5]*sin(x[0] + u[8] - y[3]) + y[6]*cos(x[0] + u[8] - y[3]);
out[878] = -y[2]*y[5]*cos(x[0] + u[8] - y[3]) + y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[880] = y[2]*sin(x[0] + u[8] - y[3]);
out[881] = y[2]*cos(x[0] + u[8] - y[3]);
out[902] = -y[2]*y[5]*sin(x[0] + u[8] - y[3]) - y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[918] = y[5]*cos(x[0] + u[8] - y[3]) - y[6]*sin(x[0] + u[8] - y[3]);
out[919] = y[2]*y[5]*sin(x[0] + u[8] - y[3]) + y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[921] = y[2]*cos(x[0] + u[8] - y[3]);
out[922] = -y[2]*sin(x[0] + u[8] - y[3]);
out[951] = p[27]*y[9];
out[966] = p[27]*x[8];
out[992] = -p[26]*y[9];
out[1007] = -p[26]*x[8];
out[1074] = -p[26]*y[13];
out[1093] = -p[26]*x[8];
out[1115] = p[26]*y[12] + p[27];
out[1133] = p[26]*x[8];
out[1213] = p[29]*y[12];
out[1214] = p[29]*y[13];
out[1215] = p[29]*y[10];
out[1216] = p[29]*y[11];
out[1244] = y[17]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1261] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[1285] = -y[16]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1301] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[1367] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[1403] = -p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]))/p[32];
out[1408] = -p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]))/p[32];
out[1409] = -p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]))/p[32];
out[1449] = -sin(y[1]);
out[1450] = -y[0]*cos(y[1]) - y[18]*sin(y[1]) + y[19]*cos(y[1]);
out[1467] = cos(y[1]);
out[1468] = sin(y[1]);
out[1490] = -cos(y[1]);
out[1491] = y[0]*sin(y[1]) - y[18]*cos(y[1]) - y[19]*sin(y[1]);
out[1508] = -sin(y[1]);
out[1509] = cos(y[1]);
out[1531] = y[21]*sin(y[1]) + y[22]*cos(y[1]);
out[1532] = y[0]*y[21]*cos(y[1]) - y[0]*y[22]*sin(y[1]);
out[1552] = y[0]*sin(y[1]);
out[1553] = y[0]*cos(y[1]);
out[1572] = -y[21]*cos(y[1]) + y[22]*sin(y[1]);
out[1573] = y[0]*y[21]*sin(y[1]) + y[0]*y[22]*cos(y[1]);
out[1593] = -y[0]*cos(y[1]);
out[1594] = y[0]*sin(y[1]);

}

void de_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[10];
out[18] = 6.2831853071795862*p[7];
out[39] = -6.2831853071795862*p[7];
out[42] = -p[11];
out[84] = -p[12];
out[209] = 1.0*p[18]/p[16];
out[210] = -1.0/p[16];
out[356] = -0.5/p[20];
out[379] = 314.15926535897933*p[31];
out[461] = p[31]/p[32];
out[462] = -1/p[32];
out[546] = -p[53];
out[611] = -p[13]/p[0];
out[653] = -p[13]/p[0];
out[677] = -p[6]/p[0];
out[719] = -p[6]/p[0];
out[798] = -p[9];
out[799] = p[8];
out[839] = -p[8];
out[840] = -p[9];
out[954] = p[23];
out[977] = p[24];
out[1033] = p[26]*u[12] + p[27];
out[1048] = -p[25];
out[1092] = -p[25];
out[1134] = -p[25];
out[1175] = p[27];
out[1201] = p[28];
out[1342] = -p[33];
out[1343] = -p[34];
out[1383] = p[34];
out[1384] = -p[33];
out[1404] = -p[31]/p[32];
out[1405] = 1.0/p[32];
out[1470] = -p[33];
out[1471] = -p[34];
out[1511] = p[34];
out[1512] = -p[33];
out[1653] = p[52];
out[1679] = -p[51];

}

void de_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[168] = -1.0e-8;
out[253] = 1.0;
out[254] = -1.0;
out[408] = -314.15926535897933;
out[572] = -1.0;
out[739] = 1.0;
out[756] = -1.0;
out[822] = 1.0;
out[882] = -1.0;
out[924] = -1.0;
out[946] = -1.0;
out[1008] = -1.0;
out[1050] = -1.0;
out[1090] = -1.0;
out[1132] = -1.0;
out[1176] = -1.0;
out[1218] = -1.0;
out[1259] = -1.0;
out[1344] = 1.0;
out[1386] = 1.0;
out[1428] = 1.0;
out[1554] = -1.0;
out[1596] = -1.0;
out[1617] = 1.0;
out[1638] = -1.0;
out[1680] = -1.0;

}

void sp_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[5] = -((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[6] = 3.0*p[14]*pow(x[7], 2)*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[7] = 2.0*p[25]*y[12]*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[8] = 2.0*p[25]*y[13]*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[10] = ((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
));
out[13] = 1.0*p[17]*((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
))/p[16];
out[16] = 0.5*((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(-p[39]*p[43]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2))*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[39]*(p[40]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) - p[41])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))))/(p[49]*pow(p[45], 3))
))/(p[19]*x[7]);
out[17] = -0.5*p[21]/(p[19]*x[7]);
out[18] = 0.5*(-p[22] + ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(-p[39]*p[40]*p[46]*p[45]*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*u[17]*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) + p[39]*p[43]*p[46]*p[45]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*u[17]*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) + p[44]*p[46]*p[45]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
)))/(p[19]*x[7]) - 0.5*(-p[22]*(-x[8] + x[7]) - p[21]*x[6] + ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
)))/(p[19]*pow(x[7], 2));
out[19] = 0.5*p[22]/(p[19]*x[7]);
out[20] = 0.5*p[21]/(p[20]*x[8]);
out[21] = 0.5*p[22]/(p[20]*x[8]);
out[22] = 0.5*(-p[22] - y[14])/(p[20]*x[8]) - 0.5*(p[22]*(-x[8] + x[7]) + p[21]*x[6] - x[8]*y[14])/(p[20]*pow(x[8], 2));
out[24] = 314.15926535897933*p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]));
out[26] = 314.15926535897933*p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]));
out[27] = 314.15926535897933*p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]));
out[29] = -y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]);
out[30] = sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]);
out[31] = y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]);
out[32] = p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]))/p[32];
out[35] = p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]))/p[32];
out[36] = p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]))/p[32];
out[37] = (-0.5*(y[12]*y[10] + y[13]*y[11])/pow(x[12] + 9.9999999999999995e-7, 2) + 0.5*(y[21]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[22]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/pow(x[12] + 9.9999999999999995e-7, 2))/p[35];
out[38] = -0.5*(y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])) + y[22]*(-y[18]*cos(y[1]) - y[19]*sin(y[1])))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[39] = 0.5*y[12]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[40] = 0.5*y[13]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[41] = 0.5*y[10]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[42] = 0.5*y[11]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[43] = -0.5*(y[21]*cos(y[1]) - y[22]*sin(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[44] = -0.5*(y[21]*sin(y[1]) + y[22]*cos(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[45] = -0.5*(y[18]*cos(y[1]) + y[19]*sin(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[46] = -0.5*(-y[18]*sin(y[1]) + y[19]*cos(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[49] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[50] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[51] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[52] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[54] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[55] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[56] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[57] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[59] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[60] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[61] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[62] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[64] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[65] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[66] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[67] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[71] = -y[2]*cos(x[0] + u[8] - y[3]);
out[72] = -sin(x[0] + u[8] - y[3]);
out[73] = y[2]*cos(x[0] + u[8] - y[3]);
out[76] = y[2]*sin(x[0] + u[8] - y[3]);
out[78] = -cos(x[0] + u[8] - y[3]);
out[79] = -y[2]*sin(x[0] + u[8] - y[3]);
out[82] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[83] = y[5]*sin(x[0] + u[8] - y[3]) + y[6]*cos(x[0] + u[8] - y[3]);
out[84] = -y[2]*y[5]*cos(x[0] + u[8] - y[3]) + y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[85] = y[2]*sin(x[0] + u[8] - y[3]);
out[86] = y[2]*cos(x[0] + u[8] - y[3]);
out[88] = -y[2]*y[5]*sin(x[0] + u[8] - y[3]) - y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[89] = y[5]*cos(x[0] + u[8] - y[3]) - y[6]*sin(x[0] + u[8] - y[3]);
out[90] = y[2]*y[5]*sin(x[0] + u[8] - y[3]) + y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[91] = y[2]*cos(x[0] + u[8] - y[3]);
out[92] = -y[2]*sin(x[0] + u[8] - y[3]);
out[95] = p[27]*y[9];
out[97] = p[27]*x[8];
out[99] = -p[26]*y[9];
out[100] = -p[26]*x[8];
out[105] = -p[26]*y[13];
out[108] = -p[26]*x[8];
out[109] = p[26]*y[12] + p[27];
out[111] = p[26]*x[8];
out[116] = p[29]*y[12];
out[117] = p[29]*y[13];
out[118] = p[29]*y[10];
out[119] = p[29]*y[11];
out[121] = y[17]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[123] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[124] = -y[16]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[125] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[129] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[133] = -p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]))/p[32];
out[136] = -p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]))/p[32];
out[137] = -p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]))/p[32];
out[139] = -sin(y[1]);
out[140] = -y[0]*cos(y[1]) - y[18]*sin(y[1]) + y[19]*cos(y[1]);
out[141] = cos(y[1]);
out[142] = sin(y[1]);
out[145] = -cos(y[1]);
out[146] = y[0]*sin(y[1]) - y[18]*cos(y[1]) - y[19]*sin(y[1]);
out[147] = -sin(y[1]);
out[148] = cos(y[1]);
out[151] = y[21]*sin(y[1]) + y[22]*cos(y[1]);
out[152] = y[0]*y[21]*cos(y[1]) - y[0]*y[22]*sin(y[1]);
out[153] = y[0]*sin(y[1]);
out[154] = y[0]*cos(y[1]);
out[156] = -y[21]*cos(y[1]) + y[22]*sin(y[1]);
out[157] = y[0]*y[21]*sin(y[1]) + y[0]*y[22]*cos(y[1]);
out[158] = -y[0]*cos(y[1]);
out[159] = y[0]*sin(y[1]);

}

void sp_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[10];
out[1] = 6.2831853071795862*p[7];
out[2] = -6.2831853071795862*p[7];
out[3] = -p[11];
out[4] = -p[12];
out[11] = 1.0*p[18]/p[16];
out[12] = -1.0/p[16];
out[23] = -0.5/p[20];
out[25] = 314.15926535897933*p[31];
out[33] = p[31]/p[32];
out[34] = -1/p[32];
out[47] = -p[53];
out[53] = -p[13]/p[0];
out[58] = -p[13]/p[0];
out[63] = -p[6]/p[0];
out[68] = -p[6]/p[0];
out[74] = -p[9];
out[75] = p[8];
out[80] = -p[8];
out[81] = -p[9];
out[96] = p[23];
out[98] = p[24];
out[102] = p[26]*u[12] + p[27];
out[103] = -p[25];
out[107] = -p[25];
out[112] = -p[25];
out[113] = p[27];
out[115] = p[28];
out[126] = -p[33];
out[127] = -p[34];
out[130] = p[34];
out[131] = -p[33];
out[134] = -p[31]/p[32];
out[135] = 1.0/p[32];
out[143] = -p[33];
out[144] = -p[34];
out[149] = p[34];
out[150] = -p[33];
out[163] = p[52];
out[164] = -p[51];

}

void sp_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[9] = -1.0e-8;
out[14] = 1.0;
out[15] = -1.0;
out[28] = -314.15926535897933;
out[48] = -1.0;
out[69] = 1.0;
out[70] = -1.0;
out[77] = 1.0;
out[87] = -1.0;
out[93] = -1.0;
out[94] = -1.0;
out[101] = -1.0;
out[104] = -1.0;
out[106] = -1.0;
out[110] = -1.0;
out[114] = -1.0;
out[120] = -1.0;
out[122] = -1.0;
out[128] = 1.0;
out[132] = 1.0;
out[138] = 1.0;
out[155] = -1.0;
out[160] = -1.0;
out[161] = 1.0;
out[162] = -1.0;
out[165] = -1.0;

}

void de_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[126] = -((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[130] = 3.0*p[14]*pow(x[7], 2)*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[149] = 2.0*p[25]*y[12]*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[150] = 2.0*p[25]*y[13]*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[172] = ((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
));
out[213] = 1.0*p[17]*((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
))/p[16];
out[292] = 0.5*((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(-p[39]*p[43]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2))*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[39]*(p[40]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) - p[41])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))))/(p[49]*pow(p[45], 3))
))/(p[19]*x[7]);
out[293] = -0.5*p[21]/(p[19]*x[7]);
out[294] = 0.5*(-p[22] + ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(-p[39]*p[40]*p[46]*p[45]*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*u[17]*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) + p[39]*p[43]*p[46]*p[45]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*u[17]*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) + p[44]*p[46]*p[45]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
)))/(p[19]*x[7]) - 0.5*(-p[22]*(-x[8] + x[7]) - p[21]*x[6] + ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
)))/(p[19]*pow(x[7], 2));
out[295] = 0.5*p[22]/(p[19]*x[7]);
out[334] = 0.5*p[21]/(p[20]*x[8]);
out[335] = 0.5*p[22]/(p[20]*x[8]);
out[336] = 0.5*(-p[22] - y[14])/(p[20]*x[8]) - 0.5*(p[22]*(-x[8] + x[7]) + p[21]*x[6] - x[8]*y[14])/(p[20]*pow(x[8], 2));
out[378] = 314.15926535897933*p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]));
out[383] = 314.15926535897933*p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]));
out[384] = 314.15926535897933*p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]));
out[419] = -y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]);
out[424] = sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]);
out[425] = y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]);
out[460] = p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]))/p[32];
out[465] = p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]))/p[32];
out[466] = p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]))/p[32];
out[504] = (-0.5*(y[12]*y[10] + y[13]*y[11])/pow(x[12] + 9.9999999999999995e-7, 2) + 0.5*(y[21]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[22]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/pow(x[12] + 9.9999999999999995e-7, 2))/p[35];
out[507] = -0.5*(y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])) + y[22]*(-y[18]*cos(y[1]) - y[19]*sin(y[1])))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[516] = 0.5*y[12]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[517] = 0.5*y[13]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[518] = 0.5*y[10]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[519] = 0.5*y[11]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[524] = -0.5*(y[21]*cos(y[1]) - y[22]*sin(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[525] = -0.5*(y[21]*sin(y[1]) + y[22]*cos(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[527] = -0.5*(y[18]*cos(y[1]) + y[19]*sin(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[528] = -0.5*(-y[18]*sin(y[1]) + y[19]*cos(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[588] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[589] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[590] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[591] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[629] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[630] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[631] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[632] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[670] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[671] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[672] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[673] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[711] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[712] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[713] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[714] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[779] = -y[2]*cos(x[0] + u[8] - y[3]);
out[795] = -sin(x[0] + u[8] - y[3]);
out[796] = y[2]*cos(x[0] + u[8] - y[3]);
out[820] = y[2]*sin(x[0] + u[8] - y[3]);
out[836] = -cos(x[0] + u[8] - y[3]);
out[837] = -y[2]*sin(x[0] + u[8] - y[3]);
out[861] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[877] = y[5]*sin(x[0] + u[8] - y[3]) + y[6]*cos(x[0] + u[8] - y[3]);
out[878] = -y[2]*y[5]*cos(x[0] + u[8] - y[3]) + y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[880] = y[2]*sin(x[0] + u[8] - y[3]);
out[881] = y[2]*cos(x[0] + u[8] - y[3]);
out[902] = -y[2]*y[5]*sin(x[0] + u[8] - y[3]) - y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[918] = y[5]*cos(x[0] + u[8] - y[3]) - y[6]*sin(x[0] + u[8] - y[3]);
out[919] = y[2]*y[5]*sin(x[0] + u[8] - y[3]) + y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[921] = y[2]*cos(x[0] + u[8] - y[3]);
out[922] = -y[2]*sin(x[0] + u[8] - y[3]);
out[951] = p[27]*y[9];
out[966] = p[27]*x[8];
out[992] = -p[26]*y[9];
out[1007] = -p[26]*x[8];
out[1074] = -p[26]*y[13];
out[1093] = -p[26]*x[8];
out[1115] = p[26]*y[12] + p[27];
out[1133] = p[26]*x[8];
out[1213] = p[29]*y[12];
out[1214] = p[29]*y[13];
out[1215] = p[29]*y[10];
out[1216] = p[29]*y[11];
out[1244] = y[17]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1261] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[1285] = -y[16]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1301] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[1367] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[1403] = -p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]))/p[32];
out[1408] = -p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]))/p[32];
out[1409] = -p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]))/p[32];
out[1449] = -sin(y[1]);
out[1450] = -y[0]*cos(y[1]) - y[18]*sin(y[1]) + y[19]*cos(y[1]);
out[1467] = cos(y[1]);
out[1468] = sin(y[1]);
out[1490] = -cos(y[1]);
out[1491] = y[0]*sin(y[1]) - y[18]*cos(y[1]) - y[19]*sin(y[1]);
out[1508] = -sin(y[1]);
out[1509] = cos(y[1]);
out[1531] = y[21]*sin(y[1]) + y[22]*cos(y[1]);
out[1532] = y[0]*y[21]*cos(y[1]) - y[0]*y[22]*sin(y[1]);
out[1552] = y[0]*sin(y[1]);
out[1553] = y[0]*cos(y[1]);
out[1572] = -y[21]*cos(y[1]) + y[22]*sin(y[1]);
out[1573] = y[0]*y[21]*sin(y[1]) + y[0]*y[22]*cos(y[1]);
out[1593] = -y[0]*cos(y[1]);
out[1594] = y[0]*sin(y[1]);

}

void de_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[10];
out[18] = 6.2831853071795862*p[7];
out[39] = -6.2831853071795862*p[7];
out[42] = -p[11];
out[84] = -p[12];
out[209] = 1.0*p[18]/p[16];
out[210] = -1.0/p[16];
out[356] = -0.5/p[20];
out[379] = 314.15926535897933*p[31];
out[461] = p[31]/p[32];
out[462] = -1/p[32];
out[546] = -p[53];
out[611] = -p[13]/p[0];
out[653] = -p[13]/p[0];
out[677] = -p[6]/p[0];
out[719] = -p[6]/p[0];
out[798] = -p[9];
out[799] = p[8];
out[839] = -p[8];
out[840] = -p[9];
out[954] = p[23];
out[977] = p[24];
out[1033] = p[26]*u[12] + p[27];
out[1048] = -p[25];
out[1092] = -p[25];
out[1134] = -p[25];
out[1175] = p[27];
out[1201] = p[28];
out[1342] = -p[33];
out[1343] = -p[34];
out[1383] = p[34];
out[1384] = -p[33];
out[1404] = -p[31]/p[32];
out[1405] = 1.0/p[32];
out[1470] = -p[33];
out[1471] = -p[34];
out[1511] = p[34];
out[1512] = -p[33];
out[1653] = p[52];
out[1679] = -p[51];

}

void de_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[168] = -1.0e-8;
out[253] = 1.0;
out[254] = -1.0;
out[408] = -314.15926535897933;
out[572] = -1.0;
out[739] = 1.0;
out[756] = -1.0;
out[822] = 1.0;
out[882] = -1.0;
out[924] = -1.0;
out[946] = -1.0;
out[1008] = -1.0;
out[1050] = -1.0;
out[1090] = -1.0;
out[1132] = -1.0;
out[1176] = -1.0;
out[1218] = -1.0;
out[1259] = -1.0;
out[1344] = 1.0;
out[1386] = 1.0;
out[1428] = 1.0;
out[1554] = -1.0;
out[1596] = -1.0;
out[1617] = 1.0;
out[1638] = -1.0;
out[1680] = -1.0;

}

void sp_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[5] = -((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[6] = 3.0*p[14]*pow(x[7], 2)*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[7] = 2.0*p[25]*y[12]*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[8] = 2.0*p[25]*y[13]*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[10] = ((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
));
out[13] = 1.0*p[17]*((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
))/p[16];
out[16] = 0.5*((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(-p[39]*p[43]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2))*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[39]*(p[40]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) - p[41])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))))/(p[49]*pow(p[45], 3))
))/(p[19]*x[7]);
out[17] = -0.5*p[21]/(p[19]*x[7]);
out[18] = 0.5*(-p[22] + ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(-p[39]*p[40]*p[46]*p[45]*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*u[17]*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) + p[39]*p[43]*p[46]*p[45]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*u[17]*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) + p[44]*p[46]*p[45]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
)))/(p[19]*x[7]) - 0.5*(-p[22]*(-x[8] + x[7]) - p[21]*x[6] + ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
)))/(p[19]*pow(x[7], 2));
out[19] = 0.5*p[22]/(p[19]*x[7]);
out[20] = 0.5*p[21]/(p[20]*x[8]);
out[21] = 0.5*p[22]/(p[20]*x[8]);
out[22] = 0.5*(-p[22] - y[14])/(p[20]*x[8]) - 0.5*(p[22]*(-x[8] + x[7]) + p[21]*x[6] - x[8]*y[14])/(p[20]*pow(x[8], 2));
out[24] = 314.15926535897933*p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]));
out[26] = 314.15926535897933*p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]));
out[27] = 314.15926535897933*p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]));
out[29] = -y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]);
out[30] = sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]);
out[31] = y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]);
out[32] = p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]))/p[32];
out[35] = p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]))/p[32];
out[36] = p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]))/p[32];
out[37] = (-0.5*(y[12]*y[10] + y[13]*y[11])/pow(x[12] + 9.9999999999999995e-7, 2) + 0.5*(y[21]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[22]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/pow(x[12] + 9.9999999999999995e-7, 2))/p[35];
out[38] = -0.5*(y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])) + y[22]*(-y[18]*cos(y[1]) - y[19]*sin(y[1])))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[39] = 0.5*y[12]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[40] = 0.5*y[13]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[41] = 0.5*y[10]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[42] = 0.5*y[11]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[43] = -0.5*(y[21]*cos(y[1]) - y[22]*sin(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[44] = -0.5*(y[21]*sin(y[1]) + y[22]*cos(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[45] = -0.5*(y[18]*cos(y[1]) + y[19]*sin(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[46] = -0.5*(-y[18]*sin(y[1]) + y[19]*cos(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[49] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[50] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[51] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[52] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[54] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[55] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[56] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[57] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[59] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[60] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[61] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[62] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[64] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[65] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[66] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[67] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[71] = -y[2]*cos(x[0] + u[8] - y[3]);
out[72] = -sin(x[0] + u[8] - y[3]);
out[73] = y[2]*cos(x[0] + u[8] - y[3]);
out[76] = y[2]*sin(x[0] + u[8] - y[3]);
out[78] = -cos(x[0] + u[8] - y[3]);
out[79] = -y[2]*sin(x[0] + u[8] - y[3]);
out[82] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[83] = y[5]*sin(x[0] + u[8] - y[3]) + y[6]*cos(x[0] + u[8] - y[3]);
out[84] = -y[2]*y[5]*cos(x[0] + u[8] - y[3]) + y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[85] = y[2]*sin(x[0] + u[8] - y[3]);
out[86] = y[2]*cos(x[0] + u[8] - y[3]);
out[88] = -y[2]*y[5]*sin(x[0] + u[8] - y[3]) - y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[89] = y[5]*cos(x[0] + u[8] - y[3]) - y[6]*sin(x[0] + u[8] - y[3]);
out[90] = y[2]*y[5]*sin(x[0] + u[8] - y[3]) + y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[91] = y[2]*cos(x[0] + u[8] - y[3]);
out[92] = -y[2]*sin(x[0] + u[8] - y[3]);
out[95] = p[27]*y[9];
out[97] = p[27]*x[8];
out[99] = -p[26]*y[9];
out[100] = -p[26]*x[8];
out[105] = -p[26]*y[13];
out[108] = -p[26]*x[8];
out[109] = p[26]*y[12] + p[27];
out[111] = p[26]*x[8];
out[116] = p[29]*y[12];
out[117] = p[29]*y[13];
out[118] = p[29]*y[10];
out[119] = p[29]*y[11];
out[121] = y[17]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[123] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[124] = -y[16]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[125] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[129] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[133] = -p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]))/p[32];
out[136] = -p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]))/p[32];
out[137] = -p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]))/p[32];
out[139] = -sin(y[1]);
out[140] = -y[0]*cos(y[1]) - y[18]*sin(y[1]) + y[19]*cos(y[1]);
out[141] = cos(y[1]);
out[142] = sin(y[1]);
out[145] = -cos(y[1]);
out[146] = y[0]*sin(y[1]) - y[18]*cos(y[1]) - y[19]*sin(y[1]);
out[147] = -sin(y[1]);
out[148] = cos(y[1]);
out[151] = y[21]*sin(y[1]) + y[22]*cos(y[1]);
out[152] = y[0]*y[21]*cos(y[1]) - y[0]*y[22]*sin(y[1]);
out[153] = y[0]*sin(y[1]);
out[154] = y[0]*cos(y[1]);
out[156] = -y[21]*cos(y[1]) + y[22]*sin(y[1]);
out[157] = y[0]*y[21]*sin(y[1]) + y[0]*y[22]*cos(y[1]);
out[158] = -y[0]*cos(y[1]);
out[159] = y[0]*sin(y[1]);

}

void sp_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -p[10];
out[1] = 6.2831853071795862*p[7];
out[2] = -6.2831853071795862*p[7];
out[3] = -p[11];
out[4] = -p[12];
out[11] = 1.0*p[18]/p[16];
out[12] = -1.0/p[16];
out[23] = -0.5/p[20];
out[25] = 314.15926535897933*p[31];
out[33] = p[31]/p[32];
out[34] = -1/p[32];
out[47] = -p[53];
out[53] = -p[13]/p[0];
out[58] = -p[13]/p[0];
out[63] = -p[6]/p[0];
out[68] = -p[6]/p[0];
out[74] = -p[9];
out[75] = p[8];
out[80] = -p[8];
out[81] = -p[9];
out[96] = p[23];
out[98] = p[24];
out[102] = p[26]*u[12] + p[27];
out[103] = -p[25];
out[107] = -p[25];
out[112] = -p[25];
out[113] = p[27];
out[115] = p[28];
out[126] = -p[33];
out[127] = -p[34];
out[130] = p[34];
out[131] = -p[33];
out[134] = -p[31]/p[32];
out[135] = 1.0/p[32];
out[143] = -p[33];
out[144] = -p[34];
out[149] = p[34];
out[150] = -p[33];
out[163] = p[52];
out[164] = -p[51];

}

void sp_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[9] = -1.0e-8;
out[14] = 1.0;
out[15] = -1.0;
out[28] = -314.15926535897933;
out[48] = -1.0;
out[69] = 1.0;
out[70] = -1.0;
out[77] = 1.0;
out[87] = -1.0;
out[93] = -1.0;
out[94] = -1.0;
out[101] = -1.0;
out[104] = -1.0;
out[106] = -1.0;
out[110] = -1.0;
out[114] = -1.0;
out[120] = -1.0;
out[122] = -1.0;
out[128] = 1.0;
out[132] = 1.0;
out[138] = 1.0;
out[155] = -1.0;
out[160] = -1.0;
out[161] = 1.0;
out[162] = -1.0;
out[165] = -1.0;

}

void de_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[126] = 0.5*Dt*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50] + 1.0;
out[130] = -1.5*Dt*p[14]*pow(x[7], 2)*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[149] = -1.0*Dt*p[25]*y[12]*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[150] = -1.0*Dt*p[25]*y[13]*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[172] = -0.5*Dt*((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
));
out[213] = -0.5*Dt*p[17]*((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
))/p[16];
out[292] = -0.25*Dt*((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(-p[39]*p[43]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2))*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[39]*(p[40]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) - p[41])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))))/(p[49]*pow(p[45], 3))
))/(p[19]*x[7]);
out[293] = 0.25*Dt*p[21]/(p[19]*x[7]);
out[294] = -0.5*Dt*(0.5*(-p[22] + ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(-p[39]*p[40]*p[46]*p[45]*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*u[17]*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) + p[39]*p[43]*p[46]*p[45]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*u[17]*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) + p[44]*p[46]*p[45]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
)))/(p[19]*x[7]) - 0.5*(-p[22]*(-x[8] + x[7]) - p[21]*x[6] + ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
)))/(p[19]*pow(x[7], 2))) + 1.0;
out[295] = -0.25*p[22]*Dt/(p[19]*x[7]);
out[334] = -0.25*Dt*p[21]/(p[20]*x[8]);
out[335] = -0.25*p[22]*Dt/(p[20]*x[8]);
out[336] = -0.5*Dt*(0.5*(-p[22] - y[14])/(p[20]*x[8]) - 0.5*(p[22]*(-x[8] + x[7]) + p[21]*x[6] - x[8]*y[14])/(p[20]*pow(x[8], 2))) + 1.0;
out[378] = -157.07963267948966*Dt*p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9])) + 1.0;
out[383] = -157.07963267948966*Dt*p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]));
out[384] = -157.07963267948966*Dt*p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]));
out[419] = -0.5*Dt*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]));
out[424] = -0.5*Dt*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]));
out[425] = -0.5*Dt*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]));
out[460] = -0.5*Dt*p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]))/p[32];
out[465] = -0.5*Dt*p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]))/p[32];
out[466] = -0.5*Dt*p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]))/p[32];
out[504] = 1.0 - 0.5*Dt*(-0.5*(y[12]*y[10] + y[13]*y[11])/pow(x[12] + 9.9999999999999995e-7, 2) + 0.5*(y[21]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[22]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/pow(x[12] + 9.9999999999999995e-7, 2))/p[35];
out[507] = 0.25*Dt*(y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])) + y[22]*(-y[18]*cos(y[1]) - y[19]*sin(y[1])))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[516] = -0.25*Dt*y[12]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[517] = -0.25*Dt*y[13]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[518] = -0.25*Dt*y[10]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[519] = -0.25*Dt*y[11]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[524] = 0.25*Dt*(y[21]*cos(y[1]) - y[22]*sin(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[525] = 0.25*Dt*(y[21]*sin(y[1]) + y[22]*cos(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[527] = 0.25*Dt*(y[18]*cos(y[1]) + y[19]*sin(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[528] = 0.25*Dt*(-y[18]*sin(y[1]) + y[19]*cos(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[588] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[589] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[590] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[591] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[629] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[630] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[631] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[632] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[670] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[671] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[672] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[673] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[711] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[712] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[713] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[714] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[779] = -y[2]*cos(x[0] + u[8] - y[3]);
out[795] = -sin(x[0] + u[8] - y[3]);
out[796] = y[2]*cos(x[0] + u[8] - y[3]);
out[820] = y[2]*sin(x[0] + u[8] - y[3]);
out[836] = -cos(x[0] + u[8] - y[3]);
out[837] = -y[2]*sin(x[0] + u[8] - y[3]);
out[861] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[877] = y[5]*sin(x[0] + u[8] - y[3]) + y[6]*cos(x[0] + u[8] - y[3]);
out[878] = -y[2]*y[5]*cos(x[0] + u[8] - y[3]) + y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[880] = y[2]*sin(x[0] + u[8] - y[3]);
out[881] = y[2]*cos(x[0] + u[8] - y[3]);
out[902] = -y[2]*y[5]*sin(x[0] + u[8] - y[3]) - y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[918] = y[5]*cos(x[0] + u[8] - y[3]) - y[6]*sin(x[0] + u[8] - y[3]);
out[919] = y[2]*y[5]*sin(x[0] + u[8] - y[3]) + y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[921] = y[2]*cos(x[0] + u[8] - y[3]);
out[922] = -y[2]*sin(x[0] + u[8] - y[3]);
out[951] = p[27]*y[9];
out[966] = p[27]*x[8];
out[992] = -p[26]*y[9];
out[1007] = -p[26]*x[8];
out[1074] = -p[26]*y[13];
out[1093] = -p[26]*x[8];
out[1115] = p[26]*y[12] + p[27];
out[1133] = p[26]*x[8];
out[1213] = p[29]*y[12];
out[1214] = p[29]*y[13];
out[1215] = p[29]*y[10];
out[1216] = p[29]*y[11];
out[1244] = y[17]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1261] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[1285] = -y[16]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[1301] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[1367] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[1403] = -p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]))/p[32];
out[1408] = -p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]))/p[32];
out[1409] = -p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]))/p[32];
out[1449] = -sin(y[1]);
out[1450] = -y[0]*cos(y[1]) - y[18]*sin(y[1]) + y[19]*cos(y[1]);
out[1467] = cos(y[1]);
out[1468] = sin(y[1]);
out[1490] = -cos(y[1]);
out[1491] = y[0]*sin(y[1]) - y[18]*cos(y[1]) - y[19]*sin(y[1]);
out[1508] = -sin(y[1]);
out[1509] = cos(y[1]);
out[1531] = y[21]*sin(y[1]) + y[22]*cos(y[1]);
out[1532] = y[0]*y[21]*cos(y[1]) - y[0]*y[22]*sin(y[1]);
out[1552] = y[0]*sin(y[1]);
out[1553] = y[0]*cos(y[1]);
out[1572] = -y[21]*cos(y[1]) + y[22]*sin(y[1]);
out[1573] = y[0]*y[21]*sin(y[1]) + y[0]*y[22]*cos(y[1]);
out[1593] = -y[0]*cos(y[1]);
out[1594] = y[0]*sin(y[1]);

}

void de_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 0.5*Dt*p[10] + 1.0;
out[18] = -3.1415926535897931*Dt*p[7];
out[39] = 3.1415926535897931*Dt*p[7];
out[42] = 0.5*Dt*p[11] + 1.0;
out[84] = 0.5*Dt*p[12] + 1.0;
out[168] = 5.0000000000000001e-9*Dt + 1.0;
out[209] = -0.5*Dt*p[18]/p[16];
out[210] = 0.5*Dt/p[16] + 1.0;
out[253] = -0.5*Dt;
out[254] = 0.5*Dt;
out[356] = 0.25*Dt/p[20];
out[379] = -157.07963267948966*Dt*p[31];
out[408] = 157.07963267948966*Dt;
out[461] = -0.5*Dt*p[31]/p[32];
out[462] = 0.5*Dt/p[32] + 1.0;
out[546] = 0.5*Dt*p[53] + 1.0;
out[572] = 0.5*Dt;
out[611] = -p[13]/p[0];
out[653] = -p[13]/p[0];
out[677] = -p[6]/p[0];
out[719] = -p[6]/p[0];
out[798] = -p[9];
out[799] = p[8];
out[839] = -p[8];
out[840] = -p[9];
out[954] = p[23];
out[977] = p[24];
out[1033] = p[26]*u[12] + p[27];
out[1048] = -p[25];
out[1092] = -p[25];
out[1134] = -p[25];
out[1175] = p[27];
out[1201] = p[28];
out[1342] = -p[33];
out[1343] = -p[34];
out[1383] = p[34];
out[1384] = -p[33];
out[1404] = -p[31]/p[32];
out[1405] = 1.0/p[32];
out[1470] = -p[33];
out[1471] = -p[34];
out[1511] = p[34];
out[1512] = -p[33];
out[1653] = p[52];
out[1679] = -p[51];

}

void de_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[252] = 1.0;
out[420] = 1.0;
out[739] = 1.0;
out[756] = -1.0;
out[822] = 1.0;
out[882] = -1.0;
out[924] = -1.0;
out[946] = -1.0;
out[1008] = -1.0;
out[1050] = -1.0;
out[1090] = -1.0;
out[1132] = -1.0;
out[1176] = -1.0;
out[1218] = -1.0;
out[1259] = -1.0;
out[1344] = 1.0;
out[1386] = 1.0;
out[1428] = 1.0;
out[1554] = -1.0;
out[1596] = -1.0;
out[1617] = 1.0;
out[1638] = -1.0;
out[1680] = -1.0;

}

void sp_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[5] = 0.5*Dt*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50] + 1.0;
out[6] = -1.5*Dt*p[14]*pow(x[7], 2)*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[7] = -1.0*Dt*p[25]*y[12]*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[8] = -1.0*Dt*p[25]*y[13]*((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))/p[50];
out[10] = -0.5*Dt*((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
));
out[13] = -0.5*Dt*p[17]*((p[15] - x[8] > 0) ? (
   0
)
: (
   1.0
))/p[16];
out[17] = -0.25*Dt*((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(-p[39]*p[43]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2))*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[39]*(p[40]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) - p[41])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))))/(p[49]*pow(p[45], 3))
))/(p[19]*x[7]);
out[18] = 0.25*Dt*p[21]/(p[19]*x[7]);
out[19] = -0.5*Dt*(0.5*(-p[22] + ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(-p[39]*p[40]*p[46]*p[45]*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*u[17]*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) + p[39]*p[43]*p[46]*p[45]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*u[17]*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) + p[44]*p[46]*p[45]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
)))/(p[19]*x[7]) - 0.5*(-p[22]*(-x[8] + x[7]) - p[21]*x[6] + ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
)))/(p[19]*pow(x[7], 2))) + 1.0;
out[20] = -0.25*p[22]*Dt/(p[19]*x[7]);
out[21] = -0.25*Dt*p[21]/(p[20]*x[8]);
out[22] = -0.25*p[22]*Dt/(p[20]*x[8]);
out[23] = -0.5*Dt*(0.5*(-p[22] - y[14])/(p[20]*x[8]) - 0.5*(p[22]*(-x[8] + x[7]) + p[21]*x[6] - x[8]*y[14])/(p[20]*pow(x[8], 2))) + 1.0;
out[25] = -157.07963267948966*Dt*p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9])) + 1.0;
out[27] = -157.07963267948966*Dt*p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]));
out[28] = -157.07963267948966*Dt*p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]));
out[30] = -0.5*Dt*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]));
out[32] = -0.5*Dt*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]));
out[33] = -0.5*Dt*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]));
out[34] = -0.5*Dt*p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]))/p[32];
out[37] = -0.5*Dt*p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]))/p[32];
out[38] = -0.5*Dt*p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]))/p[32];
out[39] = 1.0 - 0.5*Dt*(-0.5*(y[12]*y[10] + y[13]*y[11])/pow(x[12] + 9.9999999999999995e-7, 2) + 0.5*(y[21]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[22]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/pow(x[12] + 9.9999999999999995e-7, 2))/p[35];
out[40] = 0.25*Dt*(y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])) + y[22]*(-y[18]*cos(y[1]) - y[19]*sin(y[1])))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[41] = -0.25*Dt*y[12]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[42] = -0.25*Dt*y[13]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[43] = -0.25*Dt*y[10]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[44] = -0.25*Dt*y[11]/(p[35]*(x[12] + 9.9999999999999995e-7));
out[45] = 0.25*Dt*(y[21]*cos(y[1]) - y[22]*sin(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[46] = 0.25*Dt*(y[21]*sin(y[1]) + y[22]*cos(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[47] = 0.25*Dt*(y[18]*cos(y[1]) + y[19]*sin(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[48] = 0.25*Dt*(-y[18]*sin(y[1]) + y[19]*cos(y[1]))/(p[35]*(x[12] + 9.9999999999999995e-7));
out[51] = 2.0*y[0]*p[1] + y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[52] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[53] = y[0]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[54] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[56] = 2.0*y[0]*(-p[2] - 0.5*p[3]) + y[2]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[57] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[58] = y[0]*(p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[59] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[61] = y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[62] = y[0]*y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[63] = y[0]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3])) + 2.0*y[2]*p[1];
out[64] = y[0]*y[2]*(-p[2]*cos(y[1] - y[3]) - p[1]*sin(y[1] - y[3]));
out[66] = y[2]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3]));
out[67] = y[0]*y[2]*(-p[2]*sin(y[1] - y[3]) + p[1]*cos(y[1] - y[3]));
out[68] = y[0]*(p[2]*cos(y[1] - y[3]) + p[1]*sin(y[1] - y[3])) + 2.0*y[2]*(-p[2] - 0.5*p[3]);
out[69] = y[0]*y[2]*(p[2]*sin(y[1] - y[3]) - p[1]*cos(y[1] - y[3]));
out[73] = -y[2]*cos(x[0] + u[8] - y[3]);
out[74] = -sin(x[0] + u[8] - y[3]);
out[75] = y[2]*cos(x[0] + u[8] - y[3]);
out[78] = y[2]*sin(x[0] + u[8] - y[3]);
out[80] = -cos(x[0] + u[8] - y[3]);
out[81] = -y[2]*sin(x[0] + u[8] - y[3]);
out[84] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[85] = y[5]*sin(x[0] + u[8] - y[3]) + y[6]*cos(x[0] + u[8] - y[3]);
out[86] = -y[2]*y[5]*cos(x[0] + u[8] - y[3]) + y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[87] = y[2]*sin(x[0] + u[8] - y[3]);
out[88] = y[2]*cos(x[0] + u[8] - y[3]);
out[90] = -y[2]*y[5]*sin(x[0] + u[8] - y[3]) - y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[91] = y[5]*cos(x[0] + u[8] - y[3]) - y[6]*sin(x[0] + u[8] - y[3]);
out[92] = y[2]*y[5]*sin(x[0] + u[8] - y[3]) + y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[93] = y[2]*cos(x[0] + u[8] - y[3]);
out[94] = -y[2]*sin(x[0] + u[8] - y[3]);
out[97] = p[27]*y[9];
out[99] = p[27]*x[8];
out[101] = -p[26]*y[9];
out[102] = -p[26]*x[8];
out[107] = -p[26]*y[13];
out[110] = -p[26]*x[8];
out[111] = p[26]*y[12] + p[27];
out[113] = p[26]*x[8];
out[118] = p[29]*y[12];
out[119] = p[29]*y[13];
out[120] = p[29]*y[10];
out[121] = p[29]*y[11];
out[123] = y[17]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[125] = y[0]*pow(sin(y[1]), 2) + y[0]*pow(cos(y[1]), 2);
out[126] = -y[16]*(pow(sin(y[1]), 2) + pow(cos(y[1]), 2));
out[127] = -y[0]*pow(sin(y[1]), 2) - y[0]*pow(cos(y[1]), 2);
out[131] = -pow(sin(y[1]), 2) - pow(cos(y[1]), 2);
out[135] = -p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]))/p[32];
out[138] = -p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]))/p[32];
out[139] = -p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]))/p[32];
out[141] = -sin(y[1]);
out[142] = -y[0]*cos(y[1]) - y[18]*sin(y[1]) + y[19]*cos(y[1]);
out[143] = cos(y[1]);
out[144] = sin(y[1]);
out[147] = -cos(y[1]);
out[148] = y[0]*sin(y[1]) - y[18]*cos(y[1]) - y[19]*sin(y[1]);
out[149] = -sin(y[1]);
out[150] = cos(y[1]);
out[153] = y[21]*sin(y[1]) + y[22]*cos(y[1]);
out[154] = y[0]*y[21]*cos(y[1]) - y[0]*y[22]*sin(y[1]);
out[155] = y[0]*sin(y[1]);
out[156] = y[0]*cos(y[1]);
out[158] = -y[21]*cos(y[1]) + y[22]*sin(y[1]);
out[159] = y[0]*y[21]*sin(y[1]) + y[0]*y[22]*cos(y[1]);
out[160] = -y[0]*cos(y[1]);
out[161] = y[0]*sin(y[1]);

}

void sp_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 0.5*Dt*p[10] + 1.0;
out[1] = -3.1415926535897931*Dt*p[7];
out[2] = 3.1415926535897931*Dt*p[7];
out[3] = 0.5*Dt*p[11] + 1.0;
out[4] = 0.5*Dt*p[12] + 1.0;
out[9] = 5.0000000000000001e-9*Dt + 1.0;
out[11] = -0.5*Dt*p[18]/p[16];
out[12] = 0.5*Dt/p[16] + 1.0;
out[15] = -0.5*Dt;
out[16] = 0.5*Dt;
out[24] = 0.25*Dt/p[20];
out[26] = -157.07963267948966*Dt*p[31];
out[29] = 157.07963267948966*Dt;
out[35] = -0.5*Dt*p[31]/p[32];
out[36] = 0.5*Dt/p[32] + 1.0;
out[49] = 0.5*Dt*p[53] + 1.0;
out[50] = 0.5*Dt;
out[55] = -p[13]/p[0];
out[60] = -p[13]/p[0];
out[65] = -p[6]/p[0];
out[70] = -p[6]/p[0];
out[76] = -p[9];
out[77] = p[8];
out[82] = -p[8];
out[83] = -p[9];
out[98] = p[23];
out[100] = p[24];
out[104] = p[26]*u[12] + p[27];
out[105] = -p[25];
out[109] = -p[25];
out[114] = -p[25];
out[115] = p[27];
out[117] = p[28];
out[128] = -p[33];
out[129] = -p[34];
out[132] = p[34];
out[133] = -p[33];
out[136] = -p[31]/p[32];
out[137] = 1.0/p[32];
out[145] = -p[33];
out[146] = -p[34];
out[151] = p[34];
out[152] = -p[33];
out[165] = p[52];
out[166] = -p[51];

}

void sp_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[14] = 1.0;
out[31] = 1.0;
out[71] = 1.0;
out[72] = -1.0;
out[79] = 1.0;
out[89] = -1.0;
out[95] = -1.0;
out[96] = -1.0;
out[103] = -1.0;
out[106] = -1.0;
out[108] = -1.0;
out[112] = -1.0;
out[116] = -1.0;
out[122] = -1.0;
out[124] = -1.0;
out[130] = 1.0;
out[134] = 1.0;
out[140] = 1.0;
out[157] = -1.0;
out[162] = -1.0;
out[163] = 1.0;
out[164] = -1.0;
out[167] = -1.0;

}

void de_Fu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[67] = ((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))*((u[10] < 0) ? (
   1.0
)
: (
   0
))/p[50];
out[150] = 0.5*((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(p[39]*p[40]*p[46]*p[45]*x[7]*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*pow(u[17], 2)*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) - p[39]*p[43]*p[46]*p[45]*x[7]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*pow(u[17], 2)*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) - p[44]*p[46]*p[45]*x[7]/(p[47]*pow(u[17], 2)))/(p[49]*pow(p[45], 3)) + 3.0*p[48]*pow(u[17], 2)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
))/(p[19]*x[7]);

}

void de_Fu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[7] = p[10];
out[106] = 1.0/p[16];

}

void de_Fu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[23] = 1.0;
out[47] = 1.0;
out[132] = -1.0;

}

void de_Gu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[103] = -y[2]*cos(x[0] + u[8] - y[3]);
out[122] = y[2]*sin(x[0] + u[8] - y[3]);
out[141] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[160] = -y[2]*y[5]*sin(x[0] + u[8] - y[3]) - y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[221] = p[26]*x[8];

}

void de_Gu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -1/p[0];
out[20] = -1/p[0];
out[40] = -1/p[0];
out[60] = -1/p[0];
out[202] = -p[25];
out[299] = -p[28];

}

void de_Gu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[82] = 1.0;
out[119] = 1.0;
out[184] = -1.0;
out[338] = -1.0;

}

void de_Hx_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[75] = ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(-p[39]*p[43]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2))*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[39]*(p[40]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) - p[41])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))))/(p[49]*pow(p[45], 3))
));
out[77] = ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(-p[39]*p[40]*p[46]*p[45]*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*u[17]*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) + p[39]*p[43]*p[46]*p[45]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*u[17]*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) + p[44]*p[46]*p[45]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
));
out[149] = p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]));
out[250] = -(y[21]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[22]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/pow(x[12], 2);
out[264] = -(y[12]*y[10] + y[13]*y[11])/pow(x[12] + 9.9999999999999995e-7, 2);

}

void de_Hx_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[95] = -p[23];
out[150] = p[31];

}

void de_Hx_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[44] = 1.0;
out[165] = 1.0;

}

void de_Hy_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[226] = y[12];
out[227] = y[13];
out[228] = y[10];
out[229] = y[11];
out[253] = y[13];
out[254] = -y[12];
out[255] = -y[11];
out[256] = y[10];
out[270] = p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]));
out[271] = p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]));
out[460] = (y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])) + y[22]*(-y[18]*cos(y[1]) - y[19]*sin(y[1])))/x[12];
out[477] = (y[21]*cos(y[1]) - y[22]*sin(y[1]))/x[12];
out[478] = (y[21]*sin(y[1]) + y[22]*cos(y[1]))/x[12];
out[480] = (y[18]*cos(y[1]) + y[19]*sin(y[1]))/x[12];
out[481] = (-y[18]*sin(y[1]) + y[19]*cos(y[1]))/x[12];
out[496] = y[12]/(x[12] + 9.9999999999999995e-7);
out[497] = y[13]/(x[12] + 9.9999999999999995e-7);
out[498] = y[10]/(x[12] + 9.9999999999999995e-7);
out[499] = y[11]/(x[12] + 9.9999999999999995e-7);

}

void de_Hy_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[209] = -p[24];

}

void de_Hy_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[29] = 1.0;
out[344] = 1.0;
out[374] = 1.0;
out[402] = 1.0;
out[426] = 1.0;
out[454] = 1.0;

}

void de_Hu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[112] = ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(p[39]*p[40]*p[46]*p[45]*x[7]*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*pow(u[17], 2)*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) - p[39]*p[43]*p[46]*p[45]*x[7]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*pow(u[17], 2)*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) - p[44]*p[46]*p[45]*x[7]/(p[47]*pow(u[17], 2)))/(p[49]*pow(p[45], 3)) + 3.0*p[48]*pow(u[17], 2)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
));

}

void de_Hu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[42] = 1.0;
out[93] = 1.0;

}

void sp_Fu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[3] = ((x[8] > 0.20000000000000001 && fabs(u[16]) > 0.01) ? (
   0
)
: (
   1.0
))*((u[10] < 0) ? (
   1.0
)
: (
   0
))/p[50];
out[6] = 0.5*((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(p[39]*p[40]*p[46]*p[45]*x[7]*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*pow(u[17], 2)*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) - p[39]*p[43]*p[46]*p[45]*x[7]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*pow(u[17], 2)*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) - p[44]*p[46]*p[45]*x[7]/(p[47]*pow(u[17], 2)))/(p[49]*pow(p[45], 3)) + 3.0*p[48]*pow(u[17], 2)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
))/(p[19]*x[7]);

}

void sp_Fu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = p[10];
out[4] = 1.0/p[16];

}

void sp_Fu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1] = 1.0;
out[2] = 1.0;
out[5] = -1.0;

}

void sp_Gu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[5] = -y[2]*cos(x[0] + u[8] - y[3]);
out[7] = y[2]*sin(x[0] + u[8] - y[3]);
out[8] = y[2]*y[5]*cos(x[0] + u[8] - y[3]) - y[2]*y[6]*sin(x[0] + u[8] - y[3]);
out[9] = -y[2]*y[5]*sin(x[0] + u[8] - y[3]) - y[2]*y[6]*cos(x[0] + u[8] - y[3]);
out[12] = p[26]*x[8];

}

void sp_Gu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -1/p[0];
out[1] = -1/p[0];
out[2] = -1/p[0];
out[3] = -1/p[0];
out[11] = -p[25];
out[13] = -p[28];

}

void sp_Gu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[4] = 1.0;
out[6] = 1.0;
out[10] = -1.0;
out[14] = -1.0;

}

void sp_Hx_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[1] = ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(-p[39]*p[43]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2))*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[39]*(p[40]*(0.10500000000000001*pow(x[5], 2)/pow(pow(x[5], 3) + 1.0, 2) - 0.080000000000000002/pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) - p[41])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))))/(p[49]*pow(p[45], 3))
));
out[2] = ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(-p[39]*p[40]*p[46]*p[45]*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*u[17]*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) + p[39]*p[43]*p[46]*p[45]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*u[17]*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) + p[44]*p[46]*p[45]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
));
out[4] = p[30]*(-y[0]*sin(y[1])*sin(x[9]) - y[0]*cos(y[1])*cos(x[9]));
out[7] = -(y[21]*(y[18]*cos(y[1]) + y[19]*sin(y[1])) + y[22]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])))/pow(x[12], 2);
out[8] = -(y[12]*y[10] + y[13]*y[11])/pow(x[12] + 9.9999999999999995e-7, 2);

}

void sp_Hx_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[3] = -p[23];
out[5] = p[31];

}

void sp_Hx_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[6] = 1.0;

}

void sp_Hy_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[3] = y[12];
out[4] = y[13];
out[5] = y[10];
out[6] = y[11];
out[7] = y[13];
out[8] = -y[12];
out[9] = -y[11];
out[10] = y[10];
out[11] = p[30]*(sin(y[1])*cos(x[9]) - sin(x[9])*cos(y[1]));
out[12] = p[30]*(y[0]*sin(y[1])*sin(x[9]) + y[0]*cos(y[1])*cos(x[9]));
out[18] = (y[21]*(-y[18]*sin(y[1]) + y[19]*cos(y[1])) + y[22]*(-y[18]*cos(y[1]) - y[19]*sin(y[1])))/x[12];
out[19] = (y[21]*cos(y[1]) - y[22]*sin(y[1]))/x[12];
out[20] = (y[21]*sin(y[1]) + y[22]*cos(y[1]))/x[12];
out[21] = (y[18]*cos(y[1]) + y[19]*sin(y[1]))/x[12];
out[22] = (-y[18]*sin(y[1]) + y[19]*cos(y[1]))/x[12];
out[23] = y[12]/(x[12] + 9.9999999999999995e-7);
out[24] = y[13]/(x[12] + 9.9999999999999995e-7);
out[25] = y[10]/(x[12] + 9.9999999999999995e-7);
out[26] = y[11]/(x[12] + 9.9999999999999995e-7);

}

void sp_Hy_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[2] = -p[24];

}

void sp_Hy_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[1] = 1.0;
out[13] = 1.0;
out[14] = 1.0;
out[15] = 1.0;
out[16] = 1.0;
out[17] = 1.0;

}

void sp_Hu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[2] = ((p[48]*pow(u[17], 3)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3)) < 0) ? (
   0
)
: (
   p[48]*pow(u[17], 3)*(p[39]*p[40]*p[46]*p[45]*x[7]*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*pow(u[17], 2)*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) - p[39]*p[43]*p[46]*p[45]*x[7]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)))/(p[47]*pow(u[17], 2)*pow(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5], 2)) - p[44]*p[46]*p[45]*x[7]/(p[47]*pow(u[17], 2)))/(p[49]*pow(p[45], 3)) + 3.0*p[48]*pow(u[17], 2)*(p[39]*(p[40]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0)) - p[41]*x[5] - p[42])*exp(-p[43]*(1.0/(p[46]*p[45]*x[7]/(p[47]*u[17]) + 0.080000000000000002*x[5]) - 0.035000000000000003/(pow(x[5], 3) + 1.0))) + p[44]*p[46]*p[45]*x[7]/(p[47]*u[17]))/(p[49]*pow(p[45], 3))
));

}

void sp_Hu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[1] = 1.0;

}



/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // void()(double *, double *, double *, double *, double *, double)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 6), // double *
/*  2 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  3 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  4 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  5 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  6 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14), // double
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  8 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static void _cffi_d_de_Fu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_num_eval _cffi_d_de_Fu_run_num_eval
#endif

static void _cffi_d_de_Fu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_up_eval _cffi_d_de_Fu_run_up_eval
#endif

static void _cffi_d_de_Fu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_xy_eval _cffi_d_de_Fu_run_xy_eval
#endif

static void _cffi_d_de_Gu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_num_eval _cffi_d_de_Gu_run_num_eval
#endif

static void _cffi_d_de_Gu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_up_eval _cffi_d_de_Gu_run_up_eval
#endif

static void _cffi_d_de_Gu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_xy_eval _cffi_d_de_Gu_run_xy_eval
#endif

static void _cffi_d_de_Hu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_num_eval _cffi_d_de_Hu_run_num_eval
#endif

static void _cffi_d_de_Hu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_up_eval _cffi_d_de_Hu_run_up_eval
#endif

static void _cffi_d_de_Hu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_xy_eval _cffi_d_de_Hu_run_xy_eval
#endif

static void _cffi_d_de_Hx_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_num_eval _cffi_d_de_Hx_run_num_eval
#endif

static void _cffi_d_de_Hx_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_up_eval _cffi_d_de_Hx_run_up_eval
#endif

static void _cffi_d_de_Hx_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_xy_eval _cffi_d_de_Hx_run_xy_eval
#endif

static void _cffi_d_de_Hy_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_num_eval _cffi_d_de_Hy_run_num_eval
#endif

static void _cffi_d_de_Hy_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_up_eval _cffi_d_de_Hy_run_up_eval
#endif

static void _cffi_d_de_Hy_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_xy_eval _cffi_d_de_Hy_run_xy_eval
#endif

static void _cffi_d_de_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_num_eval _cffi_d_de_jac_ini_num_eval
#endif

static void _cffi_d_de_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_up_eval _cffi_d_de_jac_ini_up_eval
#endif

static void _cffi_d_de_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_xy_eval _cffi_d_de_jac_ini_xy_eval
#endif

static void _cffi_d_de_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_num_eval _cffi_d_de_jac_run_num_eval
#endif

static void _cffi_d_de_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_up_eval _cffi_d_de_jac_run_up_eval
#endif

static void _cffi_d_de_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_xy_eval _cffi_d_de_jac_run_xy_eval
#endif

static void _cffi_d_de_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_num_eval _cffi_d_de_jac_trap_num_eval
#endif

static void _cffi_d_de_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_up_eval _cffi_d_de_jac_trap_up_eval
#endif

static void _cffi_d_de_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_xy_eval _cffi_d_de_jac_trap_xy_eval
#endif

static void _cffi_d_f_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_ini_eval _cffi_d_f_ini_eval
#endif

static void _cffi_d_f_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_run_eval _cffi_d_f_run_eval
#endif

static void _cffi_d_g_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_ini_eval _cffi_d_g_ini_eval
#endif

static void _cffi_d_g_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_run_eval _cffi_d_g_run_eval
#endif

static void _cffi_d_h_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  h_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_h_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "h_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { h_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_h_eval _cffi_d_h_eval
#endif

static void _cffi_d_sp_Fu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_num_eval _cffi_d_sp_Fu_run_num_eval
#endif

static void _cffi_d_sp_Fu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_up_eval _cffi_d_sp_Fu_run_up_eval
#endif

static void _cffi_d_sp_Fu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_xy_eval _cffi_d_sp_Fu_run_xy_eval
#endif

static void _cffi_d_sp_Gu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_num_eval _cffi_d_sp_Gu_run_num_eval
#endif

static void _cffi_d_sp_Gu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_up_eval _cffi_d_sp_Gu_run_up_eval
#endif

static void _cffi_d_sp_Gu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_xy_eval _cffi_d_sp_Gu_run_xy_eval
#endif

static void _cffi_d_sp_Hu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_num_eval _cffi_d_sp_Hu_run_num_eval
#endif

static void _cffi_d_sp_Hu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_up_eval _cffi_d_sp_Hu_run_up_eval
#endif

static void _cffi_d_sp_Hu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_xy_eval _cffi_d_sp_Hu_run_xy_eval
#endif

static void _cffi_d_sp_Hx_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_num_eval _cffi_d_sp_Hx_run_num_eval
#endif

static void _cffi_d_sp_Hx_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_up_eval _cffi_d_sp_Hx_run_up_eval
#endif

static void _cffi_d_sp_Hx_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_xy_eval _cffi_d_sp_Hx_run_xy_eval
#endif

static void _cffi_d_sp_Hy_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_num_eval _cffi_d_sp_Hy_run_num_eval
#endif

static void _cffi_d_sp_Hy_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_up_eval _cffi_d_sp_Hy_run_up_eval
#endif

static void _cffi_d_sp_Hy_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_xy_eval _cffi_d_sp_Hy_run_xy_eval
#endif

static void _cffi_d_sp_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_num_eval _cffi_d_sp_jac_ini_num_eval
#endif

static void _cffi_d_sp_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_up_eval _cffi_d_sp_jac_ini_up_eval
#endif

static void _cffi_d_sp_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_xy_eval _cffi_d_sp_jac_ini_xy_eval
#endif

static void _cffi_d_sp_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_num_eval _cffi_d_sp_jac_run_num_eval
#endif

static void _cffi_d_sp_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_up_eval _cffi_d_sp_jac_run_up_eval
#endif

static void _cffi_d_sp_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_xy_eval _cffi_d_sp_jac_run_xy_eval
#endif

static void _cffi_d_sp_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_num_eval _cffi_d_sp_jac_trap_num_eval
#endif

static void _cffi_d_sp_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_up_eval _cffi_d_sp_jac_trap_up_eval
#endif

static void _cffi_d_sp_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_xy_eval _cffi_d_sp_jac_trap_xy_eval
#endif

static const struct _cffi_global_s _cffi_globals[] = {
  { "de_Fu_run_num_eval", (void *)_cffi_f_de_Fu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_num_eval },
  { "de_Fu_run_up_eval", (void *)_cffi_f_de_Fu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_up_eval },
  { "de_Fu_run_xy_eval", (void *)_cffi_f_de_Fu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_xy_eval },
  { "de_Gu_run_num_eval", (void *)_cffi_f_de_Gu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_num_eval },
  { "de_Gu_run_up_eval", (void *)_cffi_f_de_Gu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_up_eval },
  { "de_Gu_run_xy_eval", (void *)_cffi_f_de_Gu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_xy_eval },
  { "de_Hu_run_num_eval", (void *)_cffi_f_de_Hu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_num_eval },
  { "de_Hu_run_up_eval", (void *)_cffi_f_de_Hu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_up_eval },
  { "de_Hu_run_xy_eval", (void *)_cffi_f_de_Hu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_xy_eval },
  { "de_Hx_run_num_eval", (void *)_cffi_f_de_Hx_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_num_eval },
  { "de_Hx_run_up_eval", (void *)_cffi_f_de_Hx_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_up_eval },
  { "de_Hx_run_xy_eval", (void *)_cffi_f_de_Hx_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_xy_eval },
  { "de_Hy_run_num_eval", (void *)_cffi_f_de_Hy_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_num_eval },
  { "de_Hy_run_up_eval", (void *)_cffi_f_de_Hy_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_up_eval },
  { "de_Hy_run_xy_eval", (void *)_cffi_f_de_Hy_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_xy_eval },
  { "de_jac_ini_num_eval", (void *)_cffi_f_de_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_num_eval },
  { "de_jac_ini_up_eval", (void *)_cffi_f_de_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_up_eval },
  { "de_jac_ini_xy_eval", (void *)_cffi_f_de_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_xy_eval },
  { "de_jac_run_num_eval", (void *)_cffi_f_de_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_num_eval },
  { "de_jac_run_up_eval", (void *)_cffi_f_de_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_up_eval },
  { "de_jac_run_xy_eval", (void *)_cffi_f_de_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_xy_eval },
  { "de_jac_trap_num_eval", (void *)_cffi_f_de_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_num_eval },
  { "de_jac_trap_up_eval", (void *)_cffi_f_de_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_up_eval },
  { "de_jac_trap_xy_eval", (void *)_cffi_f_de_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_xy_eval },
  { "f_ini_eval", (void *)_cffi_f_f_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_ini_eval },
  { "f_run_eval", (void *)_cffi_f_f_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_run_eval },
  { "g_ini_eval", (void *)_cffi_f_g_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_ini_eval },
  { "g_run_eval", (void *)_cffi_f_g_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_run_eval },
  { "h_eval", (void *)_cffi_f_h_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_h_eval },
  { "sp_Fu_run_num_eval", (void *)_cffi_f_sp_Fu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_num_eval },
  { "sp_Fu_run_up_eval", (void *)_cffi_f_sp_Fu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_up_eval },
  { "sp_Fu_run_xy_eval", (void *)_cffi_f_sp_Fu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_xy_eval },
  { "sp_Gu_run_num_eval", (void *)_cffi_f_sp_Gu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_num_eval },
  { "sp_Gu_run_up_eval", (void *)_cffi_f_sp_Gu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_up_eval },
  { "sp_Gu_run_xy_eval", (void *)_cffi_f_sp_Gu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_xy_eval },
  { "sp_Hu_run_num_eval", (void *)_cffi_f_sp_Hu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_num_eval },
  { "sp_Hu_run_up_eval", (void *)_cffi_f_sp_Hu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_up_eval },
  { "sp_Hu_run_xy_eval", (void *)_cffi_f_sp_Hu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_xy_eval },
  { "sp_Hx_run_num_eval", (void *)_cffi_f_sp_Hx_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_num_eval },
  { "sp_Hx_run_up_eval", (void *)_cffi_f_sp_Hx_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_up_eval },
  { "sp_Hx_run_xy_eval", (void *)_cffi_f_sp_Hx_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_xy_eval },
  { "sp_Hy_run_num_eval", (void *)_cffi_f_sp_Hy_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_num_eval },
  { "sp_Hy_run_up_eval", (void *)_cffi_f_sp_Hy_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_up_eval },
  { "sp_Hy_run_xy_eval", (void *)_cffi_f_sp_Hy_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_xy_eval },
  { "sp_jac_ini_num_eval", (void *)_cffi_f_sp_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_num_eval },
  { "sp_jac_ini_up_eval", (void *)_cffi_f_sp_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_up_eval },
  { "sp_jac_ini_xy_eval", (void *)_cffi_f_sp_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_xy_eval },
  { "sp_jac_run_num_eval", (void *)_cffi_f_sp_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_num_eval },
  { "sp_jac_run_up_eval", (void *)_cffi_f_sp_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_up_eval },
  { "sp_jac_run_xy_eval", (void *)_cffi_f_sp_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_xy_eval },
  { "sp_jac_trap_num_eval", (void *)_cffi_f_sp_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_num_eval },
  { "sp_jac_trap_up_eval", (void *)_cffi_f_sp_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_up_eval },
  { "sp_jac_trap_xy_eval", (void *)_cffi_f_sp_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_xy_eval },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  NULL,  /* no fields */
  NULL,  /* no struct_unions */
  NULL,  /* no enums */
  NULL,  /* no typenames */
  53,  /* num_globals */
  0,  /* num_struct_unions */
  0,  /* num_enums */
  0,  /* num_typenames */
  NULL,  /* no includes */
  9,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit_pmsm_test_cffi(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit_pmsm_test_cffi(void) { return NULL; }
#  else
     initpmsm_test_cffi(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit_pmsm_test_cffi(void)
{
  return _cffi_init("pmsm_test_cffi", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
initpmsm_test_cffi(void)
{
  _cffi_init("pmsm_test_cffi", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
