#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/

void f_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -2.7777777777777776e-7*y[26]*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0*x[0] + 600.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0*x[0] + 620.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258*x[0] + 673.33333333333326
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0*x[0] + 620.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0*x[0] + 350.0
)
: (
   750
))))))/(p[13]*y[27]);
out[1] = -x[0] + u[2];
out[2] = -p[23]*x[2] - y[49] + u[17] + 1;

}
void g_ini_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 94.615102344455664*y[1] + 184.75059629806526*y[0] - 17.974903844364835*y[3] - 69.368640085185305*y[2] - 40.748687841669557*y[5] - 43.675799641021079*y[4] - 17.974903844364821*y[7] - 69.368640085185291*y[6] - 94.615102344455664*y[9] - 184.75059629806526*y[8] + 17.974903844364835*y[11] + 69.368640085185305*y[10] + 40.748687841669557*y[13] + 43.675799641021079*y[12] + 17.974903844364821*y[15] + 69.368640085185291*y[14] - y[16];
out[1] = 184.75059629806526*y[1] - 94.615102344455664*y[0] - 69.368640085185305*y[3] + 17.974903844364835*y[2] - 43.675799641021079*y[5] + 40.748687841669557*y[4] - 69.368640085185291*y[7] + 17.974903844364821*y[6] - 184.75059629806526*y[9] + 94.615102344455664*y[8] + 69.368640085185305*y[11] - 17.974903844364835*y[10] + 43.675799641021079*y[13] - 40.748687841669557*y[12] + 69.368640085185291*y[15] - 17.974903844364821*y[14] - y[21];
out[2] = -17.974903844364825*y[1] - 69.368640085185291*y[0] + 94.615102344455636*y[3] + 184.7505962980652*y[2] - 17.97490384436481*y[5] - 69.368640085185319*y[4] - 40.748687841669565*y[7] - 43.675799641021079*y[6] + 17.974903844364825*y[9] + 69.368640085185291*y[8] - 94.615102344455636*y[11] - 184.7505962980652*y[10] + 17.97490384436481*y[13] + 69.368640085185319*y[12] + 40.748687841669565*y[15] + 43.675799641021079*y[14] - y[17];
out[3] = -69.368640085185291*y[1] + 17.974903844364825*y[0] + 184.7505962980652*y[3] - 94.615102344455636*y[2] - 69.368640085185319*y[5] + 17.97490384436481*y[4] - 43.675799641021079*y[7] + 40.748687841669565*y[6] + 69.368640085185291*y[9] - 17.974903844364825*y[8] - 184.7505962980652*y[11] + 94.615102344455636*y[10] + 69.368640085185319*y[13] - 17.97490384436481*y[12] + 43.675799641021079*y[15] - 40.748687841669565*y[14] - y[22];
out[4] = -40.748687841669579*y[1] - 43.675799641021101*y[0] - 17.974903844364821*y[3] - 69.368640085185305*y[2] + 94.61510234445565*y[5] + 184.75059629806526*y[4] - 17.974903844364821*y[7] - 69.368640085185305*y[6] + 40.748687841669579*y[9] + 43.675799641021101*y[8] + 17.974903844364821*y[11] + 69.368640085185305*y[10] - 94.61510234445565*y[13] - 184.75059629806526*y[12] + 17.974903844364821*y[15] + 69.368640085185305*y[14] - y[18];
out[5] = -43.675799641021101*y[1] + 40.748687841669579*y[0] - 69.368640085185305*y[3] + 17.974903844364821*y[2] + 184.75059629806526*y[5] - 94.61510234445565*y[4] - 69.368640085185305*y[7] + 17.974903844364821*y[6] + 43.675799641021101*y[9] - 40.748687841669579*y[8] + 69.368640085185305*y[11] - 17.974903844364821*y[10] - 184.75059629806526*y[13] + 94.61510234445565*y[12] + 69.368640085185305*y[15] - 17.974903844364821*y[14] - y[23];
out[6] = -17.974903844364825*y[1] - 69.368640085185305*y[0] - 40.74868784166955*y[3] - 43.675799641021079*y[2] - 17.974903844364839*y[5] - 69.368640085185291*y[4] + 94.61510234445565*y[7] + 184.7505962980652*y[6] + 17.974903844364825*y[9] + 69.368640085185305*y[8] + 40.74868784166955*y[11] + 43.675799641021079*y[10] + 17.974903844364839*y[13] + 69.368640085185291*y[12] - 94.61510234445565*y[15] - 184.7505962980652*y[14] - y[19];
out[7] = -69.368640085185305*y[1] + 17.974903844364825*y[0] - 43.675799641021079*y[3] + 40.74868784166955*y[2] - 69.368640085185291*y[5] + 17.974903844364839*y[4] + 184.7505962980652*y[7] - 94.61510234445565*y[6] + 69.368640085185305*y[9] - 17.974903844364825*y[8] + 43.675799641021079*y[11] - 40.74868784166955*y[10] + 69.368640085185291*y[13] - 17.974903844364839*y[12] - 184.7505962980652*y[15] + 94.61510234445565*y[14] - y[24];
out[8] = -94.615102344455664*y[1] - 184.75059629806526*y[0] + 17.974903844364835*y[3] + 69.368640085185305*y[2] + 40.748687841669557*y[5] + 43.675799641021079*y[4] + 17.974903844364821*y[7] + 69.368640085185291*y[6] + 94.615102344455664*y[9] + 184.75059629806526*y[8] - 17.974903844364835*y[11] - 69.368640085185305*y[10] - 40.748687841669557*y[13] - 43.675799641021079*y[12] - 17.974903844364821*y[15] - 69.368640085185291*y[14] - y[41];
out[9] = -184.75059629806526*y[1] + 94.615102344455664*y[0] + 69.368640085185305*y[3] - 17.974903844364835*y[2] + 43.675799641021079*y[5] - 40.748687841669557*y[4] + 69.368640085185291*y[7] - 17.974903844364821*y[6] + 184.75059629806526*y[9] - 94.615102344455664*y[8] - 69.368640085185305*y[11] + 17.974903844364835*y[10] - 43.675799641021079*y[13] + 40.748687841669557*y[12] - 69.368640085185291*y[15] + 17.974903844364821*y[14] - y[45];
out[10] = 17.974903844364825*y[1] + 69.368640085185291*y[0] - 94.615102344455636*y[3] - 184.7505962980652*y[2] + 17.97490384436481*y[5] + 69.368640085185319*y[4] + 40.748687841669565*y[7] + 43.675799641021079*y[6] - 17.974903844364825*y[9] - 69.368640085185291*y[8] + 94.615102344455636*y[11] + 184.7505962980652*y[10] - 17.97490384436481*y[13] - 69.368640085185319*y[12] - 40.748687841669565*y[15] - 43.675799641021079*y[14] - y[42];
out[11] = 69.368640085185291*y[1] - 17.974903844364825*y[0] - 184.7505962980652*y[3] + 94.615102344455636*y[2] + 69.368640085185319*y[5] - 17.97490384436481*y[4] + 43.675799641021079*y[7] - 40.748687841669565*y[6] - 69.368640085185291*y[9] + 17.974903844364825*y[8] + 184.7505962980652*y[11] - 94.615102344455636*y[10] - 69.368640085185319*y[13] + 17.97490384436481*y[12] - 43.675799641021079*y[15] + 40.748687841669565*y[14] - y[46];
out[12] = 40.748687841669579*y[1] + 43.675799641021101*y[0] + 17.974903844364821*y[3] + 69.368640085185305*y[2] - 94.61510234445565*y[5] - 184.75059629806526*y[4] + 17.974903844364821*y[7] + 69.368640085185305*y[6] - 40.748687841669579*y[9] - 43.675799641021101*y[8] - 17.974903844364821*y[11] - 69.368640085185305*y[10] + 94.61510234445565*y[13] + 184.75059629806526*y[12] - 17.974903844364821*y[15] - 69.368640085185305*y[14] - y[43];
out[13] = 43.675799641021101*y[1] - 40.748687841669579*y[0] + 69.368640085185305*y[3] - 17.974903844364821*y[2] - 184.75059629806526*y[5] + 94.61510234445565*y[4] + 69.368640085185305*y[7] - 17.974903844364821*y[6] - 43.675799641021101*y[9] + 40.748687841669579*y[8] - 69.368640085185305*y[11] + 17.974903844364821*y[10] + 184.75059629806526*y[13] - 94.61510234445565*y[12] - 69.368640085185305*y[15] + 17.974903844364821*y[14] - y[47];
out[14] = 17.974903844364825*y[1] + 69.368640085185305*y[0] + 40.74868784166955*y[3] + 43.675799641021079*y[2] + 17.974903844364839*y[5] + 69.368640085185291*y[4] - 94.61510234445565*y[7] - 184.7505962980652*y[6] - 17.974903844364825*y[9] - 69.368640085185305*y[8] - 40.74868784166955*y[11] - 43.675799641021079*y[10] - 17.974903844364839*y[13] - 69.368640085185291*y[12] + 94.61510234445565*y[15] + 184.7505962980652*y[14] - y[44];
out[15] = 69.368640085185305*y[1] - 17.974903844364825*y[0] + 43.675799641021079*y[3] - 40.74868784166955*y[2] + 69.368640085185291*y[5] - 17.974903844364839*y[4] - 184.7505962980652*y[7] + 94.61510234445565*y[6] - 69.368640085185305*y[9] + 17.974903844364825*y[8] - 43.675799641021079*y[11] + 40.74868784166955*y[10] - 69.368640085185291*y[13] + 17.974903844364839*y[12] + 184.7505962980652*y[15] - 94.61510234445565*y[14] - y[48];
out[16] = -p[1]*y[16] - y[0] + 1.0*p[0]*y[21] + y[20] + y[35];
out[17] = -p[1]*y[17] - y[2] + 1.0*p[0]*y[22] + y[20] + y[36];
out[18] = -p[1]*y[18] - y[4] + 1.0*p[0]*y[23] + y[20] + y[37];
out[19] = -p[3]*y[19] - y[6] + 1.0*p[2]*y[24] + y[20] + u[0];
out[20] = p[5]*y[20]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + 1.0*p[4]*y[25]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + y[16] + y[17] + y[18] + y[19];
out[21] = -1.0*p[1]*y[21] - 1.0*y[1] - 1.0*p[0]*y[16] + 1.0*y[25] + 1.0*y[38];
out[22] = -1.0*p[1]*y[22] - 1.0*y[3] - 1.0*p[0]*y[17] + 1.0*y[25] + 1.0*y[39];
out[23] = -1.0*p[1]*y[23] - 1.0*y[5] - 1.0*p[0]*y[18] + 1.0*y[25] + 1.0*y[40];
out[24] = -1.0*p[3]*y[24] - 1.0*y[7] - 1.0*p[2]*y[19] + 1.0*y[25] + 1.0*u[1];
out[25] = 1.0*p[5]*y[25]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) - 1.0*p[4]*y[20]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + 1.0*y[21] + 1.0*y[22] + 1.0*y[23] + 1.0*y[24];
out[26] = p[6]*(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7) + 4*p[8] + 1.0*y[21]*y[38] + y[16]*y[35] + 1.0*y[22]*y[39] + y[17]*y[36] + 1.0*y[23]*y[40] + 1.0*y[23]*u[1] + y[18]*y[37] + y[18]*u[0] - y[26];
out[27] = -p[14]*y[26]/y[27] - y[27] + ((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0*x[0] + 600.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0*x[0] + 620.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258*x[0] + 673.33333333333326
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0*x[0] + 620.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0*x[0] + 350.0
)
: (
   750
))))));
out[28] = -p[10]*x[1] - p[9]*(-x[0] + u[2]) - y[28];
out[29] = -1.0*y[1]*y[32] - y[0]*y[29] + u[3] + (1.0/3.0)*u[6] + (1.0/3.0)*y[28];
out[30] = -1.0*y[3]*y[33] - y[2]*y[30] + u[4] + (1.0/3.0)*u[6] + (1.0/3.0)*y[28];
out[31] = -1.0*y[5]*y[34] - y[4]*y[31] + u[5] + (1.0/3.0)*u[6] + (1.0/3.0)*y[28];
out[32] = -1.0*y[1]*y[29] + 1.0*y[0]*y[32] + u[8] + (1.0/3.0)*u[11];
out[33] = -1.0*y[3]*y[30] + 1.0*y[2]*y[33] + u[9] + (1.0/3.0)*u[11];
out[34] = -1.0*y[5]*y[31] + 1.0*y[4]*y[34] + u[10] + (1.0/3.0)*u[11];
out[35] = -p[1]*y[29] - y[0] + 1.0*p[0]*y[32] + y[35];
out[36] = -p[1]*y[30] - y[2] + 1.0*p[0]*y[33] + y[36];
out[37] = -p[1]*y[31] - y[4] + 1.0*p[0]*y[34] + y[37];
out[38] = -1.0*p[1]*y[32] - 1.0*y[1] - p[0]*y[29] + 1.0*y[38];
out[39] = -1.0*p[1]*y[33] - 1.0*y[3] - p[0]*y[30] + 1.0*y[39];
out[40] = -1.0*p[1]*y[34] - 1.0*y[5] - p[0]*y[31] + 1.0*y[40];
out[41] = -p[16]*y[41] - y[8] + 1.0*p[15]*y[45] + u[12]*cos(u[16]);
out[42] = -p[16]*y[42] - y[10] + 1.0*p[15]*y[46] + u[13]*cos(u[16] - 2.0943951023931953);
out[43] = -p[16]*y[43] - y[12] + 1.0*p[15]*y[47] + u[14]*cos(u[16] - 4.1887902047863905);
out[44] = -p[18]*y[44] - y[14] + 1.0*p[17]*y[48];
out[45] = -1.0*p[16]*y[45] - 1.0*y[9] - 1.0*p[15]*y[41] + 1.0*u[12]*sin(u[16]);
out[46] = -1.0*p[16]*y[46] - 1.0*y[11] - 1.0*p[15]*y[42] + 1.0*u[13]*sin(u[16] - 2.0943951023931953);
out[47] = -1.0*p[16]*y[47] - 1.0*y[13] - 1.0*p[15]*y[43] + 1.0*u[14]*sin(u[16] - 4.1887902047863905);
out[48] = -1.0*p[18]*y[48] - 1.0*y[15] - 1.0*p[17]*y[44];
out[49] = 1.0 - y[49];
out[50] = p[22]*x[2] + p[21]*(1 - y[49]) - y[50];

}
void f_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -2.7777777777777776e-7*y[26]*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0*x[0] + 600.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0*x[0] + 620.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258*x[0] + 673.33333333333326
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0*x[0] + 620.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0*x[0] + 350.0
)
: (
   750
))))))/(p[13]*y[27]);
out[1] = -x[0] + u[2];
out[2] = -p[23]*x[2] - y[49] + u[17] + 1;

}
void g_run_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 94.615102344455664*y[1] + 184.75059629806526*y[0] - 17.974903844364835*y[3] - 69.368640085185305*y[2] - 40.748687841669557*y[5] - 43.675799641021079*y[4] - 17.974903844364821*y[7] - 69.368640085185291*y[6] - 94.615102344455664*y[9] - 184.75059629806526*y[8] + 17.974903844364835*y[11] + 69.368640085185305*y[10] + 40.748687841669557*y[13] + 43.675799641021079*y[12] + 17.974903844364821*y[15] + 69.368640085185291*y[14] - y[16];
out[1] = 184.75059629806526*y[1] - 94.615102344455664*y[0] - 69.368640085185305*y[3] + 17.974903844364835*y[2] - 43.675799641021079*y[5] + 40.748687841669557*y[4] - 69.368640085185291*y[7] + 17.974903844364821*y[6] - 184.75059629806526*y[9] + 94.615102344455664*y[8] + 69.368640085185305*y[11] - 17.974903844364835*y[10] + 43.675799641021079*y[13] - 40.748687841669557*y[12] + 69.368640085185291*y[15] - 17.974903844364821*y[14] - y[21];
out[2] = -17.974903844364825*y[1] - 69.368640085185291*y[0] + 94.615102344455636*y[3] + 184.7505962980652*y[2] - 17.97490384436481*y[5] - 69.368640085185319*y[4] - 40.748687841669565*y[7] - 43.675799641021079*y[6] + 17.974903844364825*y[9] + 69.368640085185291*y[8] - 94.615102344455636*y[11] - 184.7505962980652*y[10] + 17.97490384436481*y[13] + 69.368640085185319*y[12] + 40.748687841669565*y[15] + 43.675799641021079*y[14] - y[17];
out[3] = -69.368640085185291*y[1] + 17.974903844364825*y[0] + 184.7505962980652*y[3] - 94.615102344455636*y[2] - 69.368640085185319*y[5] + 17.97490384436481*y[4] - 43.675799641021079*y[7] + 40.748687841669565*y[6] + 69.368640085185291*y[9] - 17.974903844364825*y[8] - 184.7505962980652*y[11] + 94.615102344455636*y[10] + 69.368640085185319*y[13] - 17.97490384436481*y[12] + 43.675799641021079*y[15] - 40.748687841669565*y[14] - y[22];
out[4] = -40.748687841669579*y[1] - 43.675799641021101*y[0] - 17.974903844364821*y[3] - 69.368640085185305*y[2] + 94.61510234445565*y[5] + 184.75059629806526*y[4] - 17.974903844364821*y[7] - 69.368640085185305*y[6] + 40.748687841669579*y[9] + 43.675799641021101*y[8] + 17.974903844364821*y[11] + 69.368640085185305*y[10] - 94.61510234445565*y[13] - 184.75059629806526*y[12] + 17.974903844364821*y[15] + 69.368640085185305*y[14] - y[18];
out[5] = -43.675799641021101*y[1] + 40.748687841669579*y[0] - 69.368640085185305*y[3] + 17.974903844364821*y[2] + 184.75059629806526*y[5] - 94.61510234445565*y[4] - 69.368640085185305*y[7] + 17.974903844364821*y[6] + 43.675799641021101*y[9] - 40.748687841669579*y[8] + 69.368640085185305*y[11] - 17.974903844364821*y[10] - 184.75059629806526*y[13] + 94.61510234445565*y[12] + 69.368640085185305*y[15] - 17.974903844364821*y[14] - y[23];
out[6] = -17.974903844364825*y[1] - 69.368640085185305*y[0] - 40.74868784166955*y[3] - 43.675799641021079*y[2] - 17.974903844364839*y[5] - 69.368640085185291*y[4] + 94.61510234445565*y[7] + 184.7505962980652*y[6] + 17.974903844364825*y[9] + 69.368640085185305*y[8] + 40.74868784166955*y[11] + 43.675799641021079*y[10] + 17.974903844364839*y[13] + 69.368640085185291*y[12] - 94.61510234445565*y[15] - 184.7505962980652*y[14] - y[19];
out[7] = -69.368640085185305*y[1] + 17.974903844364825*y[0] - 43.675799641021079*y[3] + 40.74868784166955*y[2] - 69.368640085185291*y[5] + 17.974903844364839*y[4] + 184.7505962980652*y[7] - 94.61510234445565*y[6] + 69.368640085185305*y[9] - 17.974903844364825*y[8] + 43.675799641021079*y[11] - 40.74868784166955*y[10] + 69.368640085185291*y[13] - 17.974903844364839*y[12] - 184.7505962980652*y[15] + 94.61510234445565*y[14] - y[24];
out[8] = -94.615102344455664*y[1] - 184.75059629806526*y[0] + 17.974903844364835*y[3] + 69.368640085185305*y[2] + 40.748687841669557*y[5] + 43.675799641021079*y[4] + 17.974903844364821*y[7] + 69.368640085185291*y[6] + 94.615102344455664*y[9] + 184.75059629806526*y[8] - 17.974903844364835*y[11] - 69.368640085185305*y[10] - 40.748687841669557*y[13] - 43.675799641021079*y[12] - 17.974903844364821*y[15] - 69.368640085185291*y[14] - y[41];
out[9] = -184.75059629806526*y[1] + 94.615102344455664*y[0] + 69.368640085185305*y[3] - 17.974903844364835*y[2] + 43.675799641021079*y[5] - 40.748687841669557*y[4] + 69.368640085185291*y[7] - 17.974903844364821*y[6] + 184.75059629806526*y[9] - 94.615102344455664*y[8] - 69.368640085185305*y[11] + 17.974903844364835*y[10] - 43.675799641021079*y[13] + 40.748687841669557*y[12] - 69.368640085185291*y[15] + 17.974903844364821*y[14] - y[45];
out[10] = 17.974903844364825*y[1] + 69.368640085185291*y[0] - 94.615102344455636*y[3] - 184.7505962980652*y[2] + 17.97490384436481*y[5] + 69.368640085185319*y[4] + 40.748687841669565*y[7] + 43.675799641021079*y[6] - 17.974903844364825*y[9] - 69.368640085185291*y[8] + 94.615102344455636*y[11] + 184.7505962980652*y[10] - 17.97490384436481*y[13] - 69.368640085185319*y[12] - 40.748687841669565*y[15] - 43.675799641021079*y[14] - y[42];
out[11] = 69.368640085185291*y[1] - 17.974903844364825*y[0] - 184.7505962980652*y[3] + 94.615102344455636*y[2] + 69.368640085185319*y[5] - 17.97490384436481*y[4] + 43.675799641021079*y[7] - 40.748687841669565*y[6] - 69.368640085185291*y[9] + 17.974903844364825*y[8] + 184.7505962980652*y[11] - 94.615102344455636*y[10] - 69.368640085185319*y[13] + 17.97490384436481*y[12] - 43.675799641021079*y[15] + 40.748687841669565*y[14] - y[46];
out[12] = 40.748687841669579*y[1] + 43.675799641021101*y[0] + 17.974903844364821*y[3] + 69.368640085185305*y[2] - 94.61510234445565*y[5] - 184.75059629806526*y[4] + 17.974903844364821*y[7] + 69.368640085185305*y[6] - 40.748687841669579*y[9] - 43.675799641021101*y[8] - 17.974903844364821*y[11] - 69.368640085185305*y[10] + 94.61510234445565*y[13] + 184.75059629806526*y[12] - 17.974903844364821*y[15] - 69.368640085185305*y[14] - y[43];
out[13] = 43.675799641021101*y[1] - 40.748687841669579*y[0] + 69.368640085185305*y[3] - 17.974903844364821*y[2] - 184.75059629806526*y[5] + 94.61510234445565*y[4] + 69.368640085185305*y[7] - 17.974903844364821*y[6] - 43.675799641021101*y[9] + 40.748687841669579*y[8] - 69.368640085185305*y[11] + 17.974903844364821*y[10] + 184.75059629806526*y[13] - 94.61510234445565*y[12] - 69.368640085185305*y[15] + 17.974903844364821*y[14] - y[47];
out[14] = 17.974903844364825*y[1] + 69.368640085185305*y[0] + 40.74868784166955*y[3] + 43.675799641021079*y[2] + 17.974903844364839*y[5] + 69.368640085185291*y[4] - 94.61510234445565*y[7] - 184.7505962980652*y[6] - 17.974903844364825*y[9] - 69.368640085185305*y[8] - 40.74868784166955*y[11] - 43.675799641021079*y[10] - 17.974903844364839*y[13] - 69.368640085185291*y[12] + 94.61510234445565*y[15] + 184.7505962980652*y[14] - y[44];
out[15] = 69.368640085185305*y[1] - 17.974903844364825*y[0] + 43.675799641021079*y[3] - 40.74868784166955*y[2] + 69.368640085185291*y[5] - 17.974903844364839*y[4] - 184.7505962980652*y[7] + 94.61510234445565*y[6] - 69.368640085185305*y[9] + 17.974903844364825*y[8] - 43.675799641021079*y[11] + 40.74868784166955*y[10] - 69.368640085185291*y[13] + 17.974903844364839*y[12] + 184.7505962980652*y[15] - 94.61510234445565*y[14] - y[48];
out[16] = -p[1]*y[16] - y[0] + 1.0*p[0]*y[21] + y[20] + y[35];
out[17] = -p[1]*y[17] - y[2] + 1.0*p[0]*y[22] + y[20] + y[36];
out[18] = -p[1]*y[18] - y[4] + 1.0*p[0]*y[23] + y[20] + y[37];
out[19] = -p[3]*y[19] - y[6] + 1.0*p[2]*y[24] + y[20] + u[0];
out[20] = p[5]*y[20]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + 1.0*p[4]*y[25]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + y[16] + y[17] + y[18] + y[19];
out[21] = -1.0*p[1]*y[21] - 1.0*y[1] - 1.0*p[0]*y[16] + 1.0*y[25] + 1.0*y[38];
out[22] = -1.0*p[1]*y[22] - 1.0*y[3] - 1.0*p[0]*y[17] + 1.0*y[25] + 1.0*y[39];
out[23] = -1.0*p[1]*y[23] - 1.0*y[5] - 1.0*p[0]*y[18] + 1.0*y[25] + 1.0*y[40];
out[24] = -1.0*p[3]*y[24] - 1.0*y[7] - 1.0*p[2]*y[19] + 1.0*y[25] + 1.0*u[1];
out[25] = 1.0*p[5]*y[25]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) - 1.0*p[4]*y[20]/(pow(p[5], 2) + 1.0*pow(p[4], 2)) + 1.0*y[21] + 1.0*y[22] + 1.0*y[23] + 1.0*y[24];
out[26] = p[6]*(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7) + p[6]*(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7) + p[7]*sqrt(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7) + 4*p[8] + 1.0*y[21]*y[38] + y[16]*y[35] + 1.0*y[22]*y[39] + y[17]*y[36] + 1.0*y[23]*y[40] + 1.0*y[23]*u[1] + y[18]*y[37] + y[18]*u[0] - y[26];
out[27] = -p[14]*y[26]/y[27] - y[27] + ((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0*x[0] + 600.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0*x[0] + 620.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258*x[0] + 673.33333333333326
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0*x[0] + 620.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0*x[0] + 350.0
)
: (
   750
))))));
out[28] = -p[10]*x[1] - p[9]*(-x[0] + u[2]) - y[28];
out[29] = -1.0*y[1]*y[32] - y[0]*y[29] + u[3] + (1.0/3.0)*u[6] + (1.0/3.0)*y[28];
out[30] = -1.0*y[3]*y[33] - y[2]*y[30] + u[4] + (1.0/3.0)*u[6] + (1.0/3.0)*y[28];
out[31] = -1.0*y[5]*y[34] - y[4]*y[31] + u[5] + (1.0/3.0)*u[6] + (1.0/3.0)*y[28];
out[32] = -1.0*y[1]*y[29] + 1.0*y[0]*y[32] + u[8] + (1.0/3.0)*u[11];
out[33] = -1.0*y[3]*y[30] + 1.0*y[2]*y[33] + u[9] + (1.0/3.0)*u[11];
out[34] = -1.0*y[5]*y[31] + 1.0*y[4]*y[34] + u[10] + (1.0/3.0)*u[11];
out[35] = -p[1]*y[29] - y[0] + 1.0*p[0]*y[32] + y[35];
out[36] = -p[1]*y[30] - y[2] + 1.0*p[0]*y[33] + y[36];
out[37] = -p[1]*y[31] - y[4] + 1.0*p[0]*y[34] + y[37];
out[38] = -1.0*p[1]*y[32] - 1.0*y[1] - p[0]*y[29] + 1.0*y[38];
out[39] = -1.0*p[1]*y[33] - 1.0*y[3] - p[0]*y[30] + 1.0*y[39];
out[40] = -1.0*p[1]*y[34] - 1.0*y[5] - p[0]*y[31] + 1.0*y[40];
out[41] = -p[16]*y[41] - y[8] + 1.0*p[15]*y[45] + u[12]*cos(u[16]);
out[42] = -p[16]*y[42] - y[10] + 1.0*p[15]*y[46] + u[13]*cos(u[16] - 2.0943951023931953);
out[43] = -p[16]*y[43] - y[12] + 1.0*p[15]*y[47] + u[14]*cos(u[16] - 4.1887902047863905);
out[44] = -p[18]*y[44] - y[14] + 1.0*p[17]*y[48];
out[45] = -1.0*p[16]*y[45] - 1.0*y[9] - 1.0*p[15]*y[41] + 1.0*u[12]*sin(u[16]);
out[46] = -1.0*p[16]*y[46] - 1.0*y[11] - 1.0*p[15]*y[42] + 1.0*u[13]*sin(u[16] - 2.0943951023931953);
out[47] = -1.0*p[16]*y[47] - 1.0*y[13] - 1.0*p[15]*y[43] + 1.0*u[14]*sin(u[16] - 4.1887902047863905);
out[48] = -1.0*p[18]*y[48] - 1.0*y[15] - 1.0*p[17]*y[44];
out[49] = 1.0 - y[49];
out[50] = p[22]*x[2] + p[21]*(1 - y[49]) - y[50];

}
void h_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 94.615102344455664*y[1] + 184.75059629806526*y[0] - 17.974903844364835*y[3] - 69.368640085185305*y[2] - 40.748687841669557*y[5] - 43.675799641021079*y[4] - 17.974903844364821*y[7] - 69.368640085185291*y[6] - 94.615102344455664*y[9] - 184.75059629806526*y[8] + 17.974903844364835*y[11] + 69.368640085185305*y[10] + 40.748687841669557*y[13] + 43.675799641021079*y[12] + 17.974903844364821*y[15] + 69.368640085185291*y[14];
out[1] = 184.75059629806526*y[1] - 94.615102344455664*y[0] - 69.368640085185305*y[3] + 17.974903844364835*y[2] - 43.675799641021079*y[5] + 40.748687841669557*y[4] - 69.368640085185291*y[7] + 17.974903844364821*y[6] - 184.75059629806526*y[9] + 94.615102344455664*y[8] + 69.368640085185305*y[11] - 17.974903844364835*y[10] + 43.675799641021079*y[13] - 40.748687841669557*y[12] + 69.368640085185291*y[15] - 17.974903844364821*y[14];
out[2] = -17.974903844364825*y[1] - 69.368640085185291*y[0] + 94.615102344455636*y[3] + 184.7505962980652*y[2] - 17.97490384436481*y[5] - 69.368640085185319*y[4] - 40.748687841669565*y[7] - 43.675799641021079*y[6] + 17.974903844364825*y[9] + 69.368640085185291*y[8] - 94.615102344455636*y[11] - 184.7505962980652*y[10] + 17.97490384436481*y[13] + 69.368640085185319*y[12] + 40.748687841669565*y[15] + 43.675799641021079*y[14];
out[3] = -69.368640085185291*y[1] + 17.974903844364825*y[0] + 184.7505962980652*y[3] - 94.615102344455636*y[2] - 69.368640085185319*y[5] + 17.97490384436481*y[4] - 43.675799641021079*y[7] + 40.748687841669565*y[6] + 69.368640085185291*y[9] - 17.974903844364825*y[8] - 184.7505962980652*y[11] + 94.615102344455636*y[10] + 69.368640085185319*y[13] - 17.97490384436481*y[12] + 43.675799641021079*y[15] - 40.748687841669565*y[14];
out[4] = -40.748687841669579*y[1] - 43.675799641021101*y[0] - 17.974903844364821*y[3] - 69.368640085185305*y[2] + 94.61510234445565*y[5] + 184.75059629806526*y[4] - 17.974903844364821*y[7] - 69.368640085185305*y[6] + 40.748687841669579*y[9] + 43.675799641021101*y[8] + 17.974903844364821*y[11] + 69.368640085185305*y[10] - 94.61510234445565*y[13] - 184.75059629806526*y[12] + 17.974903844364821*y[15] + 69.368640085185305*y[14];
out[5] = -43.675799641021101*y[1] + 40.748687841669579*y[0] - 69.368640085185305*y[3] + 17.974903844364821*y[2] + 184.75059629806526*y[5] - 94.61510234445565*y[4] - 69.368640085185305*y[7] + 17.974903844364821*y[6] + 43.675799641021101*y[9] - 40.748687841669579*y[8] + 69.368640085185305*y[11] - 17.974903844364821*y[10] - 184.75059629806526*y[13] + 94.61510234445565*y[12] + 69.368640085185305*y[15] - 17.974903844364821*y[14];
out[6] = -17.974903844364825*y[1] - 69.368640085185305*y[0] - 40.74868784166955*y[3] - 43.675799641021079*y[2] - 17.974903844364839*y[5] - 69.368640085185291*y[4] + 94.61510234445565*y[7] + 184.7505962980652*y[6] + 17.974903844364825*y[9] + 69.368640085185305*y[8] + 40.74868784166955*y[11] + 43.675799641021079*y[10] + 17.974903844364839*y[13] + 69.368640085185291*y[12] - 94.61510234445565*y[15] - 184.7505962980652*y[14];
out[7] = -69.368640085185305*y[1] + 17.974903844364825*y[0] - 43.675799641021079*y[3] + 40.74868784166955*y[2] - 69.368640085185291*y[5] + 17.974903844364839*y[4] + 184.7505962980652*y[7] - 94.61510234445565*y[6] + 69.368640085185305*y[9] - 17.974903844364825*y[8] + 43.675799641021079*y[11] - 40.74868784166955*y[10] + 69.368640085185291*y[13] - 17.974903844364839*y[12] - 184.7505962980652*y[15] + 94.61510234445565*y[14];
out[8] = sqrt(1.0*pow(y[21], 2) + pow(y[16], 2));
out[9] = sqrt(1.0*pow(y[22], 2) + pow(y[17], 2));
out[10] = sqrt(1.0*pow(y[23], 2) + pow(y[18], 2));
out[11] = sqrt(1.0*pow(y[24], 2) + pow(y[19], 2));
out[12] = 1.0*y[1]*y[21] + y[0]*y[16];
out[13] = 1.0*y[1]*y[16] - 1.0*y[0]*y[21];
out[14] = 1.0*y[3]*y[22] + y[2]*y[17];
out[15] = 1.0*y[3]*y[17] - 1.0*y[2]*y[22];
out[16] = 1.0*y[5]*y[23] + y[4]*y[18];
out[17] = 1.0*y[5]*y[18] - 1.0*y[4]*y[23];
out[18] = u[6];
out[19] = sqrt(1.0*pow(y[45], 2) + pow(y[41], 2));
out[20] = sqrt(1.0*pow(y[46], 2) + pow(y[42], 2));
out[21] = sqrt(1.0*pow(y[47], 2) + pow(y[43], 2));
out[22] = sqrt(1.0*pow(y[48], 2) + pow(y[44], 2));
out[23] = 1.0*y[9]*y[45] + y[8]*y[41] + 1.0*y[11]*y[46] + y[10]*y[42] + 1.0*y[13]*y[47] + y[12]*y[43];
out[24] = 1.0*y[9]*y[41] - 1.0*y[8]*y[45] + 1.0*y[11]*y[42] - 1.0*y[10]*y[46] + 1.0*y[13]*y[43] - 1.0*y[12]*y[47];
out[25] = x[2];
out[26] = u[17];

}
void de_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -2.7777777777777776e-7*y[26]*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0
)
: (
   0
))))))/(p[13]*y[27]);
out[29] = -2.7777777777777776e-7*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0*x[0] + 600.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0*x[0] + 620.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258*x[0] + 673.33333333333326
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0*x[0] + 620.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0*x[0] + 350.0
)
: (
   750.0
))))))/(p[13]*y[27]);
out[30] = 2.7777777777777776e-7*y[26]*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0*x[0] + 600.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0*x[0] + 620.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258*x[0] + 673.33333333333326
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0*x[0] + 620.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0*x[0] + 350.0
)
: (
   750.0
))))))/(p[13]*pow(y[27], 2));
out[1585] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[35];
out[1586] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[36];
out[1587] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[37] + u[0];
out[1588] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1590] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38];
out[1591] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[39];
out[1592] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[40] + 1.0*u[1];
out[1593] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1604] = y[16];
out[1605] = y[17];
out[1606] = y[18];
out[1607] = 1.0*y[21];
out[1608] = 1.0*y[22];
out[1609] = 1.0*y[23];
out[1620] = ((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0
)
: (
   0
))))));
out[1649] = -p[14]/y[27];
out[1650] = p[14]*y[26]/pow(y[27], 2) - 1.0;
out[1731] = -y[29];
out[1732] = -1.0*y[32];
out[1760] = -y[0];
out[1763] = -1.0*y[1];
out[1787] = -y[30];
out[1788] = -1.0*y[33];
out[1815] = -y[2];
out[1818] = -1.0*y[3];
out[1843] = -y[31];
out[1844] = -1.0*y[34];
out[1870] = -y[4];
out[1873] = -1.0*y[5];
out[1893] = 1.0*y[32];
out[1894] = -1.0*y[29];
out[1922] = -1.0*y[1];
out[1925] = 1.0*y[0];
out[1949] = 1.0*y[33];
out[1950] = -1.0*y[30];
out[1977] = -1.0*y[3];
out[1980] = 1.0*y[2];
out[2005] = 1.0*y[34];
out[2006] = -1.0*y[31];
out[2032] = -1.0*y[5];
out[2035] = 1.0*y[4];

}

void de_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[110] = -p[23];
out[1045] = -p[1];
out[1050] = 1.0*p[0];
out[1100] = -p[1];
out[1105] = 1.0*p[0];
out[1155] = -p[1];
out[1160] = 1.0*p[0];
out[1210] = -p[3];
out[1215] = 1.0*p[2];
out[1265] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1270] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1315] = -1.0*p[0];
out[1320] = -1.0*p[1];
out[1370] = -1.0*p[0];
out[1375] = -1.0*p[1];
out[1425] = -1.0*p[0];
out[1430] = -1.0*p[1];
out[1480] = -1.0*p[2];
out[1485] = -1.0*p[3];
out[1535] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1540] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1674] = p[9];
out[1675] = -p[10];
out[2084] = -p[1];
out[2087] = 1.0*p[0];
out[2139] = -p[1];
out[2142] = 1.0*p[0];
out[2194] = -p[1];
out[2197] = 1.0*p[0];
out[2246] = -p[0];
out[2249] = -1.0*p[1];
out[2301] = -p[0];
out[2304] = -1.0*p[1];
out[2356] = -p[0];
out[2359] = -1.0*p[1];
out[2420] = -p[16];
out[2424] = 1.0*p[15];
out[2475] = -p[16];
out[2479] = 1.0*p[15];
out[2530] = -p[16];
out[2534] = 1.0*p[15];
out[2585] = -p[18];
out[2589] = 1.0*p[17];
out[2636] = -1.0*p[15];
out[2640] = -1.0*p[16];
out[2691] = -1.0*p[15];
out[2695] = -1.0*p[16];
out[2746] = -1.0*p[15];
out[2750] = -1.0*p[16];
out[2801] = -1.0*p[17];
out[2805] = -1.0*p[18];
out[2864] = p[22];
out[2914] = -p[21];

}

void de_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[54] = -1.0;
out[160] = -1.0;
out[165] = 184.75059629806526;
out[166] = 94.615102344455664;
out[167] = -69.368640085185305;
out[168] = -17.974903844364835;
out[169] = -43.675799641021079;
out[170] = -40.748687841669557;
out[171] = -69.368640085185291;
out[172] = -17.974903844364821;
out[173] = -184.75059629806526;
out[174] = -94.615102344455664;
out[175] = 69.368640085185305;
out[176] = 17.974903844364835;
out[177] = 43.675799641021079;
out[178] = 40.748687841669557;
out[179] = 69.368640085185291;
out[180] = 17.974903844364821;
out[181] = -1.0;
out[219] = -94.615102344455664;
out[220] = 184.75059629806526;
out[221] = 17.974903844364835;
out[222] = -69.368640085185305;
out[223] = 40.748687841669557;
out[224] = -43.675799641021079;
out[225] = 17.974903844364821;
out[226] = -69.368640085185291;
out[227] = 94.615102344455664;
out[228] = -184.75059629806526;
out[229] = -17.974903844364835;
out[230] = 69.368640085185305;
out[231] = -40.748687841669557;
out[232] = 43.675799641021079;
out[233] = -17.974903844364821;
out[234] = 69.368640085185291;
out[240] = -1.0;
out[273] = -69.368640085185291;
out[274] = -17.974903844364825;
out[275] = 184.7505962980652;
out[276] = 94.615102344455636;
out[277] = -69.368640085185319;
out[278] = -17.97490384436481;
out[279] = -43.675799641021079;
out[280] = -40.748687841669565;
out[281] = 69.368640085185291;
out[282] = 17.974903844364825;
out[283] = -184.7505962980652;
out[284] = -94.615102344455636;
out[285] = 69.368640085185319;
out[286] = 17.97490384436481;
out[287] = 43.675799641021079;
out[288] = 40.748687841669565;
out[290] = -1.0;
out[327] = 17.974903844364825;
out[328] = -69.368640085185291;
out[329] = -94.615102344455636;
out[330] = 184.7505962980652;
out[331] = 17.97490384436481;
out[332] = -69.368640085185319;
out[333] = 40.748687841669565;
out[334] = -43.675799641021079;
out[335] = -17.974903844364825;
out[336] = 69.368640085185291;
out[337] = 94.615102344455636;
out[338] = -184.7505962980652;
out[339] = -17.97490384436481;
out[340] = 69.368640085185319;
out[341] = -40.748687841669565;
out[342] = 43.675799641021079;
out[349] = -1.0;
out[381] = -43.675799641021101;
out[382] = -40.748687841669579;
out[383] = -69.368640085185305;
out[384] = -17.974903844364821;
out[385] = 184.75059629806526;
out[386] = 94.61510234445565;
out[387] = -69.368640085185305;
out[388] = -17.974903844364821;
out[389] = 43.675799641021101;
out[390] = 40.748687841669579;
out[391] = 69.368640085185305;
out[392] = 17.974903844364821;
out[393] = -184.75059629806526;
out[394] = -94.61510234445565;
out[395] = 69.368640085185305;
out[396] = 17.974903844364821;
out[399] = -1.0;
out[435] = 40.748687841669579;
out[436] = -43.675799641021101;
out[437] = 17.974903844364821;
out[438] = -69.368640085185305;
out[439] = -94.61510234445565;
out[440] = 184.75059629806526;
out[441] = 17.974903844364821;
out[442] = -69.368640085185305;
out[443] = -40.748687841669579;
out[444] = 43.675799641021101;
out[445] = -17.974903844364821;
out[446] = 69.368640085185305;
out[447] = 94.61510234445565;
out[448] = -184.75059629806526;
out[449] = -17.974903844364821;
out[450] = 69.368640085185305;
out[458] = -1.0;
out[489] = -69.368640085185305;
out[490] = -17.974903844364825;
out[491] = -43.675799641021079;
out[492] = -40.74868784166955;
out[493] = -69.368640085185291;
out[494] = -17.974903844364839;
out[495] = 184.7505962980652;
out[496] = 94.61510234445565;
out[497] = 69.368640085185305;
out[498] = 17.974903844364825;
out[499] = 43.675799641021079;
out[500] = 40.74868784166955;
out[501] = 69.368640085185291;
out[502] = 17.974903844364839;
out[503] = -184.7505962980652;
out[504] = -94.61510234445565;
out[508] = -1.0;
out[543] = 17.974903844364825;
out[544] = -69.368640085185305;
out[545] = 40.74868784166955;
out[546] = -43.675799641021079;
out[547] = 17.974903844364839;
out[548] = -69.368640085185291;
out[549] = -94.61510234445565;
out[550] = 184.7505962980652;
out[551] = -17.974903844364825;
out[552] = 69.368640085185305;
out[553] = -40.74868784166955;
out[554] = 43.675799641021079;
out[555] = -17.974903844364839;
out[556] = 69.368640085185291;
out[557] = 94.61510234445565;
out[558] = -184.7505962980652;
out[567] = -1.0;
out[597] = -184.75059629806526;
out[598] = -94.615102344455664;
out[599] = 69.368640085185305;
out[600] = 17.974903844364835;
out[601] = 43.675799641021079;
out[602] = 40.748687841669557;
out[603] = 69.368640085185291;
out[604] = 17.974903844364821;
out[605] = 184.75059629806526;
out[606] = 94.615102344455664;
out[607] = -69.368640085185305;
out[608] = -17.974903844364835;
out[609] = -43.675799641021079;
out[610] = -40.748687841669557;
out[611] = -69.368640085185291;
out[612] = -17.974903844364821;
out[638] = -1.0;
out[651] = 94.615102344455664;
out[652] = -184.75059629806526;
out[653] = -17.974903844364835;
out[654] = 69.368640085185305;
out[655] = -40.748687841669557;
out[656] = 43.675799641021079;
out[657] = -17.974903844364821;
out[658] = 69.368640085185291;
out[659] = -94.615102344455664;
out[660] = 184.75059629806526;
out[661] = 17.974903844364835;
out[662] = -69.368640085185305;
out[663] = 40.748687841669557;
out[664] = -43.675799641021079;
out[665] = 17.974903844364821;
out[666] = -69.368640085185291;
out[696] = -1.0;
out[705] = 69.368640085185291;
out[706] = 17.974903844364825;
out[707] = -184.7505962980652;
out[708] = -94.615102344455636;
out[709] = 69.368640085185319;
out[710] = 17.97490384436481;
out[711] = 43.675799641021079;
out[712] = 40.748687841669565;
out[713] = -69.368640085185291;
out[714] = -17.974903844364825;
out[715] = 184.7505962980652;
out[716] = 94.615102344455636;
out[717] = -69.368640085185319;
out[718] = -17.97490384436481;
out[719] = -43.675799641021079;
out[720] = -40.748687841669565;
out[747] = -1.0;
out[759] = -17.974903844364825;
out[760] = 69.368640085185291;
out[761] = 94.615102344455636;
out[762] = -184.7505962980652;
out[763] = -17.97490384436481;
out[764] = 69.368640085185319;
out[765] = -40.748687841669565;
out[766] = 43.675799641021079;
out[767] = 17.974903844364825;
out[768] = -69.368640085185291;
out[769] = -94.615102344455636;
out[770] = 184.7505962980652;
out[771] = 17.97490384436481;
out[772] = -69.368640085185319;
out[773] = 40.748687841669565;
out[774] = -43.675799641021079;
out[805] = -1.0;
out[813] = 43.675799641021101;
out[814] = 40.748687841669579;
out[815] = 69.368640085185305;
out[816] = 17.974903844364821;
out[817] = -184.75059629806526;
out[818] = -94.61510234445565;
out[819] = 69.368640085185305;
out[820] = 17.974903844364821;
out[821] = -43.675799641021101;
out[822] = -40.748687841669579;
out[823] = -69.368640085185305;
out[824] = -17.974903844364821;
out[825] = 184.75059629806526;
out[826] = 94.61510234445565;
out[827] = -69.368640085185305;
out[828] = -17.974903844364821;
out[856] = -1.0;
out[867] = -40.748687841669579;
out[868] = 43.675799641021101;
out[869] = -17.974903844364821;
out[870] = 69.368640085185305;
out[871] = 94.61510234445565;
out[872] = -184.75059629806526;
out[873] = -17.974903844364821;
out[874] = 69.368640085185305;
out[875] = 40.748687841669579;
out[876] = -43.675799641021101;
out[877] = 17.974903844364821;
out[878] = -69.368640085185305;
out[879] = -94.61510234445565;
out[880] = 184.75059629806526;
out[881] = 17.974903844364821;
out[882] = -69.368640085185305;
out[914] = -1.0;
out[921] = 69.368640085185305;
out[922] = 17.974903844364825;
out[923] = 43.675799641021079;
out[924] = 40.74868784166955;
out[925] = 69.368640085185291;
out[926] = 17.974903844364839;
out[927] = -184.7505962980652;
out[928] = -94.61510234445565;
out[929] = -69.368640085185305;
out[930] = -17.974903844364825;
out[931] = -43.675799641021079;
out[932] = -40.74868784166955;
out[933] = -69.368640085185291;
out[934] = -17.974903844364839;
out[935] = 184.7505962980652;
out[936] = 94.61510234445565;
out[965] = -1.0;
out[975] = -17.974903844364825;
out[976] = 69.368640085185305;
out[977] = -40.74868784166955;
out[978] = 43.675799641021079;
out[979] = -17.974903844364839;
out[980] = 69.368640085185291;
out[981] = 94.61510234445565;
out[982] = -184.7505962980652;
out[983] = 17.974903844364825;
out[984] = -69.368640085185305;
out[985] = 40.74868784166955;
out[986] = -43.675799641021079;
out[987] = 17.974903844364839;
out[988] = -69.368640085185291;
out[989] = -94.61510234445565;
out[990] = 184.7505962980652;
out[1023] = -1.0;
out[1029] = -1.0;
out[1049] = 1.0;
out[1064] = 1.0;
out[1085] = -1.0;
out[1103] = 1.0;
out[1119] = 1.0;
out[1141] = -1.0;
out[1157] = 1.0;
out[1174] = 1.0;
out[1197] = -1.0;
out[1211] = 1.0;
out[1261] = 1.0;
out[1262] = 1.0;
out[1263] = 1.0;
out[1264] = 1.0;
out[1300] = -1.0;
out[1324] = 1.0;
out[1337] = 1.0;
out[1356] = -1.0;
out[1378] = 1.0;
out[1392] = 1.0;
out[1412] = -1.0;
out[1432] = 1.0;
out[1447] = 1.0;
out[1468] = -1.0;
out[1486] = 1.0;
out[1536] = 1.0;
out[1537] = 1.0;
out[1538] = 1.0;
out[1539] = 1.0;
out[1595] = -1.0;
out[1705] = -1.0;
out[1759] = 0.33333333333333331;
out[1813] = 0.33333333333333331;
out[1867] = 0.33333333333333331;
out[2055] = -1.0;
out[2090] = 1.0;
out[2111] = -1.0;
out[2145] = 1.0;
out[2167] = -1.0;
out[2200] = 1.0;
out[2218] = -1.0;
out[2255] = 1.0;
out[2274] = -1.0;
out[2310] = 1.0;
out[2330] = -1.0;
out[2365] = 1.0;
out[2387] = -1.0;
out[2443] = -1.0;
out[2499] = -1.0;
out[2555] = -1.0;
out[2604] = -1.0;
out[2660] = -1.0;
out[2716] = -1.0;
out[2772] = -1.0;
out[2860] = -1.0;
out[2915] = -1.0;

}

void sp_jac_ini_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -2.7777777777777776e-7*y[26]*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0
)
: (
   0
))))))/(p[13]*y[27]);
out[1] = -2.7777777777777776e-7*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0*x[0] + 600.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0*x[0] + 620.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258*x[0] + 673.33333333333326
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0*x[0] + 620.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0*x[0] + 350.0
)
: (
   750.0
))))))/(p[13]*y[27]);
out[2] = 2.7777777777777776e-7*y[26]*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0*x[0] + 600.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0*x[0] + 620.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258*x[0] + 673.33333333333326
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0*x[0] + 620.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0*x[0] + 350.0
)
: (
   750.0
))))))/(p[13]*pow(y[27], 2));
out[328] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[35];
out[329] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[36];
out[330] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[37] + u[0];
out[331] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[332] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38];
out[333] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[39];
out[334] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[40] + 1.0*u[1];
out[335] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[337] = y[16];
out[338] = y[17];
out[339] = y[18];
out[340] = 1.0*y[21];
out[341] = 1.0*y[22];
out[342] = 1.0*y[23];
out[343] = ((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0
)
: (
   0
))))));
out[344] = -p[14]/y[27];
out[345] = p[14]*y[26]/pow(y[27], 2) - 1.0;
out[349] = -y[29];
out[350] = -1.0*y[32];
out[352] = -y[0];
out[353] = -1.0*y[1];
out[354] = -y[30];
out[355] = -1.0*y[33];
out[357] = -y[2];
out[358] = -1.0*y[3];
out[359] = -y[31];
out[360] = -1.0*y[34];
out[362] = -y[4];
out[363] = -1.0*y[5];
out[364] = 1.0*y[32];
out[365] = -1.0*y[29];
out[366] = -1.0*y[1];
out[367] = 1.0*y[0];
out[368] = 1.0*y[33];
out[369] = -1.0*y[30];
out[370] = -1.0*y[3];
out[371] = 1.0*y[2];
out[372] = 1.0*y[34];
out[373] = -1.0*y[31];
out[374] = -1.0*y[5];
out[375] = 1.0*y[4];

}

void sp_jac_ini_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[4] = -p[23];
out[279] = -p[1];
out[281] = 1.0*p[0];
out[284] = -p[1];
out[286] = 1.0*p[0];
out[289] = -p[1];
out[291] = 1.0*p[0];
out[294] = -p[3];
out[296] = 1.0*p[2];
out[301] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[302] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[304] = -1.0*p[0];
out[305] = -1.0*p[1];
out[309] = -1.0*p[0];
out[310] = -1.0*p[1];
out[314] = -1.0*p[0];
out[315] = -1.0*p[1];
out[319] = -1.0*p[2];
out[320] = -1.0*p[3];
out[322] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[327] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[346] = p[9];
out[347] = -p[10];
out[377] = -p[1];
out[378] = 1.0*p[0];
out[381] = -p[1];
out[382] = 1.0*p[0];
out[385] = -p[1];
out[386] = 1.0*p[0];
out[389] = -p[0];
out[390] = -1.0*p[1];
out[393] = -p[0];
out[394] = -1.0*p[1];
out[397] = -p[0];
out[398] = -1.0*p[1];
out[401] = -p[16];
out[402] = 1.0*p[15];
out[404] = -p[16];
out[405] = 1.0*p[15];
out[407] = -p[16];
out[408] = 1.0*p[15];
out[410] = -p[18];
out[411] = 1.0*p[17];
out[413] = -1.0*p[15];
out[414] = -1.0*p[16];
out[416] = -1.0*p[15];
out[417] = -1.0*p[16];
out[419] = -1.0*p[15];
out[420] = -1.0*p[16];
out[422] = -1.0*p[17];
out[423] = -1.0*p[18];
out[425] = p[22];
out[426] = -p[21];

}

void sp_jac_ini_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[3] = -1.0;
out[5] = -1.0;
out[6] = 184.75059629806526;
out[7] = 94.615102344455664;
out[8] = -69.368640085185305;
out[9] = -17.974903844364835;
out[10] = -43.675799641021079;
out[11] = -40.748687841669557;
out[12] = -69.368640085185291;
out[13] = -17.974903844364821;
out[14] = -184.75059629806526;
out[15] = -94.615102344455664;
out[16] = 69.368640085185305;
out[17] = 17.974903844364835;
out[18] = 43.675799641021079;
out[19] = 40.748687841669557;
out[20] = 69.368640085185291;
out[21] = 17.974903844364821;
out[22] = -1.0;
out[23] = -94.615102344455664;
out[24] = 184.75059629806526;
out[25] = 17.974903844364835;
out[26] = -69.368640085185305;
out[27] = 40.748687841669557;
out[28] = -43.675799641021079;
out[29] = 17.974903844364821;
out[30] = -69.368640085185291;
out[31] = 94.615102344455664;
out[32] = -184.75059629806526;
out[33] = -17.974903844364835;
out[34] = 69.368640085185305;
out[35] = -40.748687841669557;
out[36] = 43.675799641021079;
out[37] = -17.974903844364821;
out[38] = 69.368640085185291;
out[39] = -1.0;
out[40] = -69.368640085185291;
out[41] = -17.974903844364825;
out[42] = 184.7505962980652;
out[43] = 94.615102344455636;
out[44] = -69.368640085185319;
out[45] = -17.97490384436481;
out[46] = -43.675799641021079;
out[47] = -40.748687841669565;
out[48] = 69.368640085185291;
out[49] = 17.974903844364825;
out[50] = -184.7505962980652;
out[51] = -94.615102344455636;
out[52] = 69.368640085185319;
out[53] = 17.97490384436481;
out[54] = 43.675799641021079;
out[55] = 40.748687841669565;
out[56] = -1.0;
out[57] = 17.974903844364825;
out[58] = -69.368640085185291;
out[59] = -94.615102344455636;
out[60] = 184.7505962980652;
out[61] = 17.97490384436481;
out[62] = -69.368640085185319;
out[63] = 40.748687841669565;
out[64] = -43.675799641021079;
out[65] = -17.974903844364825;
out[66] = 69.368640085185291;
out[67] = 94.615102344455636;
out[68] = -184.7505962980652;
out[69] = -17.97490384436481;
out[70] = 69.368640085185319;
out[71] = -40.748687841669565;
out[72] = 43.675799641021079;
out[73] = -1.0;
out[74] = -43.675799641021101;
out[75] = -40.748687841669579;
out[76] = -69.368640085185305;
out[77] = -17.974903844364821;
out[78] = 184.75059629806526;
out[79] = 94.61510234445565;
out[80] = -69.368640085185305;
out[81] = -17.974903844364821;
out[82] = 43.675799641021101;
out[83] = 40.748687841669579;
out[84] = 69.368640085185305;
out[85] = 17.974903844364821;
out[86] = -184.75059629806526;
out[87] = -94.61510234445565;
out[88] = 69.368640085185305;
out[89] = 17.974903844364821;
out[90] = -1.0;
out[91] = 40.748687841669579;
out[92] = -43.675799641021101;
out[93] = 17.974903844364821;
out[94] = -69.368640085185305;
out[95] = -94.61510234445565;
out[96] = 184.75059629806526;
out[97] = 17.974903844364821;
out[98] = -69.368640085185305;
out[99] = -40.748687841669579;
out[100] = 43.675799641021101;
out[101] = -17.974903844364821;
out[102] = 69.368640085185305;
out[103] = 94.61510234445565;
out[104] = -184.75059629806526;
out[105] = -17.974903844364821;
out[106] = 69.368640085185305;
out[107] = -1.0;
out[108] = -69.368640085185305;
out[109] = -17.974903844364825;
out[110] = -43.675799641021079;
out[111] = -40.74868784166955;
out[112] = -69.368640085185291;
out[113] = -17.974903844364839;
out[114] = 184.7505962980652;
out[115] = 94.61510234445565;
out[116] = 69.368640085185305;
out[117] = 17.974903844364825;
out[118] = 43.675799641021079;
out[119] = 40.74868784166955;
out[120] = 69.368640085185291;
out[121] = 17.974903844364839;
out[122] = -184.7505962980652;
out[123] = -94.61510234445565;
out[124] = -1.0;
out[125] = 17.974903844364825;
out[126] = -69.368640085185305;
out[127] = 40.74868784166955;
out[128] = -43.675799641021079;
out[129] = 17.974903844364839;
out[130] = -69.368640085185291;
out[131] = -94.61510234445565;
out[132] = 184.7505962980652;
out[133] = -17.974903844364825;
out[134] = 69.368640085185305;
out[135] = -40.74868784166955;
out[136] = 43.675799641021079;
out[137] = -17.974903844364839;
out[138] = 69.368640085185291;
out[139] = 94.61510234445565;
out[140] = -184.7505962980652;
out[141] = -1.0;
out[142] = -184.75059629806526;
out[143] = -94.615102344455664;
out[144] = 69.368640085185305;
out[145] = 17.974903844364835;
out[146] = 43.675799641021079;
out[147] = 40.748687841669557;
out[148] = 69.368640085185291;
out[149] = 17.974903844364821;
out[150] = 184.75059629806526;
out[151] = 94.615102344455664;
out[152] = -69.368640085185305;
out[153] = -17.974903844364835;
out[154] = -43.675799641021079;
out[155] = -40.748687841669557;
out[156] = -69.368640085185291;
out[157] = -17.974903844364821;
out[158] = -1.0;
out[159] = 94.615102344455664;
out[160] = -184.75059629806526;
out[161] = -17.974903844364835;
out[162] = 69.368640085185305;
out[163] = -40.748687841669557;
out[164] = 43.675799641021079;
out[165] = -17.974903844364821;
out[166] = 69.368640085185291;
out[167] = -94.615102344455664;
out[168] = 184.75059629806526;
out[169] = 17.974903844364835;
out[170] = -69.368640085185305;
out[171] = 40.748687841669557;
out[172] = -43.675799641021079;
out[173] = 17.974903844364821;
out[174] = -69.368640085185291;
out[175] = -1.0;
out[176] = 69.368640085185291;
out[177] = 17.974903844364825;
out[178] = -184.7505962980652;
out[179] = -94.615102344455636;
out[180] = 69.368640085185319;
out[181] = 17.97490384436481;
out[182] = 43.675799641021079;
out[183] = 40.748687841669565;
out[184] = -69.368640085185291;
out[185] = -17.974903844364825;
out[186] = 184.7505962980652;
out[187] = 94.615102344455636;
out[188] = -69.368640085185319;
out[189] = -17.97490384436481;
out[190] = -43.675799641021079;
out[191] = -40.748687841669565;
out[192] = -1.0;
out[193] = -17.974903844364825;
out[194] = 69.368640085185291;
out[195] = 94.615102344455636;
out[196] = -184.7505962980652;
out[197] = -17.97490384436481;
out[198] = 69.368640085185319;
out[199] = -40.748687841669565;
out[200] = 43.675799641021079;
out[201] = 17.974903844364825;
out[202] = -69.368640085185291;
out[203] = -94.615102344455636;
out[204] = 184.7505962980652;
out[205] = 17.97490384436481;
out[206] = -69.368640085185319;
out[207] = 40.748687841669565;
out[208] = -43.675799641021079;
out[209] = -1.0;
out[210] = 43.675799641021101;
out[211] = 40.748687841669579;
out[212] = 69.368640085185305;
out[213] = 17.974903844364821;
out[214] = -184.75059629806526;
out[215] = -94.61510234445565;
out[216] = 69.368640085185305;
out[217] = 17.974903844364821;
out[218] = -43.675799641021101;
out[219] = -40.748687841669579;
out[220] = -69.368640085185305;
out[221] = -17.974903844364821;
out[222] = 184.75059629806526;
out[223] = 94.61510234445565;
out[224] = -69.368640085185305;
out[225] = -17.974903844364821;
out[226] = -1.0;
out[227] = -40.748687841669579;
out[228] = 43.675799641021101;
out[229] = -17.974903844364821;
out[230] = 69.368640085185305;
out[231] = 94.61510234445565;
out[232] = -184.75059629806526;
out[233] = -17.974903844364821;
out[234] = 69.368640085185305;
out[235] = 40.748687841669579;
out[236] = -43.675799641021101;
out[237] = 17.974903844364821;
out[238] = -69.368640085185305;
out[239] = -94.61510234445565;
out[240] = 184.75059629806526;
out[241] = 17.974903844364821;
out[242] = -69.368640085185305;
out[243] = -1.0;
out[244] = 69.368640085185305;
out[245] = 17.974903844364825;
out[246] = 43.675799641021079;
out[247] = 40.74868784166955;
out[248] = 69.368640085185291;
out[249] = 17.974903844364839;
out[250] = -184.7505962980652;
out[251] = -94.61510234445565;
out[252] = -69.368640085185305;
out[253] = -17.974903844364825;
out[254] = -43.675799641021079;
out[255] = -40.74868784166955;
out[256] = -69.368640085185291;
out[257] = -17.974903844364839;
out[258] = 184.7505962980652;
out[259] = 94.61510234445565;
out[260] = -1.0;
out[261] = -17.974903844364825;
out[262] = 69.368640085185305;
out[263] = -40.74868784166955;
out[264] = 43.675799641021079;
out[265] = -17.974903844364839;
out[266] = 69.368640085185291;
out[267] = 94.61510234445565;
out[268] = -184.7505962980652;
out[269] = 17.974903844364825;
out[270] = -69.368640085185305;
out[271] = 40.74868784166955;
out[272] = -43.675799641021079;
out[273] = 17.974903844364839;
out[274] = -69.368640085185291;
out[275] = -94.61510234445565;
out[276] = 184.7505962980652;
out[277] = -1.0;
out[278] = -1.0;
out[280] = 1.0;
out[282] = 1.0;
out[283] = -1.0;
out[285] = 1.0;
out[287] = 1.0;
out[288] = -1.0;
out[290] = 1.0;
out[292] = 1.0;
out[293] = -1.0;
out[295] = 1.0;
out[297] = 1.0;
out[298] = 1.0;
out[299] = 1.0;
out[300] = 1.0;
out[303] = -1.0;
out[306] = 1.0;
out[307] = 1.0;
out[308] = -1.0;
out[311] = 1.0;
out[312] = 1.0;
out[313] = -1.0;
out[316] = 1.0;
out[317] = 1.0;
out[318] = -1.0;
out[321] = 1.0;
out[323] = 1.0;
out[324] = 1.0;
out[325] = 1.0;
out[326] = 1.0;
out[336] = -1.0;
out[348] = -1.0;
out[351] = 0.33333333333333331;
out[356] = 0.33333333333333331;
out[361] = 0.33333333333333331;
out[376] = -1.0;
out[379] = 1.0;
out[380] = -1.0;
out[383] = 1.0;
out[384] = -1.0;
out[387] = 1.0;
out[388] = -1.0;
out[391] = 1.0;
out[392] = -1.0;
out[395] = 1.0;
out[396] = -1.0;
out[399] = 1.0;
out[400] = -1.0;
out[403] = -1.0;
out[406] = -1.0;
out[409] = -1.0;
out[412] = -1.0;
out[415] = -1.0;
out[418] = -1.0;
out[421] = -1.0;
out[424] = -1.0;
out[427] = -1.0;

}

void de_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -2.7777777777777776e-7*y[26]*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0
)
: (
   0
))))))/(p[13]*y[27]);
out[29] = -2.7777777777777776e-7*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0*x[0] + 600.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0*x[0] + 620.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258*x[0] + 673.33333333333326
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0*x[0] + 620.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0*x[0] + 350.0
)
: (
   750.0
))))))/(p[13]*y[27]);
out[30] = 2.7777777777777776e-7*y[26]*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0*x[0] + 600.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0*x[0] + 620.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258*x[0] + 673.33333333333326
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0*x[0] + 620.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0*x[0] + 350.0
)
: (
   750.0
))))))/(p[13]*pow(y[27], 2));
out[1585] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[35];
out[1586] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[36];
out[1587] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[37] + u[0];
out[1588] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1590] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38];
out[1591] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[39];
out[1592] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[40] + 1.0*u[1];
out[1593] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1604] = y[16];
out[1605] = y[17];
out[1606] = y[18];
out[1607] = 1.0*y[21];
out[1608] = 1.0*y[22];
out[1609] = 1.0*y[23];
out[1620] = ((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0
)
: (
   0
))))));
out[1649] = -p[14]/y[27];
out[1650] = p[14]*y[26]/pow(y[27], 2) - 1.0;
out[1731] = -y[29];
out[1732] = -1.0*y[32];
out[1760] = -y[0];
out[1763] = -1.0*y[1];
out[1787] = -y[30];
out[1788] = -1.0*y[33];
out[1815] = -y[2];
out[1818] = -1.0*y[3];
out[1843] = -y[31];
out[1844] = -1.0*y[34];
out[1870] = -y[4];
out[1873] = -1.0*y[5];
out[1893] = 1.0*y[32];
out[1894] = -1.0*y[29];
out[1922] = -1.0*y[1];
out[1925] = 1.0*y[0];
out[1949] = 1.0*y[33];
out[1950] = -1.0*y[30];
out[1977] = -1.0*y[3];
out[1980] = 1.0*y[2];
out[2005] = 1.0*y[34];
out[2006] = -1.0*y[31];
out[2032] = -1.0*y[5];
out[2035] = 1.0*y[4];

}

void de_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[110] = -p[23];
out[1045] = -p[1];
out[1050] = 1.0*p[0];
out[1100] = -p[1];
out[1105] = 1.0*p[0];
out[1155] = -p[1];
out[1160] = 1.0*p[0];
out[1210] = -p[3];
out[1215] = 1.0*p[2];
out[1265] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1270] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1315] = -1.0*p[0];
out[1320] = -1.0*p[1];
out[1370] = -1.0*p[0];
out[1375] = -1.0*p[1];
out[1425] = -1.0*p[0];
out[1430] = -1.0*p[1];
out[1480] = -1.0*p[2];
out[1485] = -1.0*p[3];
out[1535] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1540] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1674] = p[9];
out[1675] = -p[10];
out[2084] = -p[1];
out[2087] = 1.0*p[0];
out[2139] = -p[1];
out[2142] = 1.0*p[0];
out[2194] = -p[1];
out[2197] = 1.0*p[0];
out[2246] = -p[0];
out[2249] = -1.0*p[1];
out[2301] = -p[0];
out[2304] = -1.0*p[1];
out[2356] = -p[0];
out[2359] = -1.0*p[1];
out[2420] = -p[16];
out[2424] = 1.0*p[15];
out[2475] = -p[16];
out[2479] = 1.0*p[15];
out[2530] = -p[16];
out[2534] = 1.0*p[15];
out[2585] = -p[18];
out[2589] = 1.0*p[17];
out[2636] = -1.0*p[15];
out[2640] = -1.0*p[16];
out[2691] = -1.0*p[15];
out[2695] = -1.0*p[16];
out[2746] = -1.0*p[15];
out[2750] = -1.0*p[16];
out[2801] = -1.0*p[17];
out[2805] = -1.0*p[18];
out[2864] = p[22];
out[2914] = -p[21];

}

void de_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[54] = -1.0;
out[160] = -1.0;
out[165] = 184.75059629806526;
out[166] = 94.615102344455664;
out[167] = -69.368640085185305;
out[168] = -17.974903844364835;
out[169] = -43.675799641021079;
out[170] = -40.748687841669557;
out[171] = -69.368640085185291;
out[172] = -17.974903844364821;
out[173] = -184.75059629806526;
out[174] = -94.615102344455664;
out[175] = 69.368640085185305;
out[176] = 17.974903844364835;
out[177] = 43.675799641021079;
out[178] = 40.748687841669557;
out[179] = 69.368640085185291;
out[180] = 17.974903844364821;
out[181] = -1.0;
out[219] = -94.615102344455664;
out[220] = 184.75059629806526;
out[221] = 17.974903844364835;
out[222] = -69.368640085185305;
out[223] = 40.748687841669557;
out[224] = -43.675799641021079;
out[225] = 17.974903844364821;
out[226] = -69.368640085185291;
out[227] = 94.615102344455664;
out[228] = -184.75059629806526;
out[229] = -17.974903844364835;
out[230] = 69.368640085185305;
out[231] = -40.748687841669557;
out[232] = 43.675799641021079;
out[233] = -17.974903844364821;
out[234] = 69.368640085185291;
out[240] = -1.0;
out[273] = -69.368640085185291;
out[274] = -17.974903844364825;
out[275] = 184.7505962980652;
out[276] = 94.615102344455636;
out[277] = -69.368640085185319;
out[278] = -17.97490384436481;
out[279] = -43.675799641021079;
out[280] = -40.748687841669565;
out[281] = 69.368640085185291;
out[282] = 17.974903844364825;
out[283] = -184.7505962980652;
out[284] = -94.615102344455636;
out[285] = 69.368640085185319;
out[286] = 17.97490384436481;
out[287] = 43.675799641021079;
out[288] = 40.748687841669565;
out[290] = -1.0;
out[327] = 17.974903844364825;
out[328] = -69.368640085185291;
out[329] = -94.615102344455636;
out[330] = 184.7505962980652;
out[331] = 17.97490384436481;
out[332] = -69.368640085185319;
out[333] = 40.748687841669565;
out[334] = -43.675799641021079;
out[335] = -17.974903844364825;
out[336] = 69.368640085185291;
out[337] = 94.615102344455636;
out[338] = -184.7505962980652;
out[339] = -17.97490384436481;
out[340] = 69.368640085185319;
out[341] = -40.748687841669565;
out[342] = 43.675799641021079;
out[349] = -1.0;
out[381] = -43.675799641021101;
out[382] = -40.748687841669579;
out[383] = -69.368640085185305;
out[384] = -17.974903844364821;
out[385] = 184.75059629806526;
out[386] = 94.61510234445565;
out[387] = -69.368640085185305;
out[388] = -17.974903844364821;
out[389] = 43.675799641021101;
out[390] = 40.748687841669579;
out[391] = 69.368640085185305;
out[392] = 17.974903844364821;
out[393] = -184.75059629806526;
out[394] = -94.61510234445565;
out[395] = 69.368640085185305;
out[396] = 17.974903844364821;
out[399] = -1.0;
out[435] = 40.748687841669579;
out[436] = -43.675799641021101;
out[437] = 17.974903844364821;
out[438] = -69.368640085185305;
out[439] = -94.61510234445565;
out[440] = 184.75059629806526;
out[441] = 17.974903844364821;
out[442] = -69.368640085185305;
out[443] = -40.748687841669579;
out[444] = 43.675799641021101;
out[445] = -17.974903844364821;
out[446] = 69.368640085185305;
out[447] = 94.61510234445565;
out[448] = -184.75059629806526;
out[449] = -17.974903844364821;
out[450] = 69.368640085185305;
out[458] = -1.0;
out[489] = -69.368640085185305;
out[490] = -17.974903844364825;
out[491] = -43.675799641021079;
out[492] = -40.74868784166955;
out[493] = -69.368640085185291;
out[494] = -17.974903844364839;
out[495] = 184.7505962980652;
out[496] = 94.61510234445565;
out[497] = 69.368640085185305;
out[498] = 17.974903844364825;
out[499] = 43.675799641021079;
out[500] = 40.74868784166955;
out[501] = 69.368640085185291;
out[502] = 17.974903844364839;
out[503] = -184.7505962980652;
out[504] = -94.61510234445565;
out[508] = -1.0;
out[543] = 17.974903844364825;
out[544] = -69.368640085185305;
out[545] = 40.74868784166955;
out[546] = -43.675799641021079;
out[547] = 17.974903844364839;
out[548] = -69.368640085185291;
out[549] = -94.61510234445565;
out[550] = 184.7505962980652;
out[551] = -17.974903844364825;
out[552] = 69.368640085185305;
out[553] = -40.74868784166955;
out[554] = 43.675799641021079;
out[555] = -17.974903844364839;
out[556] = 69.368640085185291;
out[557] = 94.61510234445565;
out[558] = -184.7505962980652;
out[567] = -1.0;
out[597] = -184.75059629806526;
out[598] = -94.615102344455664;
out[599] = 69.368640085185305;
out[600] = 17.974903844364835;
out[601] = 43.675799641021079;
out[602] = 40.748687841669557;
out[603] = 69.368640085185291;
out[604] = 17.974903844364821;
out[605] = 184.75059629806526;
out[606] = 94.615102344455664;
out[607] = -69.368640085185305;
out[608] = -17.974903844364835;
out[609] = -43.675799641021079;
out[610] = -40.748687841669557;
out[611] = -69.368640085185291;
out[612] = -17.974903844364821;
out[638] = -1.0;
out[651] = 94.615102344455664;
out[652] = -184.75059629806526;
out[653] = -17.974903844364835;
out[654] = 69.368640085185305;
out[655] = -40.748687841669557;
out[656] = 43.675799641021079;
out[657] = -17.974903844364821;
out[658] = 69.368640085185291;
out[659] = -94.615102344455664;
out[660] = 184.75059629806526;
out[661] = 17.974903844364835;
out[662] = -69.368640085185305;
out[663] = 40.748687841669557;
out[664] = -43.675799641021079;
out[665] = 17.974903844364821;
out[666] = -69.368640085185291;
out[696] = -1.0;
out[705] = 69.368640085185291;
out[706] = 17.974903844364825;
out[707] = -184.7505962980652;
out[708] = -94.615102344455636;
out[709] = 69.368640085185319;
out[710] = 17.97490384436481;
out[711] = 43.675799641021079;
out[712] = 40.748687841669565;
out[713] = -69.368640085185291;
out[714] = -17.974903844364825;
out[715] = 184.7505962980652;
out[716] = 94.615102344455636;
out[717] = -69.368640085185319;
out[718] = -17.97490384436481;
out[719] = -43.675799641021079;
out[720] = -40.748687841669565;
out[747] = -1.0;
out[759] = -17.974903844364825;
out[760] = 69.368640085185291;
out[761] = 94.615102344455636;
out[762] = -184.7505962980652;
out[763] = -17.97490384436481;
out[764] = 69.368640085185319;
out[765] = -40.748687841669565;
out[766] = 43.675799641021079;
out[767] = 17.974903844364825;
out[768] = -69.368640085185291;
out[769] = -94.615102344455636;
out[770] = 184.7505962980652;
out[771] = 17.97490384436481;
out[772] = -69.368640085185319;
out[773] = 40.748687841669565;
out[774] = -43.675799641021079;
out[805] = -1.0;
out[813] = 43.675799641021101;
out[814] = 40.748687841669579;
out[815] = 69.368640085185305;
out[816] = 17.974903844364821;
out[817] = -184.75059629806526;
out[818] = -94.61510234445565;
out[819] = 69.368640085185305;
out[820] = 17.974903844364821;
out[821] = -43.675799641021101;
out[822] = -40.748687841669579;
out[823] = -69.368640085185305;
out[824] = -17.974903844364821;
out[825] = 184.75059629806526;
out[826] = 94.61510234445565;
out[827] = -69.368640085185305;
out[828] = -17.974903844364821;
out[856] = -1.0;
out[867] = -40.748687841669579;
out[868] = 43.675799641021101;
out[869] = -17.974903844364821;
out[870] = 69.368640085185305;
out[871] = 94.61510234445565;
out[872] = -184.75059629806526;
out[873] = -17.974903844364821;
out[874] = 69.368640085185305;
out[875] = 40.748687841669579;
out[876] = -43.675799641021101;
out[877] = 17.974903844364821;
out[878] = -69.368640085185305;
out[879] = -94.61510234445565;
out[880] = 184.75059629806526;
out[881] = 17.974903844364821;
out[882] = -69.368640085185305;
out[914] = -1.0;
out[921] = 69.368640085185305;
out[922] = 17.974903844364825;
out[923] = 43.675799641021079;
out[924] = 40.74868784166955;
out[925] = 69.368640085185291;
out[926] = 17.974903844364839;
out[927] = -184.7505962980652;
out[928] = -94.61510234445565;
out[929] = -69.368640085185305;
out[930] = -17.974903844364825;
out[931] = -43.675799641021079;
out[932] = -40.74868784166955;
out[933] = -69.368640085185291;
out[934] = -17.974903844364839;
out[935] = 184.7505962980652;
out[936] = 94.61510234445565;
out[965] = -1.0;
out[975] = -17.974903844364825;
out[976] = 69.368640085185305;
out[977] = -40.74868784166955;
out[978] = 43.675799641021079;
out[979] = -17.974903844364839;
out[980] = 69.368640085185291;
out[981] = 94.61510234445565;
out[982] = -184.7505962980652;
out[983] = 17.974903844364825;
out[984] = -69.368640085185305;
out[985] = 40.74868784166955;
out[986] = -43.675799641021079;
out[987] = 17.974903844364839;
out[988] = -69.368640085185291;
out[989] = -94.61510234445565;
out[990] = 184.7505962980652;
out[1023] = -1.0;
out[1029] = -1.0;
out[1049] = 1.0;
out[1064] = 1.0;
out[1085] = -1.0;
out[1103] = 1.0;
out[1119] = 1.0;
out[1141] = -1.0;
out[1157] = 1.0;
out[1174] = 1.0;
out[1197] = -1.0;
out[1211] = 1.0;
out[1261] = 1.0;
out[1262] = 1.0;
out[1263] = 1.0;
out[1264] = 1.0;
out[1300] = -1.0;
out[1324] = 1.0;
out[1337] = 1.0;
out[1356] = -1.0;
out[1378] = 1.0;
out[1392] = 1.0;
out[1412] = -1.0;
out[1432] = 1.0;
out[1447] = 1.0;
out[1468] = -1.0;
out[1486] = 1.0;
out[1536] = 1.0;
out[1537] = 1.0;
out[1538] = 1.0;
out[1539] = 1.0;
out[1595] = -1.0;
out[1705] = -1.0;
out[1759] = 0.33333333333333331;
out[1813] = 0.33333333333333331;
out[1867] = 0.33333333333333331;
out[2055] = -1.0;
out[2090] = 1.0;
out[2111] = -1.0;
out[2145] = 1.0;
out[2167] = -1.0;
out[2200] = 1.0;
out[2218] = -1.0;
out[2255] = 1.0;
out[2274] = -1.0;
out[2310] = 1.0;
out[2330] = -1.0;
out[2365] = 1.0;
out[2387] = -1.0;
out[2443] = -1.0;
out[2499] = -1.0;
out[2555] = -1.0;
out[2604] = -1.0;
out[2660] = -1.0;
out[2716] = -1.0;
out[2772] = -1.0;
out[2860] = -1.0;
out[2915] = -1.0;

}

void sp_jac_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = -2.7777777777777776e-7*y[26]*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0
)
: (
   0
))))))/(p[13]*y[27]);
out[1] = -2.7777777777777776e-7*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0*x[0] + 600.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0*x[0] + 620.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258*x[0] + 673.33333333333326
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0*x[0] + 620.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0*x[0] + 350.0
)
: (
   750.0
))))))/(p[13]*y[27]);
out[2] = 2.7777777777777776e-7*y[26]*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0*x[0] + 600.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0*x[0] + 620.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258*x[0] + 673.33333333333326
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0*x[0] + 620.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0*x[0] + 350.0
)
: (
   750.0
))))))/(p[13]*pow(y[27], 2));
out[328] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[35];
out[329] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[36];
out[330] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[37] + u[0];
out[331] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[332] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38];
out[333] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[39];
out[334] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[40] + 1.0*u[1];
out[335] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[337] = y[16];
out[338] = y[17];
out[339] = y[18];
out[340] = 1.0*y[21];
out[341] = 1.0*y[22];
out[342] = 1.0*y[23];
out[343] = ((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0
)
: (
   0
))))));
out[344] = -p[14]/y[27];
out[345] = p[14]*y[26]/pow(y[27], 2) - 1.0;
out[349] = -y[29];
out[350] = -1.0*y[32];
out[352] = -y[0];
out[353] = -1.0*y[1];
out[354] = -y[30];
out[355] = -1.0*y[33];
out[357] = -y[2];
out[358] = -1.0*y[3];
out[359] = -y[31];
out[360] = -1.0*y[34];
out[362] = -y[4];
out[363] = -1.0*y[5];
out[364] = 1.0*y[32];
out[365] = -1.0*y[29];
out[366] = -1.0*y[1];
out[367] = 1.0*y[0];
out[368] = 1.0*y[33];
out[369] = -1.0*y[30];
out[370] = -1.0*y[3];
out[371] = 1.0*y[2];
out[372] = 1.0*y[34];
out[373] = -1.0*y[31];
out[374] = -1.0*y[5];
out[375] = 1.0*y[4];

}

void sp_jac_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[4] = -p[23];
out[279] = -p[1];
out[281] = 1.0*p[0];
out[284] = -p[1];
out[286] = 1.0*p[0];
out[289] = -p[1];
out[291] = 1.0*p[0];
out[294] = -p[3];
out[296] = 1.0*p[2];
out[301] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[302] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[304] = -1.0*p[0];
out[305] = -1.0*p[1];
out[309] = -1.0*p[0];
out[310] = -1.0*p[1];
out[314] = -1.0*p[0];
out[315] = -1.0*p[1];
out[319] = -1.0*p[2];
out[320] = -1.0*p[3];
out[322] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[327] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[346] = p[9];
out[347] = -p[10];
out[377] = -p[1];
out[378] = 1.0*p[0];
out[381] = -p[1];
out[382] = 1.0*p[0];
out[385] = -p[1];
out[386] = 1.0*p[0];
out[389] = -p[0];
out[390] = -1.0*p[1];
out[393] = -p[0];
out[394] = -1.0*p[1];
out[397] = -p[0];
out[398] = -1.0*p[1];
out[401] = -p[16];
out[402] = 1.0*p[15];
out[404] = -p[16];
out[405] = 1.0*p[15];
out[407] = -p[16];
out[408] = 1.0*p[15];
out[410] = -p[18];
out[411] = 1.0*p[17];
out[413] = -1.0*p[15];
out[414] = -1.0*p[16];
out[416] = -1.0*p[15];
out[417] = -1.0*p[16];
out[419] = -1.0*p[15];
out[420] = -1.0*p[16];
out[422] = -1.0*p[17];
out[423] = -1.0*p[18];
out[425] = p[22];
out[426] = -p[21];

}

void sp_jac_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[3] = -1.0;
out[5] = -1.0;
out[6] = 184.75059629806526;
out[7] = 94.615102344455664;
out[8] = -69.368640085185305;
out[9] = -17.974903844364835;
out[10] = -43.675799641021079;
out[11] = -40.748687841669557;
out[12] = -69.368640085185291;
out[13] = -17.974903844364821;
out[14] = -184.75059629806526;
out[15] = -94.615102344455664;
out[16] = 69.368640085185305;
out[17] = 17.974903844364835;
out[18] = 43.675799641021079;
out[19] = 40.748687841669557;
out[20] = 69.368640085185291;
out[21] = 17.974903844364821;
out[22] = -1.0;
out[23] = -94.615102344455664;
out[24] = 184.75059629806526;
out[25] = 17.974903844364835;
out[26] = -69.368640085185305;
out[27] = 40.748687841669557;
out[28] = -43.675799641021079;
out[29] = 17.974903844364821;
out[30] = -69.368640085185291;
out[31] = 94.615102344455664;
out[32] = -184.75059629806526;
out[33] = -17.974903844364835;
out[34] = 69.368640085185305;
out[35] = -40.748687841669557;
out[36] = 43.675799641021079;
out[37] = -17.974903844364821;
out[38] = 69.368640085185291;
out[39] = -1.0;
out[40] = -69.368640085185291;
out[41] = -17.974903844364825;
out[42] = 184.7505962980652;
out[43] = 94.615102344455636;
out[44] = -69.368640085185319;
out[45] = -17.97490384436481;
out[46] = -43.675799641021079;
out[47] = -40.748687841669565;
out[48] = 69.368640085185291;
out[49] = 17.974903844364825;
out[50] = -184.7505962980652;
out[51] = -94.615102344455636;
out[52] = 69.368640085185319;
out[53] = 17.97490384436481;
out[54] = 43.675799641021079;
out[55] = 40.748687841669565;
out[56] = -1.0;
out[57] = 17.974903844364825;
out[58] = -69.368640085185291;
out[59] = -94.615102344455636;
out[60] = 184.7505962980652;
out[61] = 17.97490384436481;
out[62] = -69.368640085185319;
out[63] = 40.748687841669565;
out[64] = -43.675799641021079;
out[65] = -17.974903844364825;
out[66] = 69.368640085185291;
out[67] = 94.615102344455636;
out[68] = -184.7505962980652;
out[69] = -17.97490384436481;
out[70] = 69.368640085185319;
out[71] = -40.748687841669565;
out[72] = 43.675799641021079;
out[73] = -1.0;
out[74] = -43.675799641021101;
out[75] = -40.748687841669579;
out[76] = -69.368640085185305;
out[77] = -17.974903844364821;
out[78] = 184.75059629806526;
out[79] = 94.61510234445565;
out[80] = -69.368640085185305;
out[81] = -17.974903844364821;
out[82] = 43.675799641021101;
out[83] = 40.748687841669579;
out[84] = 69.368640085185305;
out[85] = 17.974903844364821;
out[86] = -184.75059629806526;
out[87] = -94.61510234445565;
out[88] = 69.368640085185305;
out[89] = 17.974903844364821;
out[90] = -1.0;
out[91] = 40.748687841669579;
out[92] = -43.675799641021101;
out[93] = 17.974903844364821;
out[94] = -69.368640085185305;
out[95] = -94.61510234445565;
out[96] = 184.75059629806526;
out[97] = 17.974903844364821;
out[98] = -69.368640085185305;
out[99] = -40.748687841669579;
out[100] = 43.675799641021101;
out[101] = -17.974903844364821;
out[102] = 69.368640085185305;
out[103] = 94.61510234445565;
out[104] = -184.75059629806526;
out[105] = -17.974903844364821;
out[106] = 69.368640085185305;
out[107] = -1.0;
out[108] = -69.368640085185305;
out[109] = -17.974903844364825;
out[110] = -43.675799641021079;
out[111] = -40.74868784166955;
out[112] = -69.368640085185291;
out[113] = -17.974903844364839;
out[114] = 184.7505962980652;
out[115] = 94.61510234445565;
out[116] = 69.368640085185305;
out[117] = 17.974903844364825;
out[118] = 43.675799641021079;
out[119] = 40.74868784166955;
out[120] = 69.368640085185291;
out[121] = 17.974903844364839;
out[122] = -184.7505962980652;
out[123] = -94.61510234445565;
out[124] = -1.0;
out[125] = 17.974903844364825;
out[126] = -69.368640085185305;
out[127] = 40.74868784166955;
out[128] = -43.675799641021079;
out[129] = 17.974903844364839;
out[130] = -69.368640085185291;
out[131] = -94.61510234445565;
out[132] = 184.7505962980652;
out[133] = -17.974903844364825;
out[134] = 69.368640085185305;
out[135] = -40.74868784166955;
out[136] = 43.675799641021079;
out[137] = -17.974903844364839;
out[138] = 69.368640085185291;
out[139] = 94.61510234445565;
out[140] = -184.7505962980652;
out[141] = -1.0;
out[142] = -184.75059629806526;
out[143] = -94.615102344455664;
out[144] = 69.368640085185305;
out[145] = 17.974903844364835;
out[146] = 43.675799641021079;
out[147] = 40.748687841669557;
out[148] = 69.368640085185291;
out[149] = 17.974903844364821;
out[150] = 184.75059629806526;
out[151] = 94.615102344455664;
out[152] = -69.368640085185305;
out[153] = -17.974903844364835;
out[154] = -43.675799641021079;
out[155] = -40.748687841669557;
out[156] = -69.368640085185291;
out[157] = -17.974903844364821;
out[158] = -1.0;
out[159] = 94.615102344455664;
out[160] = -184.75059629806526;
out[161] = -17.974903844364835;
out[162] = 69.368640085185305;
out[163] = -40.748687841669557;
out[164] = 43.675799641021079;
out[165] = -17.974903844364821;
out[166] = 69.368640085185291;
out[167] = -94.615102344455664;
out[168] = 184.75059629806526;
out[169] = 17.974903844364835;
out[170] = -69.368640085185305;
out[171] = 40.748687841669557;
out[172] = -43.675799641021079;
out[173] = 17.974903844364821;
out[174] = -69.368640085185291;
out[175] = -1.0;
out[176] = 69.368640085185291;
out[177] = 17.974903844364825;
out[178] = -184.7505962980652;
out[179] = -94.615102344455636;
out[180] = 69.368640085185319;
out[181] = 17.97490384436481;
out[182] = 43.675799641021079;
out[183] = 40.748687841669565;
out[184] = -69.368640085185291;
out[185] = -17.974903844364825;
out[186] = 184.7505962980652;
out[187] = 94.615102344455636;
out[188] = -69.368640085185319;
out[189] = -17.97490384436481;
out[190] = -43.675799641021079;
out[191] = -40.748687841669565;
out[192] = -1.0;
out[193] = -17.974903844364825;
out[194] = 69.368640085185291;
out[195] = 94.615102344455636;
out[196] = -184.7505962980652;
out[197] = -17.97490384436481;
out[198] = 69.368640085185319;
out[199] = -40.748687841669565;
out[200] = 43.675799641021079;
out[201] = 17.974903844364825;
out[202] = -69.368640085185291;
out[203] = -94.615102344455636;
out[204] = 184.7505962980652;
out[205] = 17.97490384436481;
out[206] = -69.368640085185319;
out[207] = 40.748687841669565;
out[208] = -43.675799641021079;
out[209] = -1.0;
out[210] = 43.675799641021101;
out[211] = 40.748687841669579;
out[212] = 69.368640085185305;
out[213] = 17.974903844364821;
out[214] = -184.75059629806526;
out[215] = -94.61510234445565;
out[216] = 69.368640085185305;
out[217] = 17.974903844364821;
out[218] = -43.675799641021101;
out[219] = -40.748687841669579;
out[220] = -69.368640085185305;
out[221] = -17.974903844364821;
out[222] = 184.75059629806526;
out[223] = 94.61510234445565;
out[224] = -69.368640085185305;
out[225] = -17.974903844364821;
out[226] = -1.0;
out[227] = -40.748687841669579;
out[228] = 43.675799641021101;
out[229] = -17.974903844364821;
out[230] = 69.368640085185305;
out[231] = 94.61510234445565;
out[232] = -184.75059629806526;
out[233] = -17.974903844364821;
out[234] = 69.368640085185305;
out[235] = 40.748687841669579;
out[236] = -43.675799641021101;
out[237] = 17.974903844364821;
out[238] = -69.368640085185305;
out[239] = -94.61510234445565;
out[240] = 184.75059629806526;
out[241] = 17.974903844364821;
out[242] = -69.368640085185305;
out[243] = -1.0;
out[244] = 69.368640085185305;
out[245] = 17.974903844364825;
out[246] = 43.675799641021079;
out[247] = 40.74868784166955;
out[248] = 69.368640085185291;
out[249] = 17.974903844364839;
out[250] = -184.7505962980652;
out[251] = -94.61510234445565;
out[252] = -69.368640085185305;
out[253] = -17.974903844364825;
out[254] = -43.675799641021079;
out[255] = -40.74868784166955;
out[256] = -69.368640085185291;
out[257] = -17.974903844364839;
out[258] = 184.7505962980652;
out[259] = 94.61510234445565;
out[260] = -1.0;
out[261] = -17.974903844364825;
out[262] = 69.368640085185305;
out[263] = -40.74868784166955;
out[264] = 43.675799641021079;
out[265] = -17.974903844364839;
out[266] = 69.368640085185291;
out[267] = 94.61510234445565;
out[268] = -184.7505962980652;
out[269] = 17.974903844364825;
out[270] = -69.368640085185305;
out[271] = 40.74868784166955;
out[272] = -43.675799641021079;
out[273] = 17.974903844364839;
out[274] = -69.368640085185291;
out[275] = -94.61510234445565;
out[276] = 184.7505962980652;
out[277] = -1.0;
out[278] = -1.0;
out[280] = 1.0;
out[282] = 1.0;
out[283] = -1.0;
out[285] = 1.0;
out[287] = 1.0;
out[288] = -1.0;
out[290] = 1.0;
out[292] = 1.0;
out[293] = -1.0;
out[295] = 1.0;
out[297] = 1.0;
out[298] = 1.0;
out[299] = 1.0;
out[300] = 1.0;
out[303] = -1.0;
out[306] = 1.0;
out[307] = 1.0;
out[308] = -1.0;
out[311] = 1.0;
out[312] = 1.0;
out[313] = -1.0;
out[316] = 1.0;
out[317] = 1.0;
out[318] = -1.0;
out[321] = 1.0;
out[323] = 1.0;
out[324] = 1.0;
out[325] = 1.0;
out[326] = 1.0;
out[336] = -1.0;
out[348] = -1.0;
out[351] = 0.33333333333333331;
out[356] = 0.33333333333333331;
out[361] = 0.33333333333333331;
out[376] = -1.0;
out[379] = 1.0;
out[380] = -1.0;
out[383] = 1.0;
out[384] = -1.0;
out[387] = 1.0;
out[388] = -1.0;
out[391] = 1.0;
out[392] = -1.0;
out[395] = 1.0;
out[396] = -1.0;
out[399] = 1.0;
out[400] = -1.0;
out[403] = -1.0;
out[406] = -1.0;
out[409] = -1.0;
out[412] = -1.0;
out[415] = -1.0;
out[418] = -1.0;
out[421] = -1.0;
out[424] = -1.0;
out[427] = -1.0;

}

void de_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.3888888888888888e-7*Dt*y[26]*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0
)
: (
   0
))))))/(p[13]*y[27]) + 1.0;
out[29] = 1.3888888888888888e-7*Dt*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0*x[0] + 600.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0*x[0] + 620.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258*x[0] + 673.33333333333326
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0*x[0] + 620.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0*x[0] + 350.0
)
: (
   750.0
))))))/(p[13]*y[27]);
out[30] = -1.3888888888888888e-7*Dt*y[26]*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0*x[0] + 600.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0*x[0] + 620.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258*x[0] + 673.33333333333326
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0*x[0] + 620.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0*x[0] + 350.0
)
: (
   750.0
))))))/(p[13]*pow(y[27], 2));
out[1585] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[35];
out[1586] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[36];
out[1587] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[37] + u[0];
out[1588] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1590] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38];
out[1591] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[39];
out[1592] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[40] + 1.0*u[1];
out[1593] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[1604] = y[16];
out[1605] = y[17];
out[1606] = y[18];
out[1607] = 1.0*y[21];
out[1608] = 1.0*y[22];
out[1609] = 1.0*y[23];
out[1620] = ((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0
)
: (
   0
))))));
out[1649] = -p[14]/y[27];
out[1650] = p[14]*y[26]/pow(y[27], 2) - 1.0;
out[1731] = -y[29];
out[1732] = -1.0*y[32];
out[1760] = -y[0];
out[1763] = -1.0*y[1];
out[1787] = -y[30];
out[1788] = -1.0*y[33];
out[1815] = -y[2];
out[1818] = -1.0*y[3];
out[1843] = -y[31];
out[1844] = -1.0*y[34];
out[1870] = -y[4];
out[1873] = -1.0*y[5];
out[1893] = 1.0*y[32];
out[1894] = -1.0*y[29];
out[1922] = -1.0*y[1];
out[1925] = 1.0*y[0];
out[1949] = 1.0*y[33];
out[1950] = -1.0*y[30];
out[1977] = -1.0*y[3];
out[1980] = 1.0*y[2];
out[2005] = 1.0*y[34];
out[2006] = -1.0*y[31];
out[2032] = -1.0*y[5];
out[2035] = 1.0*y[4];

}

void de_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[54] = 0.5*Dt;
out[110] = 0.5*Dt*p[23] + 1.0;
out[160] = 0.5*Dt;
out[1045] = -p[1];
out[1050] = 1.0*p[0];
out[1100] = -p[1];
out[1105] = 1.0*p[0];
out[1155] = -p[1];
out[1160] = 1.0*p[0];
out[1210] = -p[3];
out[1215] = 1.0*p[2];
out[1265] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1270] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1315] = -1.0*p[0];
out[1320] = -1.0*p[1];
out[1370] = -1.0*p[0];
out[1375] = -1.0*p[1];
out[1425] = -1.0*p[0];
out[1430] = -1.0*p[1];
out[1480] = -1.0*p[2];
out[1485] = -1.0*p[3];
out[1535] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1540] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[1674] = p[9];
out[1675] = -p[10];
out[2084] = -p[1];
out[2087] = 1.0*p[0];
out[2139] = -p[1];
out[2142] = 1.0*p[0];
out[2194] = -p[1];
out[2197] = 1.0*p[0];
out[2246] = -p[0];
out[2249] = -1.0*p[1];
out[2301] = -p[0];
out[2304] = -1.0*p[1];
out[2356] = -p[0];
out[2359] = -1.0*p[1];
out[2420] = -p[16];
out[2424] = 1.0*p[15];
out[2475] = -p[16];
out[2479] = 1.0*p[15];
out[2530] = -p[16];
out[2534] = 1.0*p[15];
out[2585] = -p[18];
out[2589] = 1.0*p[17];
out[2636] = -1.0*p[15];
out[2640] = -1.0*p[16];
out[2691] = -1.0*p[15];
out[2695] = -1.0*p[16];
out[2746] = -1.0*p[15];
out[2750] = -1.0*p[16];
out[2801] = -1.0*p[17];
out[2805] = -1.0*p[18];
out[2864] = p[22];
out[2914] = -p[21];

}

void de_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[55] = 1.0;
out[165] = 184.75059629806526;
out[166] = 94.615102344455664;
out[167] = -69.368640085185305;
out[168] = -17.974903844364835;
out[169] = -43.675799641021079;
out[170] = -40.748687841669557;
out[171] = -69.368640085185291;
out[172] = -17.974903844364821;
out[173] = -184.75059629806526;
out[174] = -94.615102344455664;
out[175] = 69.368640085185305;
out[176] = 17.974903844364835;
out[177] = 43.675799641021079;
out[178] = 40.748687841669557;
out[179] = 69.368640085185291;
out[180] = 17.974903844364821;
out[181] = -1.0;
out[219] = -94.615102344455664;
out[220] = 184.75059629806526;
out[221] = 17.974903844364835;
out[222] = -69.368640085185305;
out[223] = 40.748687841669557;
out[224] = -43.675799641021079;
out[225] = 17.974903844364821;
out[226] = -69.368640085185291;
out[227] = 94.615102344455664;
out[228] = -184.75059629806526;
out[229] = -17.974903844364835;
out[230] = 69.368640085185305;
out[231] = -40.748687841669557;
out[232] = 43.675799641021079;
out[233] = -17.974903844364821;
out[234] = 69.368640085185291;
out[240] = -1.0;
out[273] = -69.368640085185291;
out[274] = -17.974903844364825;
out[275] = 184.7505962980652;
out[276] = 94.615102344455636;
out[277] = -69.368640085185319;
out[278] = -17.97490384436481;
out[279] = -43.675799641021079;
out[280] = -40.748687841669565;
out[281] = 69.368640085185291;
out[282] = 17.974903844364825;
out[283] = -184.7505962980652;
out[284] = -94.615102344455636;
out[285] = 69.368640085185319;
out[286] = 17.97490384436481;
out[287] = 43.675799641021079;
out[288] = 40.748687841669565;
out[290] = -1.0;
out[327] = 17.974903844364825;
out[328] = -69.368640085185291;
out[329] = -94.615102344455636;
out[330] = 184.7505962980652;
out[331] = 17.97490384436481;
out[332] = -69.368640085185319;
out[333] = 40.748687841669565;
out[334] = -43.675799641021079;
out[335] = -17.974903844364825;
out[336] = 69.368640085185291;
out[337] = 94.615102344455636;
out[338] = -184.7505962980652;
out[339] = -17.97490384436481;
out[340] = 69.368640085185319;
out[341] = -40.748687841669565;
out[342] = 43.675799641021079;
out[349] = -1.0;
out[381] = -43.675799641021101;
out[382] = -40.748687841669579;
out[383] = -69.368640085185305;
out[384] = -17.974903844364821;
out[385] = 184.75059629806526;
out[386] = 94.61510234445565;
out[387] = -69.368640085185305;
out[388] = -17.974903844364821;
out[389] = 43.675799641021101;
out[390] = 40.748687841669579;
out[391] = 69.368640085185305;
out[392] = 17.974903844364821;
out[393] = -184.75059629806526;
out[394] = -94.61510234445565;
out[395] = 69.368640085185305;
out[396] = 17.974903844364821;
out[399] = -1.0;
out[435] = 40.748687841669579;
out[436] = -43.675799641021101;
out[437] = 17.974903844364821;
out[438] = -69.368640085185305;
out[439] = -94.61510234445565;
out[440] = 184.75059629806526;
out[441] = 17.974903844364821;
out[442] = -69.368640085185305;
out[443] = -40.748687841669579;
out[444] = 43.675799641021101;
out[445] = -17.974903844364821;
out[446] = 69.368640085185305;
out[447] = 94.61510234445565;
out[448] = -184.75059629806526;
out[449] = -17.974903844364821;
out[450] = 69.368640085185305;
out[458] = -1.0;
out[489] = -69.368640085185305;
out[490] = -17.974903844364825;
out[491] = -43.675799641021079;
out[492] = -40.74868784166955;
out[493] = -69.368640085185291;
out[494] = -17.974903844364839;
out[495] = 184.7505962980652;
out[496] = 94.61510234445565;
out[497] = 69.368640085185305;
out[498] = 17.974903844364825;
out[499] = 43.675799641021079;
out[500] = 40.74868784166955;
out[501] = 69.368640085185291;
out[502] = 17.974903844364839;
out[503] = -184.7505962980652;
out[504] = -94.61510234445565;
out[508] = -1.0;
out[543] = 17.974903844364825;
out[544] = -69.368640085185305;
out[545] = 40.74868784166955;
out[546] = -43.675799641021079;
out[547] = 17.974903844364839;
out[548] = -69.368640085185291;
out[549] = -94.61510234445565;
out[550] = 184.7505962980652;
out[551] = -17.974903844364825;
out[552] = 69.368640085185305;
out[553] = -40.74868784166955;
out[554] = 43.675799641021079;
out[555] = -17.974903844364839;
out[556] = 69.368640085185291;
out[557] = 94.61510234445565;
out[558] = -184.7505962980652;
out[567] = -1.0;
out[597] = -184.75059629806526;
out[598] = -94.615102344455664;
out[599] = 69.368640085185305;
out[600] = 17.974903844364835;
out[601] = 43.675799641021079;
out[602] = 40.748687841669557;
out[603] = 69.368640085185291;
out[604] = 17.974903844364821;
out[605] = 184.75059629806526;
out[606] = 94.615102344455664;
out[607] = -69.368640085185305;
out[608] = -17.974903844364835;
out[609] = -43.675799641021079;
out[610] = -40.748687841669557;
out[611] = -69.368640085185291;
out[612] = -17.974903844364821;
out[638] = -1.0;
out[651] = 94.615102344455664;
out[652] = -184.75059629806526;
out[653] = -17.974903844364835;
out[654] = 69.368640085185305;
out[655] = -40.748687841669557;
out[656] = 43.675799641021079;
out[657] = -17.974903844364821;
out[658] = 69.368640085185291;
out[659] = -94.615102344455664;
out[660] = 184.75059629806526;
out[661] = 17.974903844364835;
out[662] = -69.368640085185305;
out[663] = 40.748687841669557;
out[664] = -43.675799641021079;
out[665] = 17.974903844364821;
out[666] = -69.368640085185291;
out[696] = -1.0;
out[705] = 69.368640085185291;
out[706] = 17.974903844364825;
out[707] = -184.7505962980652;
out[708] = -94.615102344455636;
out[709] = 69.368640085185319;
out[710] = 17.97490384436481;
out[711] = 43.675799641021079;
out[712] = 40.748687841669565;
out[713] = -69.368640085185291;
out[714] = -17.974903844364825;
out[715] = 184.7505962980652;
out[716] = 94.615102344455636;
out[717] = -69.368640085185319;
out[718] = -17.97490384436481;
out[719] = -43.675799641021079;
out[720] = -40.748687841669565;
out[747] = -1.0;
out[759] = -17.974903844364825;
out[760] = 69.368640085185291;
out[761] = 94.615102344455636;
out[762] = -184.7505962980652;
out[763] = -17.97490384436481;
out[764] = 69.368640085185319;
out[765] = -40.748687841669565;
out[766] = 43.675799641021079;
out[767] = 17.974903844364825;
out[768] = -69.368640085185291;
out[769] = -94.615102344455636;
out[770] = 184.7505962980652;
out[771] = 17.97490384436481;
out[772] = -69.368640085185319;
out[773] = 40.748687841669565;
out[774] = -43.675799641021079;
out[805] = -1.0;
out[813] = 43.675799641021101;
out[814] = 40.748687841669579;
out[815] = 69.368640085185305;
out[816] = 17.974903844364821;
out[817] = -184.75059629806526;
out[818] = -94.61510234445565;
out[819] = 69.368640085185305;
out[820] = 17.974903844364821;
out[821] = -43.675799641021101;
out[822] = -40.748687841669579;
out[823] = -69.368640085185305;
out[824] = -17.974903844364821;
out[825] = 184.75059629806526;
out[826] = 94.61510234445565;
out[827] = -69.368640085185305;
out[828] = -17.974903844364821;
out[856] = -1.0;
out[867] = -40.748687841669579;
out[868] = 43.675799641021101;
out[869] = -17.974903844364821;
out[870] = 69.368640085185305;
out[871] = 94.61510234445565;
out[872] = -184.75059629806526;
out[873] = -17.974903844364821;
out[874] = 69.368640085185305;
out[875] = 40.748687841669579;
out[876] = -43.675799641021101;
out[877] = 17.974903844364821;
out[878] = -69.368640085185305;
out[879] = -94.61510234445565;
out[880] = 184.75059629806526;
out[881] = 17.974903844364821;
out[882] = -69.368640085185305;
out[914] = -1.0;
out[921] = 69.368640085185305;
out[922] = 17.974903844364825;
out[923] = 43.675799641021079;
out[924] = 40.74868784166955;
out[925] = 69.368640085185291;
out[926] = 17.974903844364839;
out[927] = -184.7505962980652;
out[928] = -94.61510234445565;
out[929] = -69.368640085185305;
out[930] = -17.974903844364825;
out[931] = -43.675799641021079;
out[932] = -40.74868784166955;
out[933] = -69.368640085185291;
out[934] = -17.974903844364839;
out[935] = 184.7505962980652;
out[936] = 94.61510234445565;
out[965] = -1.0;
out[975] = -17.974903844364825;
out[976] = 69.368640085185305;
out[977] = -40.74868784166955;
out[978] = 43.675799641021079;
out[979] = -17.974903844364839;
out[980] = 69.368640085185291;
out[981] = 94.61510234445565;
out[982] = -184.7505962980652;
out[983] = 17.974903844364825;
out[984] = -69.368640085185305;
out[985] = 40.74868784166955;
out[986] = -43.675799641021079;
out[987] = 17.974903844364839;
out[988] = -69.368640085185291;
out[989] = -94.61510234445565;
out[990] = 184.7505962980652;
out[1023] = -1.0;
out[1029] = -1.0;
out[1049] = 1.0;
out[1064] = 1.0;
out[1085] = -1.0;
out[1103] = 1.0;
out[1119] = 1.0;
out[1141] = -1.0;
out[1157] = 1.0;
out[1174] = 1.0;
out[1197] = -1.0;
out[1211] = 1.0;
out[1261] = 1.0;
out[1262] = 1.0;
out[1263] = 1.0;
out[1264] = 1.0;
out[1300] = -1.0;
out[1324] = 1.0;
out[1337] = 1.0;
out[1356] = -1.0;
out[1378] = 1.0;
out[1392] = 1.0;
out[1412] = -1.0;
out[1432] = 1.0;
out[1447] = 1.0;
out[1468] = -1.0;
out[1486] = 1.0;
out[1536] = 1.0;
out[1537] = 1.0;
out[1538] = 1.0;
out[1539] = 1.0;
out[1595] = -1.0;
out[1705] = -1.0;
out[1759] = 0.33333333333333331;
out[1813] = 0.33333333333333331;
out[1867] = 0.33333333333333331;
out[2055] = -1.0;
out[2090] = 1.0;
out[2111] = -1.0;
out[2145] = 1.0;
out[2167] = -1.0;
out[2200] = 1.0;
out[2218] = -1.0;
out[2255] = 1.0;
out[2274] = -1.0;
out[2310] = 1.0;
out[2330] = -1.0;
out[2365] = 1.0;
out[2387] = -1.0;
out[2443] = -1.0;
out[2499] = -1.0;
out[2555] = -1.0;
out[2604] = -1.0;
out[2660] = -1.0;
out[2716] = -1.0;
out[2772] = -1.0;
out[2860] = -1.0;
out[2915] = -1.0;

}

void sp_jac_trap_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.3888888888888888e-7*Dt*y[26]*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0
)
: (
   0
))))))/(p[13]*y[27]) + 1.0;
out[1] = 1.3888888888888888e-7*Dt*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0*x[0] + 600.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0*x[0] + 620.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258*x[0] + 673.33333333333326
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0*x[0] + 620.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0*x[0] + 350.0
)
: (
   750.0
))))))/(p[13]*y[27]);
out[2] = -1.3888888888888888e-7*Dt*y[26]*((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0*x[0] + 600.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0*x[0] + 620.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258*x[0] + 673.33333333333326
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0*x[0] + 620.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0*x[0] + 350.0
)
: (
   750.0
))))))/(p[13]*pow(y[27], 2));
out[329] = 2.0*p[6]*y[16] + p[7]*y[16]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + y[35];
out[330] = 2.0*p[6]*y[17] + p[7]*y[17]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + y[36];
out[331] = 2.0*p[6]*y[18] + p[7]*y[18]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + y[37] + u[0];
out[332] = 2.0*p[6]*y[19] + p[7]*y[19]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[333] = 2.0*p[6]*y[21] + p[7]*y[21]*pow(pow(y[21], 2) + pow(y[16], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[38];
out[334] = 2.0*p[6]*y[22] + p[7]*y[22]*pow(pow(y[22], 2) + pow(y[17], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[39];
out[335] = 2.0*p[6]*y[23] + p[7]*y[23]*pow(pow(y[23], 2) + pow(y[18], 2) + 9.9999999999999995e-7, -0.5) + 1.0*y[40] + 1.0*u[1];
out[336] = 2.0*p[6]*y[24] + p[7]*y[24]*pow(pow(y[24], 2) + pow(y[19], 2) + 9.9999999999999995e-7, -0.5);
out[338] = y[16];
out[339] = y[17];
out[340] = y[18];
out[341] = 1.0*y[21];
out[342] = 1.0*y[22];
out[343] = 1.0*y[23];
out[344] = ((x[0] >= 0 && x[0] <= 0.10000000000000001) ? (
   500.0
)
: ((x[0] >= 0.10000000000000001 && x[0] <= 0.20000000000000001) ? (
   300.0
)
: ((x[0] >= 0.20000000000000001 && x[0] <= 0.80000000000000004) ? (
   33.333333333333258
)
: ((x[0] >= 0.80000000000000004 && x[0] <= 0.90000000000000002) ? (
   100.0
)
: ((x[0] >= 0.90000000000000002 && x[0] <= 1.0) ? (
   400.0
)
: (
   0
))))));
out[345] = -p[14]/y[27];
out[346] = p[14]*y[26]/pow(y[27], 2) - 1.0;
out[350] = -y[29];
out[351] = -1.0*y[32];
out[353] = -y[0];
out[354] = -1.0*y[1];
out[355] = -y[30];
out[356] = -1.0*y[33];
out[358] = -y[2];
out[359] = -1.0*y[3];
out[360] = -y[31];
out[361] = -1.0*y[34];
out[363] = -y[4];
out[364] = -1.0*y[5];
out[365] = 1.0*y[32];
out[366] = -1.0*y[29];
out[367] = -1.0*y[1];
out[368] = 1.0*y[0];
out[369] = 1.0*y[33];
out[370] = -1.0*y[30];
out[371] = -1.0*y[3];
out[372] = 1.0*y[2];
out[373] = 1.0*y[34];
out[374] = -1.0*y[31];
out[375] = -1.0*y[5];
out[376] = 1.0*y[4];

}

void sp_jac_trap_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[3] = 0.5*Dt;
out[5] = 0.5*Dt*p[23] + 1.0;
out[6] = 0.5*Dt;
out[280] = -p[1];
out[282] = 1.0*p[0];
out[285] = -p[1];
out[287] = 1.0*p[0];
out[290] = -p[1];
out[292] = 1.0*p[0];
out[295] = -p[3];
out[297] = 1.0*p[2];
out[302] = p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[303] = 1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[305] = -1.0*p[0];
out[306] = -1.0*p[1];
out[310] = -1.0*p[0];
out[311] = -1.0*p[1];
out[315] = -1.0*p[0];
out[316] = -1.0*p[1];
out[320] = -1.0*p[2];
out[321] = -1.0*p[3];
out[323] = -1.0*p[4]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[328] = 1.0*p[5]/(pow(p[5], 2) + 1.0*pow(p[4], 2));
out[347] = p[9];
out[348] = -p[10];
out[378] = -p[1];
out[379] = 1.0*p[0];
out[382] = -p[1];
out[383] = 1.0*p[0];
out[386] = -p[1];
out[387] = 1.0*p[0];
out[390] = -p[0];
out[391] = -1.0*p[1];
out[394] = -p[0];
out[395] = -1.0*p[1];
out[398] = -p[0];
out[399] = -1.0*p[1];
out[402] = -p[16];
out[403] = 1.0*p[15];
out[405] = -p[16];
out[406] = 1.0*p[15];
out[408] = -p[16];
out[409] = 1.0*p[15];
out[411] = -p[18];
out[412] = 1.0*p[17];
out[414] = -1.0*p[15];
out[415] = -1.0*p[16];
out[417] = -1.0*p[15];
out[418] = -1.0*p[16];
out[420] = -1.0*p[15];
out[421] = -1.0*p[16];
out[423] = -1.0*p[17];
out[424] = -1.0*p[18];
out[426] = p[22];
out[427] = -p[21];

}

void sp_jac_trap_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[4] = 1.0;
out[7] = 184.75059629806526;
out[8] = 94.615102344455664;
out[9] = -69.368640085185305;
out[10] = -17.974903844364835;
out[11] = -43.675799641021079;
out[12] = -40.748687841669557;
out[13] = -69.368640085185291;
out[14] = -17.974903844364821;
out[15] = -184.75059629806526;
out[16] = -94.615102344455664;
out[17] = 69.368640085185305;
out[18] = 17.974903844364835;
out[19] = 43.675799641021079;
out[20] = 40.748687841669557;
out[21] = 69.368640085185291;
out[22] = 17.974903844364821;
out[23] = -1.0;
out[24] = -94.615102344455664;
out[25] = 184.75059629806526;
out[26] = 17.974903844364835;
out[27] = -69.368640085185305;
out[28] = 40.748687841669557;
out[29] = -43.675799641021079;
out[30] = 17.974903844364821;
out[31] = -69.368640085185291;
out[32] = 94.615102344455664;
out[33] = -184.75059629806526;
out[34] = -17.974903844364835;
out[35] = 69.368640085185305;
out[36] = -40.748687841669557;
out[37] = 43.675799641021079;
out[38] = -17.974903844364821;
out[39] = 69.368640085185291;
out[40] = -1.0;
out[41] = -69.368640085185291;
out[42] = -17.974903844364825;
out[43] = 184.7505962980652;
out[44] = 94.615102344455636;
out[45] = -69.368640085185319;
out[46] = -17.97490384436481;
out[47] = -43.675799641021079;
out[48] = -40.748687841669565;
out[49] = 69.368640085185291;
out[50] = 17.974903844364825;
out[51] = -184.7505962980652;
out[52] = -94.615102344455636;
out[53] = 69.368640085185319;
out[54] = 17.97490384436481;
out[55] = 43.675799641021079;
out[56] = 40.748687841669565;
out[57] = -1.0;
out[58] = 17.974903844364825;
out[59] = -69.368640085185291;
out[60] = -94.615102344455636;
out[61] = 184.7505962980652;
out[62] = 17.97490384436481;
out[63] = -69.368640085185319;
out[64] = 40.748687841669565;
out[65] = -43.675799641021079;
out[66] = -17.974903844364825;
out[67] = 69.368640085185291;
out[68] = 94.615102344455636;
out[69] = -184.7505962980652;
out[70] = -17.97490384436481;
out[71] = 69.368640085185319;
out[72] = -40.748687841669565;
out[73] = 43.675799641021079;
out[74] = -1.0;
out[75] = -43.675799641021101;
out[76] = -40.748687841669579;
out[77] = -69.368640085185305;
out[78] = -17.974903844364821;
out[79] = 184.75059629806526;
out[80] = 94.61510234445565;
out[81] = -69.368640085185305;
out[82] = -17.974903844364821;
out[83] = 43.675799641021101;
out[84] = 40.748687841669579;
out[85] = 69.368640085185305;
out[86] = 17.974903844364821;
out[87] = -184.75059629806526;
out[88] = -94.61510234445565;
out[89] = 69.368640085185305;
out[90] = 17.974903844364821;
out[91] = -1.0;
out[92] = 40.748687841669579;
out[93] = -43.675799641021101;
out[94] = 17.974903844364821;
out[95] = -69.368640085185305;
out[96] = -94.61510234445565;
out[97] = 184.75059629806526;
out[98] = 17.974903844364821;
out[99] = -69.368640085185305;
out[100] = -40.748687841669579;
out[101] = 43.675799641021101;
out[102] = -17.974903844364821;
out[103] = 69.368640085185305;
out[104] = 94.61510234445565;
out[105] = -184.75059629806526;
out[106] = -17.974903844364821;
out[107] = 69.368640085185305;
out[108] = -1.0;
out[109] = -69.368640085185305;
out[110] = -17.974903844364825;
out[111] = -43.675799641021079;
out[112] = -40.74868784166955;
out[113] = -69.368640085185291;
out[114] = -17.974903844364839;
out[115] = 184.7505962980652;
out[116] = 94.61510234445565;
out[117] = 69.368640085185305;
out[118] = 17.974903844364825;
out[119] = 43.675799641021079;
out[120] = 40.74868784166955;
out[121] = 69.368640085185291;
out[122] = 17.974903844364839;
out[123] = -184.7505962980652;
out[124] = -94.61510234445565;
out[125] = -1.0;
out[126] = 17.974903844364825;
out[127] = -69.368640085185305;
out[128] = 40.74868784166955;
out[129] = -43.675799641021079;
out[130] = 17.974903844364839;
out[131] = -69.368640085185291;
out[132] = -94.61510234445565;
out[133] = 184.7505962980652;
out[134] = -17.974903844364825;
out[135] = 69.368640085185305;
out[136] = -40.74868784166955;
out[137] = 43.675799641021079;
out[138] = -17.974903844364839;
out[139] = 69.368640085185291;
out[140] = 94.61510234445565;
out[141] = -184.7505962980652;
out[142] = -1.0;
out[143] = -184.75059629806526;
out[144] = -94.615102344455664;
out[145] = 69.368640085185305;
out[146] = 17.974903844364835;
out[147] = 43.675799641021079;
out[148] = 40.748687841669557;
out[149] = 69.368640085185291;
out[150] = 17.974903844364821;
out[151] = 184.75059629806526;
out[152] = 94.615102344455664;
out[153] = -69.368640085185305;
out[154] = -17.974903844364835;
out[155] = -43.675799641021079;
out[156] = -40.748687841669557;
out[157] = -69.368640085185291;
out[158] = -17.974903844364821;
out[159] = -1.0;
out[160] = 94.615102344455664;
out[161] = -184.75059629806526;
out[162] = -17.974903844364835;
out[163] = 69.368640085185305;
out[164] = -40.748687841669557;
out[165] = 43.675799641021079;
out[166] = -17.974903844364821;
out[167] = 69.368640085185291;
out[168] = -94.615102344455664;
out[169] = 184.75059629806526;
out[170] = 17.974903844364835;
out[171] = -69.368640085185305;
out[172] = 40.748687841669557;
out[173] = -43.675799641021079;
out[174] = 17.974903844364821;
out[175] = -69.368640085185291;
out[176] = -1.0;
out[177] = 69.368640085185291;
out[178] = 17.974903844364825;
out[179] = -184.7505962980652;
out[180] = -94.615102344455636;
out[181] = 69.368640085185319;
out[182] = 17.97490384436481;
out[183] = 43.675799641021079;
out[184] = 40.748687841669565;
out[185] = -69.368640085185291;
out[186] = -17.974903844364825;
out[187] = 184.7505962980652;
out[188] = 94.615102344455636;
out[189] = -69.368640085185319;
out[190] = -17.97490384436481;
out[191] = -43.675799641021079;
out[192] = -40.748687841669565;
out[193] = -1.0;
out[194] = -17.974903844364825;
out[195] = 69.368640085185291;
out[196] = 94.615102344455636;
out[197] = -184.7505962980652;
out[198] = -17.97490384436481;
out[199] = 69.368640085185319;
out[200] = -40.748687841669565;
out[201] = 43.675799641021079;
out[202] = 17.974903844364825;
out[203] = -69.368640085185291;
out[204] = -94.615102344455636;
out[205] = 184.7505962980652;
out[206] = 17.97490384436481;
out[207] = -69.368640085185319;
out[208] = 40.748687841669565;
out[209] = -43.675799641021079;
out[210] = -1.0;
out[211] = 43.675799641021101;
out[212] = 40.748687841669579;
out[213] = 69.368640085185305;
out[214] = 17.974903844364821;
out[215] = -184.75059629806526;
out[216] = -94.61510234445565;
out[217] = 69.368640085185305;
out[218] = 17.974903844364821;
out[219] = -43.675799641021101;
out[220] = -40.748687841669579;
out[221] = -69.368640085185305;
out[222] = -17.974903844364821;
out[223] = 184.75059629806526;
out[224] = 94.61510234445565;
out[225] = -69.368640085185305;
out[226] = -17.974903844364821;
out[227] = -1.0;
out[228] = -40.748687841669579;
out[229] = 43.675799641021101;
out[230] = -17.974903844364821;
out[231] = 69.368640085185305;
out[232] = 94.61510234445565;
out[233] = -184.75059629806526;
out[234] = -17.974903844364821;
out[235] = 69.368640085185305;
out[236] = 40.748687841669579;
out[237] = -43.675799641021101;
out[238] = 17.974903844364821;
out[239] = -69.368640085185305;
out[240] = -94.61510234445565;
out[241] = 184.75059629806526;
out[242] = 17.974903844364821;
out[243] = -69.368640085185305;
out[244] = -1.0;
out[245] = 69.368640085185305;
out[246] = 17.974903844364825;
out[247] = 43.675799641021079;
out[248] = 40.74868784166955;
out[249] = 69.368640085185291;
out[250] = 17.974903844364839;
out[251] = -184.7505962980652;
out[252] = -94.61510234445565;
out[253] = -69.368640085185305;
out[254] = -17.974903844364825;
out[255] = -43.675799641021079;
out[256] = -40.74868784166955;
out[257] = -69.368640085185291;
out[258] = -17.974903844364839;
out[259] = 184.7505962980652;
out[260] = 94.61510234445565;
out[261] = -1.0;
out[262] = -17.974903844364825;
out[263] = 69.368640085185305;
out[264] = -40.74868784166955;
out[265] = 43.675799641021079;
out[266] = -17.974903844364839;
out[267] = 69.368640085185291;
out[268] = 94.61510234445565;
out[269] = -184.7505962980652;
out[270] = 17.974903844364825;
out[271] = -69.368640085185305;
out[272] = 40.74868784166955;
out[273] = -43.675799641021079;
out[274] = 17.974903844364839;
out[275] = -69.368640085185291;
out[276] = -94.61510234445565;
out[277] = 184.7505962980652;
out[278] = -1.0;
out[279] = -1.0;
out[281] = 1.0;
out[283] = 1.0;
out[284] = -1.0;
out[286] = 1.0;
out[288] = 1.0;
out[289] = -1.0;
out[291] = 1.0;
out[293] = 1.0;
out[294] = -1.0;
out[296] = 1.0;
out[298] = 1.0;
out[299] = 1.0;
out[300] = 1.0;
out[301] = 1.0;
out[304] = -1.0;
out[307] = 1.0;
out[308] = 1.0;
out[309] = -1.0;
out[312] = 1.0;
out[313] = 1.0;
out[314] = -1.0;
out[317] = 1.0;
out[318] = 1.0;
out[319] = -1.0;
out[322] = 1.0;
out[324] = 1.0;
out[325] = 1.0;
out[326] = 1.0;
out[327] = 1.0;
out[337] = -1.0;
out[349] = -1.0;
out[352] = 0.33333333333333331;
out[357] = 0.33333333333333331;
out[362] = 0.33333333333333331;
out[377] = -1.0;
out[380] = 1.0;
out[381] = -1.0;
out[384] = 1.0;
out[385] = -1.0;
out[388] = 1.0;
out[389] = -1.0;
out[392] = 1.0;
out[393] = -1.0;
out[396] = 1.0;
out[397] = -1.0;
out[400] = 1.0;
out[401] = -1.0;
out[404] = -1.0;
out[407] = -1.0;
out[410] = -1.0;
out[413] = -1.0;
out[416] = -1.0;
out[419] = -1.0;
out[422] = -1.0;
out[425] = -1.0;
out[428] = -1.0;

}

void de_Fu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Fu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Fu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[20] = 1.0;
out[53] = 1.0;

}

void de_Gu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[468] = y[18];
out[469] = 1.0*y[23];

}

void de_Gu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[506] = -p[9];
out[750] = cos(u[16]);
out[754] = -u[12]*sin(u[16]);
out[769] = cos(u[16] - 2.0943951023931953);
out[772] = -u[13]*sin(u[16] - 2.0943951023931953);
out[788] = cos(u[16] - 4.1887902047863905);
out[790] = -u[14]*sin(u[16] - 4.1887902047863905);
out[822] = 1.0*sin(u[16]);
out[826] = 1.0*u[12]*cos(u[16]);
out[841] = 1.0*sin(u[16] - 2.0943951023931953);
out[844] = 1.0*u[13]*cos(u[16] - 2.0943951023931953);
out[860] = 1.0*sin(u[16] - 4.1887902047863905);
out[862] = 1.0*u[14]*cos(u[16] - 4.1887902047863905);

}

void de_Gu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[342] = 1.0;
out[433] = 1.0;
out[511] = -1.0;
out[525] = 1.0;
out[528] = 0.33333333333333331;
out[529] = 0.33333333333333331;
out[544] = 1.0;
out[546] = 0.33333333333333331;
out[547] = 0.33333333333333331;
out[563] = 1.0;
out[564] = 0.33333333333333331;
out[565] = 0.33333333333333331;
out[584] = 1.0;
out[587] = 0.33333333333333331;
out[603] = 1.0;
out[605] = 0.33333333333333331;
out[622] = 1.0;
out[623] = 0.33333333333333331;

}

void de_Hx_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hx_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hx_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[77] = 1.0;

}

void de_Hy_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[424] = y[16]*pow(1.0*pow(y[21], 2) + pow(y[16], 2), -0.5);
out[429] = 1.0*y[21]*pow(1.0*pow(y[21], 2) + pow(y[16], 2), -0.5);
out[476] = y[17]*pow(1.0*pow(y[22], 2) + pow(y[17], 2), -0.5);
out[481] = 1.0*y[22]*pow(1.0*pow(y[22], 2) + pow(y[17], 2), -0.5);
out[528] = y[18]*pow(1.0*pow(y[23], 2) + pow(y[18], 2), -0.5);
out[533] = 1.0*y[23]*pow(1.0*pow(y[23], 2) + pow(y[18], 2), -0.5);
out[580] = y[19]*pow(1.0*pow(y[24], 2) + pow(y[19], 2), -0.5);
out[585] = 1.0*y[24]*pow(1.0*pow(y[24], 2) + pow(y[19], 2), -0.5);
out[612] = y[16];
out[613] = 1.0*y[21];
out[628] = y[0];
out[633] = 1.0*y[1];
out[663] = -1.0*y[21];
out[664] = 1.0*y[16];
out[679] = 1.0*y[1];
out[684] = -1.0*y[0];
out[716] = y[17];
out[717] = 1.0*y[22];
out[731] = y[2];
out[736] = 1.0*y[3];
out[767] = -1.0*y[22];
out[768] = 1.0*y[17];
out[782] = 1.0*y[3];
out[787] = -1.0*y[2];
out[820] = y[18];
out[821] = 1.0*y[23];
out[834] = y[4];
out[839] = 1.0*y[5];
out[871] = -1.0*y[23];
out[872] = 1.0*y[18];
out[885] = 1.0*y[5];
out[890] = -1.0*y[4];
out[1010] = y[41]*pow(1.0*pow(y[45], 2) + pow(y[41], 2), -0.5);
out[1014] = 1.0*y[45]*pow(1.0*pow(y[45], 2) + pow(y[41], 2), -0.5);
out[1062] = y[42]*pow(1.0*pow(y[46], 2) + pow(y[42], 2), -0.5);
out[1066] = 1.0*y[46]*pow(1.0*pow(y[46], 2) + pow(y[42], 2), -0.5);
out[1114] = y[43]*pow(1.0*pow(y[47], 2) + pow(y[43], 2), -0.5);
out[1118] = 1.0*y[47]*pow(1.0*pow(y[47], 2) + pow(y[43], 2), -0.5);
out[1166] = y[44]*pow(1.0*pow(y[48], 2) + pow(y[44], 2), -0.5);
out[1170] = 1.0*y[48]*pow(1.0*pow(y[48], 2) + pow(y[44], 2), -0.5);
out[1181] = y[41];
out[1182] = 1.0*y[45];
out[1183] = y[42];
out[1184] = 1.0*y[46];
out[1185] = y[43];
out[1186] = 1.0*y[47];
out[1214] = y[8];
out[1215] = y[10];
out[1216] = y[12];
out[1218] = 1.0*y[9];
out[1219] = 1.0*y[11];
out[1220] = 1.0*y[13];
out[1232] = -1.0*y[45];
out[1233] = 1.0*y[41];
out[1234] = -1.0*y[46];
out[1235] = 1.0*y[42];
out[1236] = -1.0*y[47];
out[1237] = 1.0*y[43];
out[1265] = 1.0*y[9];
out[1266] = 1.0*y[11];
out[1267] = 1.0*y[13];
out[1269] = -1.0*y[8];
out[1270] = -1.0*y[10];
out[1271] = -1.0*y[12];

}

void de_Hy_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hy_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 184.75059629806526;
out[1] = 94.615102344455664;
out[2] = -69.368640085185305;
out[3] = -17.974903844364835;
out[4] = -43.675799641021079;
out[5] = -40.748687841669557;
out[6] = -69.368640085185291;
out[7] = -17.974903844364821;
out[8] = -184.75059629806526;
out[9] = -94.615102344455664;
out[10] = 69.368640085185305;
out[11] = 17.974903844364835;
out[12] = 43.675799641021079;
out[13] = 40.748687841669557;
out[14] = 69.368640085185291;
out[15] = 17.974903844364821;
out[51] = -94.615102344455664;
out[52] = 184.75059629806526;
out[53] = 17.974903844364835;
out[54] = -69.368640085185305;
out[55] = 40.748687841669557;
out[56] = -43.675799641021079;
out[57] = 17.974903844364821;
out[58] = -69.368640085185291;
out[59] = 94.615102344455664;
out[60] = -184.75059629806526;
out[61] = -17.974903844364835;
out[62] = 69.368640085185305;
out[63] = -40.748687841669557;
out[64] = 43.675799641021079;
out[65] = -17.974903844364821;
out[66] = 69.368640085185291;
out[102] = -69.368640085185291;
out[103] = -17.974903844364825;
out[104] = 184.7505962980652;
out[105] = 94.615102344455636;
out[106] = -69.368640085185319;
out[107] = -17.97490384436481;
out[108] = -43.675799641021079;
out[109] = -40.748687841669565;
out[110] = 69.368640085185291;
out[111] = 17.974903844364825;
out[112] = -184.7505962980652;
out[113] = -94.615102344455636;
out[114] = 69.368640085185319;
out[115] = 17.97490384436481;
out[116] = 43.675799641021079;
out[117] = 40.748687841669565;
out[153] = 17.974903844364825;
out[154] = -69.368640085185291;
out[155] = -94.615102344455636;
out[156] = 184.7505962980652;
out[157] = 17.97490384436481;
out[158] = -69.368640085185319;
out[159] = 40.748687841669565;
out[160] = -43.675799641021079;
out[161] = -17.974903844364825;
out[162] = 69.368640085185291;
out[163] = 94.615102344455636;
out[164] = -184.7505962980652;
out[165] = -17.97490384436481;
out[166] = 69.368640085185319;
out[167] = -40.748687841669565;
out[168] = 43.675799641021079;
out[204] = -43.675799641021101;
out[205] = -40.748687841669579;
out[206] = -69.368640085185305;
out[207] = -17.974903844364821;
out[208] = 184.75059629806526;
out[209] = 94.61510234445565;
out[210] = -69.368640085185305;
out[211] = -17.974903844364821;
out[212] = 43.675799641021101;
out[213] = 40.748687841669579;
out[214] = 69.368640085185305;
out[215] = 17.974903844364821;
out[216] = -184.75059629806526;
out[217] = -94.61510234445565;
out[218] = 69.368640085185305;
out[219] = 17.974903844364821;
out[255] = 40.748687841669579;
out[256] = -43.675799641021101;
out[257] = 17.974903844364821;
out[258] = -69.368640085185305;
out[259] = -94.61510234445565;
out[260] = 184.75059629806526;
out[261] = 17.974903844364821;
out[262] = -69.368640085185305;
out[263] = -40.748687841669579;
out[264] = 43.675799641021101;
out[265] = -17.974903844364821;
out[266] = 69.368640085185305;
out[267] = 94.61510234445565;
out[268] = -184.75059629806526;
out[269] = -17.974903844364821;
out[270] = 69.368640085185305;
out[306] = -69.368640085185305;
out[307] = -17.974903844364825;
out[308] = -43.675799641021079;
out[309] = -40.74868784166955;
out[310] = -69.368640085185291;
out[311] = -17.974903844364839;
out[312] = 184.7505962980652;
out[313] = 94.61510234445565;
out[314] = 69.368640085185305;
out[315] = 17.974903844364825;
out[316] = 43.675799641021079;
out[317] = 40.74868784166955;
out[318] = 69.368640085185291;
out[319] = 17.974903844364839;
out[320] = -184.7505962980652;
out[321] = -94.61510234445565;
out[357] = 17.974903844364825;
out[358] = -69.368640085185305;
out[359] = 40.74868784166955;
out[360] = -43.675799641021079;
out[361] = 17.974903844364839;
out[362] = -69.368640085185291;
out[363] = -94.61510234445565;
out[364] = 184.7505962980652;
out[365] = -17.974903844364825;
out[366] = 69.368640085185305;
out[367] = -40.74868784166955;
out[368] = 43.675799641021079;
out[369] = -17.974903844364839;
out[370] = 69.368640085185291;
out[371] = 94.61510234445565;
out[372] = -184.7505962980652;

}

void de_Hu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void de_Hu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[330] = 1.0;
out[485] = 1.0;

}

void sp_Fu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Fu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Fu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[1] = 1.0;

}

void sp_Gu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[2] = y[18];
out[3] = 1.0*y[23];

}

void sp_Gu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[4] = -p[9];
out[21] = cos(u[16]);
out[22] = -u[12]*sin(u[16]);
out[23] = cos(u[16] - 2.0943951023931953);
out[24] = -u[13]*sin(u[16] - 2.0943951023931953);
out[25] = cos(u[16] - 4.1887902047863905);
out[26] = -u[14]*sin(u[16] - 4.1887902047863905);
out[27] = 1.0*sin(u[16]);
out[28] = 1.0*u[12]*cos(u[16]);
out[29] = 1.0*sin(u[16] - 2.0943951023931953);
out[30] = 1.0*u[13]*cos(u[16] - 2.0943951023931953);
out[31] = 1.0*sin(u[16] - 4.1887902047863905);
out[32] = 1.0*u[14]*cos(u[16] - 4.1887902047863905);

}

void sp_Gu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[1] = 1.0;
out[5] = -1.0;
out[6] = 1.0;
out[7] = 0.33333333333333331;
out[8] = 0.33333333333333331;
out[9] = 1.0;
out[10] = 0.33333333333333331;
out[11] = 0.33333333333333331;
out[12] = 1.0;
out[13] = 0.33333333333333331;
out[14] = 0.33333333333333331;
out[15] = 1.0;
out[16] = 0.33333333333333331;
out[17] = 1.0;
out[18] = 0.33333333333333331;
out[19] = 1.0;
out[20] = 0.33333333333333331;

}

void sp_Hx_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hx_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hx_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;

}

void sp_Hy_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[128] = y[16]*pow(1.0*pow(y[21], 2) + pow(y[16], 2), -0.5);
out[129] = 1.0*y[21]*pow(1.0*pow(y[21], 2) + pow(y[16], 2), -0.5);
out[130] = y[17]*pow(1.0*pow(y[22], 2) + pow(y[17], 2), -0.5);
out[131] = 1.0*y[22]*pow(1.0*pow(y[22], 2) + pow(y[17], 2), -0.5);
out[132] = y[18]*pow(1.0*pow(y[23], 2) + pow(y[18], 2), -0.5);
out[133] = 1.0*y[23]*pow(1.0*pow(y[23], 2) + pow(y[18], 2), -0.5);
out[134] = y[19]*pow(1.0*pow(y[24], 2) + pow(y[19], 2), -0.5);
out[135] = 1.0*y[24]*pow(1.0*pow(y[24], 2) + pow(y[19], 2), -0.5);
out[136] = y[16];
out[137] = 1.0*y[21];
out[138] = y[0];
out[139] = 1.0*y[1];
out[140] = -1.0*y[21];
out[141] = 1.0*y[16];
out[142] = 1.0*y[1];
out[143] = -1.0*y[0];
out[144] = y[17];
out[145] = 1.0*y[22];
out[146] = y[2];
out[147] = 1.0*y[3];
out[148] = -1.0*y[22];
out[149] = 1.0*y[17];
out[150] = 1.0*y[3];
out[151] = -1.0*y[2];
out[152] = y[18];
out[153] = 1.0*y[23];
out[154] = y[4];
out[155] = 1.0*y[5];
out[156] = -1.0*y[23];
out[157] = 1.0*y[18];
out[158] = 1.0*y[5];
out[159] = -1.0*y[4];
out[160] = y[41]*pow(1.0*pow(y[45], 2) + pow(y[41], 2), -0.5);
out[161] = 1.0*y[45]*pow(1.0*pow(y[45], 2) + pow(y[41], 2), -0.5);
out[162] = y[42]*pow(1.0*pow(y[46], 2) + pow(y[42], 2), -0.5);
out[163] = 1.0*y[46]*pow(1.0*pow(y[46], 2) + pow(y[42], 2), -0.5);
out[164] = y[43]*pow(1.0*pow(y[47], 2) + pow(y[43], 2), -0.5);
out[165] = 1.0*y[47]*pow(1.0*pow(y[47], 2) + pow(y[43], 2), -0.5);
out[166] = y[44]*pow(1.0*pow(y[48], 2) + pow(y[44], 2), -0.5);
out[167] = 1.0*y[48]*pow(1.0*pow(y[48], 2) + pow(y[44], 2), -0.5);
out[168] = y[41];
out[169] = 1.0*y[45];
out[170] = y[42];
out[171] = 1.0*y[46];
out[172] = y[43];
out[173] = 1.0*y[47];
out[174] = y[8];
out[175] = y[10];
out[176] = y[12];
out[177] = 1.0*y[9];
out[178] = 1.0*y[11];
out[179] = 1.0*y[13];
out[180] = -1.0*y[45];
out[181] = 1.0*y[41];
out[182] = -1.0*y[46];
out[183] = 1.0*y[42];
out[184] = -1.0*y[47];
out[185] = 1.0*y[43];
out[186] = 1.0*y[9];
out[187] = 1.0*y[11];
out[188] = 1.0*y[13];
out[189] = -1.0*y[8];
out[190] = -1.0*y[10];
out[191] = -1.0*y[12];

}

void sp_Hy_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hy_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 184.75059629806526;
out[1] = 94.615102344455664;
out[2] = -69.368640085185305;
out[3] = -17.974903844364835;
out[4] = -43.675799641021079;
out[5] = -40.748687841669557;
out[6] = -69.368640085185291;
out[7] = -17.974903844364821;
out[8] = -184.75059629806526;
out[9] = -94.615102344455664;
out[10] = 69.368640085185305;
out[11] = 17.974903844364835;
out[12] = 43.675799641021079;
out[13] = 40.748687841669557;
out[14] = 69.368640085185291;
out[15] = 17.974903844364821;
out[16] = -94.615102344455664;
out[17] = 184.75059629806526;
out[18] = 17.974903844364835;
out[19] = -69.368640085185305;
out[20] = 40.748687841669557;
out[21] = -43.675799641021079;
out[22] = 17.974903844364821;
out[23] = -69.368640085185291;
out[24] = 94.615102344455664;
out[25] = -184.75059629806526;
out[26] = -17.974903844364835;
out[27] = 69.368640085185305;
out[28] = -40.748687841669557;
out[29] = 43.675799641021079;
out[30] = -17.974903844364821;
out[31] = 69.368640085185291;
out[32] = -69.368640085185291;
out[33] = -17.974903844364825;
out[34] = 184.7505962980652;
out[35] = 94.615102344455636;
out[36] = -69.368640085185319;
out[37] = -17.97490384436481;
out[38] = -43.675799641021079;
out[39] = -40.748687841669565;
out[40] = 69.368640085185291;
out[41] = 17.974903844364825;
out[42] = -184.7505962980652;
out[43] = -94.615102344455636;
out[44] = 69.368640085185319;
out[45] = 17.97490384436481;
out[46] = 43.675799641021079;
out[47] = 40.748687841669565;
out[48] = 17.974903844364825;
out[49] = -69.368640085185291;
out[50] = -94.615102344455636;
out[51] = 184.7505962980652;
out[52] = 17.97490384436481;
out[53] = -69.368640085185319;
out[54] = 40.748687841669565;
out[55] = -43.675799641021079;
out[56] = -17.974903844364825;
out[57] = 69.368640085185291;
out[58] = 94.615102344455636;
out[59] = -184.7505962980652;
out[60] = -17.97490384436481;
out[61] = 69.368640085185319;
out[62] = -40.748687841669565;
out[63] = 43.675799641021079;
out[64] = -43.675799641021101;
out[65] = -40.748687841669579;
out[66] = -69.368640085185305;
out[67] = -17.974903844364821;
out[68] = 184.75059629806526;
out[69] = 94.61510234445565;
out[70] = -69.368640085185305;
out[71] = -17.974903844364821;
out[72] = 43.675799641021101;
out[73] = 40.748687841669579;
out[74] = 69.368640085185305;
out[75] = 17.974903844364821;
out[76] = -184.75059629806526;
out[77] = -94.61510234445565;
out[78] = 69.368640085185305;
out[79] = 17.974903844364821;
out[80] = 40.748687841669579;
out[81] = -43.675799641021101;
out[82] = 17.974903844364821;
out[83] = -69.368640085185305;
out[84] = -94.61510234445565;
out[85] = 184.75059629806526;
out[86] = 17.974903844364821;
out[87] = -69.368640085185305;
out[88] = -40.748687841669579;
out[89] = 43.675799641021101;
out[90] = -17.974903844364821;
out[91] = 69.368640085185305;
out[92] = 94.61510234445565;
out[93] = -184.75059629806526;
out[94] = -17.974903844364821;
out[95] = 69.368640085185305;
out[96] = -69.368640085185305;
out[97] = -17.974903844364825;
out[98] = -43.675799641021079;
out[99] = -40.74868784166955;
out[100] = -69.368640085185291;
out[101] = -17.974903844364839;
out[102] = 184.7505962980652;
out[103] = 94.61510234445565;
out[104] = 69.368640085185305;
out[105] = 17.974903844364825;
out[106] = 43.675799641021079;
out[107] = 40.74868784166955;
out[108] = 69.368640085185291;
out[109] = 17.974903844364839;
out[110] = -184.7505962980652;
out[111] = -94.61510234445565;
out[112] = 17.974903844364825;
out[113] = -69.368640085185305;
out[114] = 40.74868784166955;
out[115] = -43.675799641021079;
out[116] = 17.974903844364839;
out[117] = -69.368640085185291;
out[118] = -94.61510234445565;
out[119] = 184.7505962980652;
out[120] = -17.974903844364825;
out[121] = 69.368640085185305;
out[122] = -40.74868784166955;
out[123] = 43.675799641021079;
out[124] = -17.974903844364839;
out[125] = 69.368640085185291;
out[126] = 94.61510234445565;
out[127] = -184.7505962980652;

}

void sp_Hu_run_xy_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hu_run_up_eval(double *out,double *x,double *y,double *u,double *p,double Dt){


}

void sp_Hu_run_num_eval(double *out,double *x,double *y,double *u,double *p,double Dt){

out[0] = 1.0;
out[1] = 1.0;

}



/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 8), // void()(double *, double *, double *, double *, double *, double)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 6), // double *
/*  2 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  3 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  4 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  5 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  6 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 14), // double
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  8 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

static void _cffi_d_de_Fu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_num_eval _cffi_d_de_Fu_run_num_eval
#endif

static void _cffi_d_de_Fu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_up_eval _cffi_d_de_Fu_run_up_eval
#endif

static void _cffi_d_de_Fu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Fu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Fu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Fu_run_xy_eval _cffi_d_de_Fu_run_xy_eval
#endif

static void _cffi_d_de_Gu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_num_eval _cffi_d_de_Gu_run_num_eval
#endif

static void _cffi_d_de_Gu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_up_eval _cffi_d_de_Gu_run_up_eval
#endif

static void _cffi_d_de_Gu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Gu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Gu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Gu_run_xy_eval _cffi_d_de_Gu_run_xy_eval
#endif

static void _cffi_d_de_Hu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_num_eval _cffi_d_de_Hu_run_num_eval
#endif

static void _cffi_d_de_Hu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_up_eval _cffi_d_de_Hu_run_up_eval
#endif

static void _cffi_d_de_Hu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hu_run_xy_eval _cffi_d_de_Hu_run_xy_eval
#endif

static void _cffi_d_de_Hx_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_num_eval _cffi_d_de_Hx_run_num_eval
#endif

static void _cffi_d_de_Hx_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_up_eval _cffi_d_de_Hx_run_up_eval
#endif

static void _cffi_d_de_Hx_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hx_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hx_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hx_run_xy_eval _cffi_d_de_Hx_run_xy_eval
#endif

static void _cffi_d_de_Hy_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_num_eval _cffi_d_de_Hy_run_num_eval
#endif

static void _cffi_d_de_Hy_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_up_eval _cffi_d_de_Hy_run_up_eval
#endif

static void _cffi_d_de_Hy_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_Hy_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_Hy_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_Hy_run_xy_eval _cffi_d_de_Hy_run_xy_eval
#endif

static void _cffi_d_de_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_num_eval _cffi_d_de_jac_ini_num_eval
#endif

static void _cffi_d_de_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_up_eval _cffi_d_de_jac_ini_up_eval
#endif

static void _cffi_d_de_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_ini_xy_eval _cffi_d_de_jac_ini_xy_eval
#endif

static void _cffi_d_de_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_num_eval _cffi_d_de_jac_run_num_eval
#endif

static void _cffi_d_de_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_up_eval _cffi_d_de_jac_run_up_eval
#endif

static void _cffi_d_de_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_run_xy_eval _cffi_d_de_jac_run_xy_eval
#endif

static void _cffi_d_de_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_num_eval _cffi_d_de_jac_trap_num_eval
#endif

static void _cffi_d_de_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_up_eval _cffi_d_de_jac_trap_up_eval
#endif

static void _cffi_d_de_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_de_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "de_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { de_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_de_jac_trap_xy_eval _cffi_d_de_jac_trap_xy_eval
#endif

static void _cffi_d_f_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_ini_eval _cffi_d_f_ini_eval
#endif

static void _cffi_d_f_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  f_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_f_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "f_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { f_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_f_run_eval _cffi_d_f_run_eval
#endif

static void _cffi_d_g_ini_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_ini_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_ini_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_ini_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_ini_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_ini_eval _cffi_d_g_ini_eval
#endif

static void _cffi_d_g_run_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  g_run_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_g_run_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "g_run_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { g_run_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_g_run_eval _cffi_d_g_run_eval
#endif

static void _cffi_d_h_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  h_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_h_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "h_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { h_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_h_eval _cffi_d_h_eval
#endif

static void _cffi_d_sp_Fu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_num_eval _cffi_d_sp_Fu_run_num_eval
#endif

static void _cffi_d_sp_Fu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_up_eval _cffi_d_sp_Fu_run_up_eval
#endif

static void _cffi_d_sp_Fu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Fu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Fu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Fu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Fu_run_xy_eval _cffi_d_sp_Fu_run_xy_eval
#endif

static void _cffi_d_sp_Gu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_num_eval _cffi_d_sp_Gu_run_num_eval
#endif

static void _cffi_d_sp_Gu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_up_eval _cffi_d_sp_Gu_run_up_eval
#endif

static void _cffi_d_sp_Gu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Gu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Gu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Gu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Gu_run_xy_eval _cffi_d_sp_Gu_run_xy_eval
#endif

static void _cffi_d_sp_Hu_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_num_eval _cffi_d_sp_Hu_run_num_eval
#endif

static void _cffi_d_sp_Hu_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_up_eval _cffi_d_sp_Hu_run_up_eval
#endif

static void _cffi_d_sp_Hu_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hu_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hu_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hu_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hu_run_xy_eval _cffi_d_sp_Hu_run_xy_eval
#endif

static void _cffi_d_sp_Hx_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_num_eval _cffi_d_sp_Hx_run_num_eval
#endif

static void _cffi_d_sp_Hx_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_up_eval _cffi_d_sp_Hx_run_up_eval
#endif

static void _cffi_d_sp_Hx_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hx_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hx_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hx_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hx_run_xy_eval _cffi_d_sp_Hx_run_xy_eval
#endif

static void _cffi_d_sp_Hy_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_num_eval _cffi_d_sp_Hy_run_num_eval
#endif

static void _cffi_d_sp_Hy_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_up_eval _cffi_d_sp_Hy_run_up_eval
#endif

static void _cffi_d_sp_Hy_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_Hy_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_Hy_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_Hy_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_Hy_run_xy_eval _cffi_d_sp_Hy_run_xy_eval
#endif

static void _cffi_d_sp_jac_ini_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_num_eval _cffi_d_sp_jac_ini_num_eval
#endif

static void _cffi_d_sp_jac_ini_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_up_eval _cffi_d_sp_jac_ini_up_eval
#endif

static void _cffi_d_sp_jac_ini_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_ini_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_ini_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_ini_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_ini_xy_eval _cffi_d_sp_jac_ini_xy_eval
#endif

static void _cffi_d_sp_jac_run_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_num_eval _cffi_d_sp_jac_run_num_eval
#endif

static void _cffi_d_sp_jac_run_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_up_eval _cffi_d_sp_jac_run_up_eval
#endif

static void _cffi_d_sp_jac_run_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_run_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_run_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_run_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_run_xy_eval _cffi_d_sp_jac_run_xy_eval
#endif

static void _cffi_d_sp_jac_trap_num_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_num_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_num_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_num_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_num_eval _cffi_d_sp_jac_trap_num_eval
#endif

static void _cffi_d_sp_jac_trap_up_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_up_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_up_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_up_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_up_eval _cffi_d_sp_jac_trap_up_eval
#endif

static void _cffi_d_sp_jac_trap_xy_eval(double * x0, double * x1, double * x2, double * x3, double * x4, double x5)
{
  sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_sp_jac_trap_xy_eval(PyObject *self, PyObject *args)
{
  double * x0;
  double * x1;
  double * x2;
  double * x3;
  double * x4;
  double x5;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *arg5;

  if (!PyArg_UnpackTuple(args, "sp_jac_trap_xy_eval", 6, 6, &arg0, &arg1, &arg2, &arg3, &arg4, &arg5))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg3, (char **)&x3);
  if (datasize != 0) {
    x3 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg3, (char **)&x3,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (double *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x5 = (double)_cffi_to_c_double(arg5);
  if (x5 == (double)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { sp_jac_trap_xy_eval(x0, x1, x2, x3, x4, x5); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_sp_jac_trap_xy_eval _cffi_d_sp_jac_trap_xy_eval
#endif

static const struct _cffi_global_s _cffi_globals[] = {
  { "de_Fu_run_num_eval", (void *)_cffi_f_de_Fu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_num_eval },
  { "de_Fu_run_up_eval", (void *)_cffi_f_de_Fu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_up_eval },
  { "de_Fu_run_xy_eval", (void *)_cffi_f_de_Fu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Fu_run_xy_eval },
  { "de_Gu_run_num_eval", (void *)_cffi_f_de_Gu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_num_eval },
  { "de_Gu_run_up_eval", (void *)_cffi_f_de_Gu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_up_eval },
  { "de_Gu_run_xy_eval", (void *)_cffi_f_de_Gu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Gu_run_xy_eval },
  { "de_Hu_run_num_eval", (void *)_cffi_f_de_Hu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_num_eval },
  { "de_Hu_run_up_eval", (void *)_cffi_f_de_Hu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_up_eval },
  { "de_Hu_run_xy_eval", (void *)_cffi_f_de_Hu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hu_run_xy_eval },
  { "de_Hx_run_num_eval", (void *)_cffi_f_de_Hx_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_num_eval },
  { "de_Hx_run_up_eval", (void *)_cffi_f_de_Hx_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_up_eval },
  { "de_Hx_run_xy_eval", (void *)_cffi_f_de_Hx_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hx_run_xy_eval },
  { "de_Hy_run_num_eval", (void *)_cffi_f_de_Hy_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_num_eval },
  { "de_Hy_run_up_eval", (void *)_cffi_f_de_Hy_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_up_eval },
  { "de_Hy_run_xy_eval", (void *)_cffi_f_de_Hy_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_Hy_run_xy_eval },
  { "de_jac_ini_num_eval", (void *)_cffi_f_de_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_num_eval },
  { "de_jac_ini_up_eval", (void *)_cffi_f_de_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_up_eval },
  { "de_jac_ini_xy_eval", (void *)_cffi_f_de_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_ini_xy_eval },
  { "de_jac_run_num_eval", (void *)_cffi_f_de_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_num_eval },
  { "de_jac_run_up_eval", (void *)_cffi_f_de_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_up_eval },
  { "de_jac_run_xy_eval", (void *)_cffi_f_de_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_run_xy_eval },
  { "de_jac_trap_num_eval", (void *)_cffi_f_de_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_num_eval },
  { "de_jac_trap_up_eval", (void *)_cffi_f_de_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_up_eval },
  { "de_jac_trap_xy_eval", (void *)_cffi_f_de_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_de_jac_trap_xy_eval },
  { "f_ini_eval", (void *)_cffi_f_f_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_ini_eval },
  { "f_run_eval", (void *)_cffi_f_f_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_f_run_eval },
  { "g_ini_eval", (void *)_cffi_f_g_ini_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_ini_eval },
  { "g_run_eval", (void *)_cffi_f_g_run_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_g_run_eval },
  { "h_eval", (void *)_cffi_f_h_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_h_eval },
  { "sp_Fu_run_num_eval", (void *)_cffi_f_sp_Fu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_num_eval },
  { "sp_Fu_run_up_eval", (void *)_cffi_f_sp_Fu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_up_eval },
  { "sp_Fu_run_xy_eval", (void *)_cffi_f_sp_Fu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Fu_run_xy_eval },
  { "sp_Gu_run_num_eval", (void *)_cffi_f_sp_Gu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_num_eval },
  { "sp_Gu_run_up_eval", (void *)_cffi_f_sp_Gu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_up_eval },
  { "sp_Gu_run_xy_eval", (void *)_cffi_f_sp_Gu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Gu_run_xy_eval },
  { "sp_Hu_run_num_eval", (void *)_cffi_f_sp_Hu_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_num_eval },
  { "sp_Hu_run_up_eval", (void *)_cffi_f_sp_Hu_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_up_eval },
  { "sp_Hu_run_xy_eval", (void *)_cffi_f_sp_Hu_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hu_run_xy_eval },
  { "sp_Hx_run_num_eval", (void *)_cffi_f_sp_Hx_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_num_eval },
  { "sp_Hx_run_up_eval", (void *)_cffi_f_sp_Hx_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_up_eval },
  { "sp_Hx_run_xy_eval", (void *)_cffi_f_sp_Hx_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hx_run_xy_eval },
  { "sp_Hy_run_num_eval", (void *)_cffi_f_sp_Hy_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_num_eval },
  { "sp_Hy_run_up_eval", (void *)_cffi_f_sp_Hy_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_up_eval },
  { "sp_Hy_run_xy_eval", (void *)_cffi_f_sp_Hy_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_Hy_run_xy_eval },
  { "sp_jac_ini_num_eval", (void *)_cffi_f_sp_jac_ini_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_num_eval },
  { "sp_jac_ini_up_eval", (void *)_cffi_f_sp_jac_ini_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_up_eval },
  { "sp_jac_ini_xy_eval", (void *)_cffi_f_sp_jac_ini_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_ini_xy_eval },
  { "sp_jac_run_num_eval", (void *)_cffi_f_sp_jac_run_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_num_eval },
  { "sp_jac_run_up_eval", (void *)_cffi_f_sp_jac_run_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_up_eval },
  { "sp_jac_run_xy_eval", (void *)_cffi_f_sp_jac_run_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_run_xy_eval },
  { "sp_jac_trap_num_eval", (void *)_cffi_f_sp_jac_trap_num_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_num_eval },
  { "sp_jac_trap_up_eval", (void *)_cffi_f_sp_jac_trap_up_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_up_eval },
  { "sp_jac_trap_xy_eval", (void *)_cffi_f_sp_jac_trap_xy_eval, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 0), (void *)_cffi_d_sp_jac_trap_xy_eval },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  NULL,  /* no fields */
  NULL,  /* no struct_unions */
  NULL,  /* no enums */
  NULL,  /* no typenames */
  53,  /* num_globals */
  0,  /* num_struct_unions */
  0,  /* num_enums */
  0,  /* num_typenames */
  NULL,  /* no includes */
  9,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit_temp_cffi(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit_temp_cffi(void) { return NULL; }
#  else
     inittemp_cffi(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit_temp_cffi(void)
{
  return _cffi_init("temp_cffi", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
inittemp_cffi(void)
{
  _cffi_init("temp_cffi", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
